
clear all
set more off


global root "PATH/TO/REPLICATION/"
cd "${root}"
qui do code\macros.do
global econ_paper "econ_Paper_Level_clean.dta"

global bad_solo_journals JASA AS JCP

global econ_journals AER AERPP ECTA ET EcT JE JET JMathE JPE QJE REStud RAND IJGT AEJ_Applied AEJ_Policy AEJ_Micro AEJ_Macro JEP JEL GEB IER REStat ECA EJ JASA JDE JEEA JF JHE JIE JME JOLE JPubE JEH QE TE

global psych_journals JEPG NBR PR PS TiCS PB JPSP ARP PNAS AP CD Cog CP DP

global math_journals AM JAM CM DMJ JASA PNAS IM AIM AS JCP

program main
	local field = "econ"
	name_prep, field(`field')
	author_year, field(`field')
	rectangularize, field(`field')

end

program name_prep
	syntax, field(str)
	* run gender package from FIELD/gender on output from gender_prep.do 
	use "${root}/`field'/output/names_tobe_gendered.dta", clear
	
	split author, parse(" ")
	local nsplit = r(nvars)
	gen last_name = ""
	forval y = 1/`nsplit' {
		replace last_name = author`y' if !missing(author`y')
	}

	rename author1 first_name

	gen middle_name = ""
	forval y = 2/`nsplit' {
		replace middle_name = middle_name + " " + author`y' if !missing(author`y') & author`y' != last_name
	}
	replace middle_name = strtrim(middle_name)
	
	
	*** delete authors with only JASA publications
	foreach journal in $bad_solo_journals {
		by author, sort: gen `journal'_only = (journal == "`journal'")
		by author: egen `journal'_only_1 = min(`journal'_only)
		order paper year author journal `journal'_only `journal'_only_1
		drop if `journal'_only_1 == 1
		drop `journal'_only `journal'_only_1
	}
	gen Name = first_name + " " + last_name
	merge m:1 Name using "${root}/`field'/gender/code/output/gender_name.dta", keep(1 3)
	drop Name
	
	* For names that still are in the form A.B.C. Last, change to A. B. C. Last
	replace author = subinstr(author, ".", ". ", .)
	replace author = itrim(author)

	compress
	save "${root}/`field'/temp/Author_Paper.dta", replace 

end

program author_year
	syntax, field(str)
	
	use "${root}/`field'/temp/Author_Paper.dta", clear // both old and new authors are here

	gen paper_id = _n
	if "`field'" != "econ" {
		local first_multi_author = "first_multi_author"
	}
	collapse (count) nm_paper = paper_id ///
		(sum) single_author_paper `first_multi_author' ///
		(first) first_name middle_name last_name author_original ///
		Male Female Ambiguous, ///
		by(author year journal) fast // author-year-journal level
	rename author author

	replace journal = subinstr(journal, ": ", "_", .) // having ": " in names is invalid in the loop below
	local loopjournals = "`field'_journals"
	foreach journal in $`loopjournals' {
		preserve
			drop if journal != "`journal'"
			rename nm_paper `journal'
			tempfile temp`journal'
			save "`temp`journal''", replace
		restore
	}

	foreach journal in $`loopjournals' {
		merge 1:1 author year journal using "`temp`journal''", keep (1 3) keepusing (`journal') nogen
		gen single_`journal' = single_author_paper if journal == "`journal'"
		replace single_`journal' = 0 if journal != "`journal'"
		if "`field'" != "econ" {
			gen first_multi_`journal' = first_multi_author if journal == "`journal'"
			replace first_multi_`journal' = 0 if journal != "`journal'"
		}
	}
	drop single_author_paper `first_multi_author'
	if "`field'" != "econ" {
		local agg_command = "first_multi_*"
	}

	collapse (sum) nm_paper ${`field'_journals} single_* `agg_command' ///
		(first) first_name middle_name last_name author_original Male Female Ambiguous, by(author year) 


	* cumulative pubs
	bysort author (year): gen nm_paper_cumulative = sum(nm_paper)
	
	foreach journal in $`loopjournals' {
		bysort author (year): gen `journal'_cumulative = sum(`journal')
		bysort author (year): gen single_`journal'_cumulative = sum(single_`journal')
		if "`field'" != "econ" {
			bysort author (year): gen first_multi_`journal'_cumulative = sum(first_multi_`journal')
			drop first_multi_`journal'
		}
		
		drop single_`journal' 
		
	}

	sort author year

	* no middle name, to be merged with the fellows
	gen author_nomi = first_name + " " + last_name

	* ==================================================================================================================================
	* generate ID for the authors, and label the variables
	sort author

	label variable author "cleaned author name"
	label variable author_original "original author name"
	label variable author_nomi "cleaned author name with no middle-initial"
	label variable nm_paper "number of paper"
	label variable year "publication year"
	
	foreach var in  $`loopjournals'   {
		local label = "label_`var'"
		label variable `var' "$`label'"
	}

	* ==========================================================================
	compress

	save "${root}/`field'/temp/Author_Year.dta", replace
end


program rectangularize
	syntax, field(str)
	* ==================================================================================================================================
	* make it rectangular
	use "${root}/`field'/temp/Author_Year.dta", clear
	
	*split up the year ranges to speed up the tsfill. Make sure a person with
	*a single pub in 2019 doesn't tsfill down to 1890
	
	egen id = group(author)
	order id author
	tsset id year
	tsfill, full
	
	order author year author_nomi

	* fill in missing years for cumulative ones
	local vars author author_original author_nomi first_name middle_name last_name Male Female Ambiguous *_cumulative
	foreach var of varlist `vars' {
		bysort id: carryforward `var', gen(`var'_ex)
		drop `var'
		rename `var'_ex `var'
	}
	
	drop if nm_paper_cumulative ==. 
	* fill in missing years for non-cumulative ones
	local loopjournals = "`field'_journals"
	foreach var in nm_paper $`loopjournals' {
		replace `var' = 0 if `var' == .
	}
	
	drop id
	
	order year author author_original author_nomi first_name middle_name last_name Male Female Ambiguous

	sort author year
	
	compress
	save "${root}/`field'/output/Author_Year_Level_Rectangular_Gendered.dta", replace


end


main


