
clear all
set more off
set trace off

global root "PATH/TO/REPLICATION/"
cd "${root}"
global econ_paper "econ_Paper_Level_clean.dta"

global econ_journals aer ecta jpe qje restud

global aer_var = "AER"
global ecta_var = "ECTA"
global jpe_var = "JPE"
global qje_var = "QJE"
global restud_var = "REStud"

program main
	prep_citeless_papers, field(econ)
	foreach journal in $econ_journals {
		aggregate_cites, field(econ) journal(`journal')
		
	}


end


program prep_citeless_papers
	syntax, field(str)
	use doi author using "${root}/`field'/temp/Author_Paper.dta", clear
	rename doi paper
	* reshape to paper level (with a list of authors)
	format %40s paper
	by paper, sort: gen author_id = _n

	reshape wide author, i(paper) j(author_id)

	* capture number of author variables
	gen list_author = ""
	local complete = 0 
	local i = 1
	while `complete' == 0 {
		capture confirm variable author`=`i'+1'
		if _rc == 0 {
			local i = `i' + 1
		}
		local complete = _rc

	}
	di "`i'"
	forval y = 1/`i' {
		format %20s author`y'
		replace list_author = list_author + "; " + author`y' if author`y' != ""
	}

	format %60s list_author
	order paper list_author

	forval y = 1/`i' {
		drop author`y'
	}

	* the dataset is now in paper_level
	save "${root}/`field'/temp/paper_level.dta", replace

	* Papers with 1000+ citations 
	* ============================================================================================================================================
	* merge by accession number 

	clear
	import excel using "${root}/`field'/WOS/econ_lifetime_cites_combined.xlsx", first 
	keep UTUniqueWOSID DOI
	rename (UTUniqueWOSID DOI) (accession doi)
	drop if missing(doi)
	duplicates drop accession, force

	compress 
	save "${root}/`field'/temp/missing_cites_doi.dta", replace

	clear 
	import excel using "${root}/`field'/WOS/econ_year_cites_combined.xlsx", first 
	gen year_cites_1000 = (cites >= 1000 & !missing(cites))
	bysort accession: egen keep = max(year_cites_1000)
	drop if keep != 1 | data == "record complete"
	keep year data accession
	rename data cite  

	merge m:1 accession using "${root}/`field'/temp/missing_cites_doi.dta"
	keep if _merge == 3
	drop _merge accession 
	rename doi paper 
	replace paper = "https://www.jstor.org/stable/10.2307/1914185" if paper == "10.2307/1914185"
	replace paper = "https://doi.org/10.2307/2297968" if paper == "10.2307/2297968"

	compress 
	save "${root}/`field'/temp/missing_paper_correspondence.dta", replace
end


program aggregate_cites
	syntax, field(str) journal(str)
	if "`journal'" == "ecta" | "`journal'" ==  "restud" {
		* merge in fixed DOIs
		import delimited "${root}/`field'/WOS/`journal'_corrected.csv", varnames(1) encoding(ISO-8859-1)clear
		rename v1 new_doi
		joinby new_doi using "${root}/`field'/WOS/wos_doi/matched_wos_doi.dta"

		duplicates drop new_doi doi title v2, force  
		drop citations title journal_fullname
		rename v2 corrected_cites

		tempfile bad_doi
		save "`bad_doi'"

		* append the manual-search ECTA doi citations
		import delimited "${root}/`field'/WOS/wos_doi/`journal'_manual_citations.csv", varnames(1) encoding(ISO-8859-1)clear
		rename (new_doi citations) (doi corrected_cites)
		order doi
		append using "`bad_doi'"

		compress
		save "${root}/`field'/temp/`journal'_doi_correspondence.dta", replace
		if "`journal'" == "ecta" {
			* append the missing doi citations 
			import excel "${root}/`field'/WOS/econ_supplemental_cites_4_28_parsed.xlsx", firstrow clear 

			keep doi data
			rename data cite 
			drop if cite == "record complete" | strpos(cite, "2021")
			sort cite 

			tempfile temp 
			save "`temp'"
		}
	}
	else {

		import delimited "${root}/`field'/WOS/wos_doi/`journal'_manual_citations.csv", varnames(1) encoding(UTF-8)clear
		drop journal
		rename citations cite
		save "${root}/`field'/WOS/wos_doi/`journal'_manual_citations.dta", replace
	}

	insheet using "${root}/`field'/WOS/`journal'.csv", clear

	rename (v1 v2) (doi cite)
	sort cite

	if "`journal'" == "ecta" | "`journal'" ==  "restud"  {
		if "`journal'" == "ecta" {
			append using "`temp'"
		}
		* merge back the bad dois
		joinby doi using "${root}/`field'/temp/`journal'_doi_correspondence.dta", unmatched(both) _merge(_merge)

		sort cite doi
		replace cite = corrected_cites if (cite == "bad_doi" & _merge == 3) 
		drop corrected_cites _merge
		rename doi paper
		* merge back the papers with missing 1000+ cites. For ecta, the dois eixst and can be joined. Remainder are appended for restud
		append using "${root}/`field'/temp/missing_paper_correspondence.dta"
			
		if "`journal'" == "ecta" {
			drop if paper == "https://doi.org/10.2307/2297968"	
				}
		else {
			drop if paper == "https://www.jstor.org/stable/10.2307/1914185"	
			
		}
		duplicates drop paper cite, force
		drop new_doi year
	}
	else {
		drop if cite == "bad_doi"
		append using "${root}/`field'/WOS/wos_doi/`journal'_manual_citations.dta"
		rename doi paper
	}
	* all papers should be matched
	merge m:1 paper using "${root}/`field'/temp/paper_level.dta", keep(3) nogen
	format %40s paper

	split cite, parse("(")
	drop if cite1 == "0 cites" | cite1 == "bad_doi"

	rename (cite1 cite2) (year num_cite)
	replace num_cite = subinstr(num_cite, ")", "", .)
	replace num_cite = subinstr(num_cite, ",", "", .)
	drop cite

	* the dataset is now paper-year level
	sort paper year
	drop if year == "CRESS LESSOR EA 2614 "
	drop if year == "ICI EA 2652 "

	* expand out the authors
	rename list_author author
	replace author = substr(author, 2, .)

	split author, parse("; ")
	rename author list_authors
	gen multi_author = 1
	replace multi_author = 0 if missing(author2)

	duplicates drop paper year num_cite, force
	reshape long author, i(paper year num_cite)
	drop if missing(author)
	drop _j list_authors

	* clean any possible utf characters from python scrape
	gen cite_utf = ustrregexra(num_cite, ustrunescape("\u200e"), "") 
	replace num_cite = cite_utf
	drop cite_utf
	destring year num_cite, replace

	order paper author year num_cite

	gen single_author = (multi_author == 0) * num_cite
	replace multi_author = multi_author * num_cite

	collapse (sum) ${`journal'_var}_cite = num_cite ///
		multi_${`journal'_var}_cite = multi_author ///
		single_${`journal'_var}_cite = single_author, by(author year) fast


	compress
	save "${root}/`field'/temp/author_year_`journal'_citation.dta", replace
end

main
