clear all
set more off

global root "PATH/TO/REPLICATION/"
cd "${root}"
global econ_paper "econ_Paper_Level_clean.dta"

program main
	prep_coauthors, field(econ)
	generate_connections, connection(ECTA) field(econ)
	generate_connections, connection(NAS) field(econ)
	generate_connections, connection(AAAS) field(econ)
	generate_econ_specific, connection(committee)
	local field = "econ"
	use "${root}/`field'/output/position_matched.dta", clear
	drop if author == ""
	merge 1:1 author year using "${root}/`field'/temp/connection_matched_ECTA.dta", nogen keep(1 3)
	merge 1:1 author year using "${root}/`field'/temp/connection_matched_NAS.dta", nogen keep(1 3)
	merge 1:1 author year using "${root}/`field'/temp/connection_matched_AAAS.dta", nogen keep(1 3)
	merge 1:1 author year using "${root}/econ/temp/connection_matched_committee.dta", nogen keep(1 3)
	
	rename (fellow_ECTA new_fellow_ECTA ever_fellow_ECTA year_appointed_ECTA) (fellow new_fellow ever_fellow year_appointed) 
	*the following rename is to match the original databuild
	rename connection_fellowECTA_cumulative connection_fellowEMA_cumulative
	compress
	save "${root}/`field'/output/coauthor_matched.dta", replace
end

program prep_coauthors
	syntax, field(str)
	use doi year author using "${root}/`field'/temp/Author_Paper.dta", clear
	rename doi paper
	format %60s paper
	format %30s author
	bys paper: gen author_id = _n

	reshape wide author, i(paper) j(author_id)

	* capture number of author variables
	gen list_authors = ""
	local complete = 0 
	local i = 1
	while `complete' == 0 {
		capture confirm variable author`=`i'+1'
		if _rc == 0 {
			local i = `i' + 1
		}
		local complete = _rc

	}
	di "`i'"
	forval y = 1/`i' {
		replace list_authors = list_authors + "; " +author`y' if author`y' != ""
	}

	replace list_authors = substr(list_authors, 2, .)

	format %60s list_authors
	order paper list_authors

	* now expand out the list_authors again to get author-paper level
	reshape long author, i(paper)

	drop if missing(author)
	drop _j
	rename list_authors coauthor

	* split the coauthors and expand them out
	split coauthor, parse("; ")
	drop coauthor

	duplicates drop paper author, force
	reshape long coauthor, i(paper author)
	drop if missing(coauthor)
	drop _j

	format %20s coauthor author

	order paper author year coauthor

	drop if author == coauthor
	sort author year
	compress
	save "${root}/`field'/temp/fellow_coauthor_interim.dta", replace
end

program generate_connections
	syntax, connection(str) field(str) 
	 
	use author ever_fellow_`connection' year_appointed_`connection' using ///
		"${root}/econ/output/position_matched.dta" ///
		if ever_fellow_`connection' == 1, clear
		
	if "`connection'" == "AAAS" {
		merge m:1 author using "${root}/econ/output/AAAS_fellows_clean.dta", ///
			keepusing(AAAS_flags) keep(1 3) nogen
		drop if AAAS_flags == 3
		drop AAAS_flags
	}
	else if "`connection'" == "NAS" {
		merge m:1 author using "${root}/econ/output/NAS_fellows_clean.dta", ///
			keepusing(primary_NAS) keep(1 3) nogen
		drop if primary_NAS == 0
		drop primary_NAS
	}
	duplicates drop
	rename author coauthor

	merge 1:m coauthor using "${root}/`field'/temp/fellow_coauthor_interim.dta", nogen
	drop if author == ""
	
	drop if year_appointed_`connection' == .
	sort author coauthor year
	
	by author coauthor (year): keep if _n == 1
	by author coauthor: replace year = max(year, year_appointed_`connection')
	gen nm_connection_fellow`connection' = 1
	collapse (sum) nm_connection_fellow`connection', by(author year)

	* merge this back into fellows_matched_rectangular_citation.dta
	merge 1:1 author year using "${root}/econ/output/position_matched.dta", keep(2 3) nogen keepusing(author year)

	replace nm_connection_fellow`connection' = 0 if nm_connection_fellow`connection' == . & year != .
	bysort author (year): gen connection_fellow`connection'_cumulative = sum(nm_connection_fellow`connection')
	
	drop nm_connection_fellow`connection'
	
	label variable connection_fellow`connection'_cumulative "Cumulative number of `connection' fellows connected"

	keep author year connection
	drop if author == ""
	compress
	save "${root}/`field'/temp/connection_matched_`connection'.dta", replace
end

program generate_econ_specific
	syntax, connection(str)
	local connection = "committee"
	use author `connection' year_appointed_`connection' using ///
		"${root}/econ/output/position_matched.dta" ///
		if `connection' == 1, clear
	
	rename author coauthor 
	* loop through the times that authors are rotated in and out of committee
	bys coauthor: gen count = _n 
	tempfile temp
	save "`temp'"
	sum count
	local N = r(max)
	forval x = 1/`N' {
		use "`temp'" if count == `x'
		merge 1:m coauthor using "${root}/econ/temp/fellow_coauthor_interim.dta", nogen keep(3)
		keep if year_appointed >= year
		
		bys author coauthor (year): keep if _n == 1
		gen nm_connection_`connection' = 1
		collapse (sum) nm_connection_`connection', by(author year_appointed)
		tempfile connect`x'
		save "`connect`x''"
	}
	clear
	forval x = 1/`N' {
		append using "`connect`x''"
	}
	collapse (sum) nm_connection_`connection', by(author year_appointed)
	rename year_appointed year
	* merge this back into fellows_matched_rectangular_citation.dta
	
	merge 1:1 author year using "${root}/econ/output/position_matched.dta", keep(2 3) nogen keepusing(author year)

	replace nm_connection_committee = 0 if nm_connection_committee == . & year != .

	label variable nm_connection_committee "Number of papers published with a committee member this year"
	
	drop if author == ""
	compress
	save "${root}/econ/temp/connection_matched_`connection'.dta", replace
end

main
