
clear all
set more off
set trace off

global root "PATH/TO/REPLICATION/"
cd "${root}"
global econ_paper "econ_Paper_Level_clean.dta"

program main
	foreach field in econ {
		correct_names, field(`field')
		prep_gender, field(`field')
	}
end

program correct_names
	syntax, field(str)
	use "${root}/`field'/output/author_years.dta", clear
	drop if paper == ""
	order paper author_original author year // author-paper level
	format %20s author_original author
	* merge the replacement names
	merge m:1 author using "${root}/`field'/output/replacement_names.dta", nogen keep(1 3) keepusing(replacement)
	replace author = replacement if replacement != ""
	if "`field'" == "econ" {
		* separate the two John Nash
		replace author = "John F. Nash" if doi == "https://www.jstor.org/stable/10.2307/1906951"
		replace author = "John Nash" if author == "John F. Nash" & doi == "https://www.jstor.org/stable/1803317"
	}
	drop author1-first_initial replacement
	
	sort author
	
	replace author = subinstr(author, ";", "", .)
	replace author = itrim(author)
	replace author = strtrim(author)

end

program prep_gender
	syntax, field(str)
	* add spaces after dots if they aren't there already (such as A.Colin Cameron)
	split author, parse(" ")
	local nsplit = r(nvars) 
	forval y = 1/`nsplit' {
		replace author`y' = subinstr(author`y', ".", ". ", .)
		replace author`y' = strrtrim(author`y')
		replace author`y' = author`y' + "." if ustrregexm(author`y', "[A-Z]$") & ustrlen(author`y') == 1
	}
	sort author
	replace author = author1
	forval y = 2/`nsplit' {
		replace author = author + " " + author`y' if !missing(author`y')
	}
	drop author1-author`nsplit' 

	replace author = proper(author)
	* change x. xxx xxx into xxx x. xxx
	split author, parse(" ")
	local nsplit = r(nvars)
	forval y = 1/`nsplit' {
		replace author`y' = author`y' + "." if strlen(author`y') == 1 // add dots to initials if they aren't there already
	}
	gen fi = author1
	replace author1 = author2 if ustrregexm(author1, "^[A-Z]\.")==1 & ustrregexm(author2, "[A-Za-z]\.") == 0 ///
		& lower(author2) != "de" & lower(author2) != "van" & lower(author2) != "von" /// 
		& lower(author2) != "la" & author3 != ""
	replace author2 = fi if fi != author1
	drop fi

	replace author = author1
	forval y = 2/`nsplit' {
		replace author = author + " " + author`y' if !missing(author`y')
	}
	
	* generate first and last names
	sort author
	gen first_name = author1
	gen last_name = ""
	forval y = 1/`nsplit' {
		replace last_name = author`y' if !missing(author`y')
	}
	capture drop authors
	
	gen authors = first_name + " " + last_name
	drop first_name last_name
	
	
	drop if author == ""
	gen first_initial = ustrregexm(author1, "^[A-Z]\.")

	
	* keep track of author order  
	split author_list, parse("; ")

	local auth_num = r(nvars)
	forval y = 1/`auth_num' {
		replace author_list`y' = author_list`y' + ",`y'" if !missing(author_list`y')
	}
	
	* indicator for single author paper 
	gen single_author_paper = 1
	replace single_author_paper = 0 if !missing(author_list2)

	if "`field'" != "econ" {
		gen author_order = ""
		forval y = 1/`auth_num' {
			replace author_order = substr(author_list`y', strpos(author_list`y', ",")+1, .) if author_original == substr(author_list`y', 1, strrpos(author_list`y', ",")-1)
		}

		* indicator for multi author paper 
		gen first_multi_author = (single_author == 0 & author_order == "1")
		destring author_order, replace 
	}
	
	drop author1-author`nsplit' author_list1-author_list`auth_num' 
	compress
	save "${root}/`field'/output/names_tobe_gendered.dta", replace

	* export names to be gendered if file doesn't exist
	capture confirm file  "${root}/`field'/gender/code/names.csv"
	if _rc != 0 {
		keep authors
		export delimited "${root}/`field'/gender/code/names.csv", replace
	}
	
end

main
