
clear all
set more off

global root "PATH/TO/REPLICATION/"
cd "${root}"
global econ_paper "econ_Paper_Level_clean.dta"


global econ_awards AAAS NAS NBER AEA Sloan EMALEC
global psych_awards NAS AAAS
global math_awards NAS AAAS
global econ_journals AER AERPP ECTA ET EcT JE JET JMathE JPE QJE REStud RAND IJGT AEJ_Applied AEJ_Policy AEJ_Micro AEJ_Macro JEP JEL GEB IER REStat ECA EJ JASA JDE JEEA JF JHE JIE JME JOLE JPubE JEH QE TE
global psych_journals JEPG NBR PR PS TiCS PB JPSP ARP PNAS AP CD Cog CP DP
global math_journals AM JAM CM DMJ JASA PNAS IM AIM AS JCP

* ==================================================================================================================================
* match to the rectangularized dataset
program  main
	local field = "econ"
	use "${root}/`field'/output/Author_Year_Level_Rectangular_Gendered.dta", clear
	ECM_fellow
	
	foreach award in $econ_awards {
		merge_award, award(`award') field(econ)
	}
	
	relative_pub, field(econ)
	
	cleanup, field(econ)
	
end
	
program relative_pub
	syntax, field(str)
	* create variable for year since firstpub
	gen pubyear = year*(nm_paper > 0)
	bys author (year): egen first_pubyear = min(pubyear) if pubyear > 0 
	gen first_pub = (year == first_pubyear)
	* fill in missing values now. the sort places nonmissing value first
	bysort author (first_pubyear) : replace first_pubyear = first_pubyear[_n-1] if missing(first_pubyear) 
	sort author year
	gen years_firstpub = year - first_pubyear
	drop first_pubyear
	
	* now since lastpub
	bys author (year): egen last_pubyear = max(pubyear) if pubyear > 0 
	gen last_pub = (year == last_pubyear)
	* fill in missing values now. the sort places nonmissing value first
	bysort author (last_pubyear) : replace last_pubyear = last_pubyear[_n-1] if missing(last_pubyear) 
	sort author year
	gen years_lastpub = year - last_pubyear
	* fix lastpub to 0 for negatives
	replace years_lastpub = 0 if years_lastpub < 0 
	drop last_pubyear pubyear
	

	label variable first_pub "Year of the first publication"
	label variable years_firstpub "Number of years since the first publication"
	
	label variable last_pub "Year of the last publication"
	label variable years_lastpub "Number of years since the last publication"
end

program ECM_fellow
	merge m:1 author using "${root}/econ/output/combined_fellows_clean.dta", keepusing(author_fellow year_appointed female author_nomi)

	* create fellow, new_fellow, and ever_fellow variables
	sort author year
	
	* limit of our data is 2020
	gen fellow = (year >= year_appointed) & year != . & year_appointed < 2020
	gen new_fellow = (year == year_appointed) & year != . & year_appointed < 2020
	gen ever_fellow = (year_appointed != . ) & year != . & year_appointed < 2020
	
	* use ECM file gendering
	replace Female = (female == "1") if female != "" & ever_fellow == 1
	replace Male = (female == "0") if female != "" & ever_fellow == 1
	replace Ambiguous = (Female == 0 & Male == 0)
	
	replace author = author_fellow if author == ""
	
	label variable female "Whether female according to fellows dataset"
	label variable fellow "Whether this person is a fellow at this given year"
	label variable ever_fellow "Whether this person ever became a fellow"


	drop _merge

	rename author_fellow author_fellow_ECTA

	* identify fellows appointed before first publication and add years to panel as
	* necessary. First create a row for the appointment year
	preserve
		bys author (year): egen max = max(new_fellow)
		keep if ever_fellow == 1 & max == 0 
		by author (year): keep if _n == 1
		keep author author_fellow_ECTA year year_appointed fellow new_fellow ///
			ever_fellow author_nomi first_name middle_name last_name Male ///
			Female Ambiguous female
		replace year = year_appointed
		replace new_fellow = 1
		tempfile prepub
		save "`prepub'"
	restore
	* now return to all fellows and append these obs
	preserve
		keep if ever_fellow == 1
		append using "`prepub'"
		
		egen id = group(author)
		order id author
		tsset id year
		tsfill, full
		order author year author_nomi

		* fill in missing years for cumulative ones
		local vars author author_original author_nomi first_name middle_name ///
			last_name Male Female Ambiguous ///
			year_appointed fellow ever_fellow author_fellow_ECTA
		foreach var of varlist `vars' {
			bysort id (year): carryforward `var', gen(`var'_ex)
			drop `var'
			rename `var'_ex `var'
		}
		drop if author == ""
		
		* fill in missing years for non-cumulative ones
		replace new_fellow = 0 if new_fellow == .
		foreach var in nm_paper $econ_journals {
			replace `var' = 0 if `var' == .
			replace `var'_cumulative = 0 if `var'_cumulative == .
			* cap replace for single_journal_cumulative
			cap replace single_`var'_cumulative = 0 if single_`var'_cumulative == .
		}
		drop id
		tempfile fellows
		save "`fellows'"
	restore
	drop if ever_fellow == 1
	append using "`fellows'"
	order author author_fellow year year_appointed fellow new_fellow ever_fellow
	
	* regenerate fellow vars
	replace fellow = (year >= year_appointed) & year != . & year_appointed < 2020
	replace new_fellow = (year == year_appointed) & year != . & year_appointed < 2020
	replace ever_fellow = (year_appointed != . ) & year != . & year_appointed < 2020

	
	compress
	
end

program merge_award	
	syntax, award(str) field(str) 
	
	if "`award'" == "NAS" {
		local gendervar = "female_NAS"
	}
	else if "`award'" == "AAAS" {
		local gendervar = "female_AAAS"
	}
	merge m:1 author using "${root}/`field'/output/`award'_fellows_clean.dta", ///
		keepusing(author_fellow year_appointed_`award' author_nomi `gendervar')
	rename author_fellow author_fellow_`award'
	* create fellow, new_fellow, and ever_fellow variables
	
	gen fellow_`award' = (year >= year_appointed_`award') & year != . & year_appointed_`award' < 2020
	gen new_fellow_`award' = (year == year_appointed_`award') & year != . & year_appointed_`award' < 2020
	gen ever_fellow_`award' = (year_appointed_`award' != . ) & year != . & year_appointed_`award' < 2020

	replace author = author_fellow_`award' if author == ""
	
	label variable fellow_`award' "Whether this person is a(n) `award' fellow at this given year"
	label variable ever_fellow_`award' "Whether this person ever became a(n) `award' fellow"

	drop _merge

	* identify fellows appointed before first publication and add years to panel as
	* necessary. First create a row for the appointment year
	preserve
		bys author (year): egen max = max(new_fellow_`award')
		keep if ever_fellow_`award' == 1 & max == 0 
		by author (year): keep if _n == 1
		keep author author_fellow_`award' year year_appointed_`award' ///
			fellow_`award' ever_fellow_`award' new_fellow_`award' /// 
			author_nomi first_name middle_name last_name Male ///
			Female Ambiguous female
		replace year = year_appointed_`award'
		replace new_fellow_`award' = 1
		tempfile prepub
		save "`prepub'"
	restore
	* now return to all fellows and append these obs
	preserve
		keep if ever_fellow_`award' == 1
		append using "`prepub'"
		
		egen id = group(author)
		order id author
		tsset id year
		tsfill, full
		order author year author_nomi

		* fill in missing years for cumulative ones
		local vars author author_original author_nomi first_name middle_name ///
			last_name Male Female Ambiguous ///
			year_appointed_`award' fellow_`award' ///
			ever_fellow_`award' author_fellow_`award'
		foreach var of varlist `vars' {
			bysort id (year): carryforward `var', gen(`var'_ex)
			drop `var'
			rename `var'_ex `var'
		}
		drop if author == ""
		
		* fill in missing years for non-cumulative ones
		foreach var in nm_paper $econ_journals {
			replace `var' = 0 if `var' == .
			replace `var'_cumulative = 0 if `var'_cumulative == .
			* cap replace for single_journal_cumulative
			cap replace single_`var'_cumulative = 0 if single_`var'_cumulative == .
		}
		drop id
		tempfile fellows
		save "`fellows'"
	restore
	drop if ever_fellow_`award' == 1
	append using "`fellows'"
	
	replace fellow_`award' = (year >= year_appointed_`award') & year != . & year_appointed_`award' < 2020
	replace new_fellow_`award' = (year == year_appointed_`award') & year != . & year_appointed_`award' < 2020
	replace ever_fellow_`award' = (year_appointed_`award' != . ) & year != . & year_appointed_`award' < 2020

	
	order author author_fellow_`award' year year_appointed_`award' ///
		fellow_`award' new_fellow_`award' ever_fellow_`award' 
	
end

program cleanup
	syntax, field(str)
	* append the unmatched fellows back in prep_regression
	preserve
		keep if year == .
		keep author year_app* author_fellow* female female_AAAS female_NAS
		
		* fill in genders where appropriate for unmatched
		gen Female = (female == "1") if female != ""
		gen Male = (female == "0") if female != "" 
		replace Female = (female_AAAS == 1) if female_AAAS != .
		replace Male = (female_AAAS == 0) if female_AAAS != .
		replace Female = (female_NAS == 1) if female_NAS != .
		replace Male = (female_NAS == 0) if female_NAS != .
		
		gen Ambiguous = (Female == 0 & Male == 0)
		
		if "`field'" == "econ" {
			gen ever_fellow = (year_appointed != .)
		}	
		local loopawards = "`field'_awards"
		foreach award in $`loopawards' {
			gen ever_fellow_`award' = (year_appointed_`award' != .)
		}
		
		order author author_fellow_ECTA year_appointed author_fellow_AAAS ///
				year_appointed_AAAS author_fellow_NAS year_appointed_NAS ///
				author_fellow_NBER year_appointed_NBER author_fellow_AEA ///
				year_appointed_AEA author_fellow_Sloan year_appointed_Sloan ///
				author_fellow_EMALEC year_appointed_EMALEC
		sort author_fellow_ECTA author_fellow_AAAS author_fellow_NAS ///
			author_fellow_NBER author_fellow_AEA  author_fellow_Sloan ///
			author_fellow_EMALEC
		save "${root}/`field'/temp/fellows_unmatched.dta", replace
	restore
	keep if year != .
	sort last_name first_name middle_name year
	
	if "`field'" == "econ" {
		order author year nm_paper_cumulative author_fellow_ECTA year_appointed author_fellow_AAAS year_appointed_AAAS ///
			author_fellow_NAS year_appointed_NAS author_fellow_NBER year_appointed_NBER author_fellow_Sloan year_appointed_Sloan ///
			author_fellow_AEA year_appointed_AEA author_fellow_EMALEC year_appointed_EMALEC
		* replace if missings were generated as we added prior years to panel
		replace new_fellow = 0 if new_fellow == . & nm_paper == 0
		replace fellow = 0 if fellow == . & nm_paper == 0
		drop ever_fellow
		bysort author (year_appointed) : replace year_appointed = year_appointed[_n-1] if missing(year_appointed) 
	
		bys author: egen ever_fellow = max(fellow)
		foreach type in $econ_awards  {
			replace new_fellow_`type' = 0 if new_fellow_`type' == . & nm_paper == 0
			replace fellow_`type' = 0 if fellow_`type' == . & nm_paper == 0
			drop ever_fellow_`type'
			bys author: egen ever_fellow_`type' = max(fellow_`type')
			bysort author (year_appointed_`type') : replace year_appointed_`type' = year_appointed_`type'[_n-1] if missing(year_appointed_`type') 
	
		}
	}
	else {
		order author year nm_paper_cumulative author_fellow_AAAS year_appointed_AAAS ///
			author_fellow_NAS year_appointed_NAS 
	}
	
	sort author year
	rename (fellow new_fellow ever_fellow year_appointed) (fellow_ECTA new_fellow_ECTA ever_fellow_ECTA year_appointed_ECTA)
	compress
	save "${root}/`field'/output/fellows_matched_rectangular.dta", replace

end

main
