

clear all
set trace off
set more off

cd "C:/Users/Chris/Dropbox/ECM_Fellow_Study/Paper2/source/compile_author"

global root "PATH/TO/REPLICATION/"
cd "${root}"
global econ_paper "econ_Paper_Level_clean.dta"

* run clean_special_character.do before this

program main
	local field = "econ"
	use "${`field'_paper}", clear
	**do some cleaning and create list of unique names
	parse_authors, field(`field')
	local nsplit = r(nsplit)
	assign_names, nsplit(`nsplit') field(`field')

	use "${root}/`field'/temp/unique_author.dta", clear // all authors
	merge 1:1 author using "${root}/`field'/output/replacement_names.dta", keep(1 3) keepusing(replacement) // all authors, some replaced some not
	
	gen norec = (_m == 3 & replacement == "") //name matched and not replaced
	drop _m
	** reminder that replacement and bestmatch are disjoint
	** replace replacement = bestmatch if !missing(bestmatch)
	
	sort last_name first_name replacement norec
	
	keep year author first_name last_name replacement norec
	format %20s author first_name last_name replacement
	
	replace norec = 1 if replacement == author
	
	save "${root}/`field'/output/name_dictionary.dta", replace
	
	drop if missing(replacement) & norec == 0 // drop either no replacement or the same replacement. keep those that have a valid replacement
	
	save "${root}/`field'/output/replacement_only.dta", replace
end



program parse_authors, rclass
	syntax, field(str)
	format %20s author title 
	
	drop if missing(author)
	
	replace author = proper(author) // first letter capitalized
	* standardize semicolon separators as necessary
	replace author = subinstr(author, ";", "; ", .)
	replace author = itrim(author)
	
	split author, parse("; ")
	local nsplit = r(nvars) 
	rename author author_list
	sort doi
	duplicates drop doi, force
	
	*split the reshape into 2 steps to minimize runtime
	*by splitting at "; " with asymmetric missings, we are creating an (n x k) 
	*matrix with mostly missing cells.
	preserve
		* first, 1-2 author papers
		keep if author3 == ""
		drop author3-author`nsplit'
		reshape long author, i(doi) // author-paper level
		tempfile long12
		save "`long12'"
	restore
	
	keep if author3 != ""
	preserve
		* next, at least 3 authors up to 9
		keep if author10 == ""
		drop author10-author`nsplit'
		reshape long author, i(doi) // author-paper level
		tempfile long36
		save "`long36'"
	restore
	keep if author10 != ""
	reshape long author, i(doi) // author-paper level
	append using `long12'
	append using `long36'
	drop if missing(author)	
	drop _j
	
	rename doi paper 
	drop if paper == ""
	* keep track of original name
	gen author_original = author
	
	* merge in hand-fixes
	if "`field'" == "econ" {
		replace author = "Xavier D'Haultfoeuille" if paper == "https://doi.org/10.1093/restud/rdx049" & strpos(author, "X")
	
		merge m:1 year paper author using "${root}/econ/temp/years_firstpub_check_g20.dta", keep(1 3)
		replace author = correct_author if _merge == 3 
		drop _merge correct_author

		merge m:1 year paper author using "${root}/econ/temp/years_firstpub_check_g60.dta", keep(1 3)
		replace author = correct_author if _merge == 3 
		drop _merge correct_author

		merge m:1 year paper author using "${root}/econ/temp/years_firstpub_check_g50.dta", keep(1 3)
		replace author = correct_author if _merge == 3 
		drop _merge correct_author check_comments
		rename paper doi
		
		merge m:1 author using "${root}/econ/input/hand_fixed_names.dta", keep(1 3) keepusing(suggested_name)
		replace author = suggested_name if _m == 3
		drop _m suggested_name
		
		* merge with check for authors with >20/50/60 year sequential publication gap
		merge m:1 author_original using "${root}/econ/input/urap_name_edit.dta", keep(1 3) keepusing(fellow_name)
		replace author = fellow_name if _m == 3
		drop _m fellow_name
		
		foreach filetype in chair member AEA aea_president aea_vp asso_editor ///
			editor election EMALEC fellows NBER nominee Sloan vote {
				append using "${root}/econ/temp/`filetype'_names.dta"
			}
		* once we have generated these for AAAS and NAS, take these out of this econ block
		append using "${root}/econ/temp/NAS_names.dta"
		append using "${root}/econ/temp/AAAS_names.dta"
	}
	
	drop if author == ""
	replace author = subinstr(author, ".", ". ", .)
	* order matters in the following lines. itrim and strtrim only clean consecutive spaces
	replace author = subinstr(author, char(10), "", .)
	replace author = itrim(author)
	replace author = strtrim(author)
	
	split author, parse(" ")
	local nsplit = r(nvars) 
	
	replace author1 = author1 + "." if strlen(author1) == 1 // Add . to first initials 
	replace author1 = subinstr(author1, ".", "", .) if strlen(author1) >= 4 // remove . if at least 4 characters long
	
	forval y = 1/`nsplit' {
		replace author`y' = subinstr(author`y', ".", ". ", .)
		replace author`y' = strrtrim(author`y')
		replace author`y' = author`y' + "." if ustrregexm(author`y', "[A-Z]$") & ustrlen(author`y') == 1 // add . to initials
		replace author`y' = subinstr(author`y', ".", "", .) if strlen(author`y') >= 4  // remove . if at least 4 characters long
	}
	
	* replace author name with cleaned name
	sort author
	replace author = author1 
	forval y = 2/`nsplit' {
		replace author = author + " " + author`y' if !missing(author`y')
	}
	
	**split again having cleaned up author
	drop author1-author`nsplit'
	
	replace author = itrim(author)
	
	replace author = proper(author) // after special character replacement
	
	split author, parse(" ")
	local nsplit = r(nvars) 
	
	gen first_name = ""
	replace first_name = author1
	gen last_name = ""
	
	forval y = 1/`nsplit' {
		replace last_name = author`y' if !missing(author`y') //last non-missing entry
	}
	
	gen first_initial = (strlen(author1) == 2 & strpos(author1, ".")) | (strlen(author1) == 1)
	save "${root}/`field'/output/author_years.dta", replace
	
	* do a collapse to make sure years are properly preserved
	collapse (mean) year (first) author1-first_initial, by(author)
	save "${root}/`field'/temp/unique_author.dta", replace
	return scalar nsplit = `nsplit'
end

program assign_names
	syntax, nsplit(int) field(str)
	use "${root}/`field'/temp/unique_author.dta", clear
	* start with names with full first and some middle only
	keep if (wordcount(author) > 3)

	* For 4+ initials, we must be very strict. if they have the same 4+ letter initial
	* we can be very sure that they are the same person. We do not many any attempt beyond 
	* disambiguate e.g. A B C D Smith vs. A B C Smith

	gen initials = substr(author1, 1, 1)
	forval x = 2/`nsplit' {
		replace initials = initials + substr(author`x', 1, 1) if !missing(author`x')
	}
	* add last name to initials
	replace initials = initials + last_name

	bys initials: gen count = _n
	bys initials: egen candidates = max(count)
	keep if candidates > 1

	bys initials: egen longname = max(strlen(author))
	gen replacement = author if longname == strlen(author)
	* this sort makes sure the replacements are carried down properly
	gsort initials -replacement
	bys initials: replace replacement = replacement[_n-1] if missing(replacement)

	keep author replacement

	tempfile longnames
	save "`longnames'"
	
	use "${root}/`field'/temp/unique_author.dta", clear
	keep year author-first_initial
	* start with names with full first and some middle only
	keep if (wordcount(author) == 3) & first_initial != 1
	* first middle last 
	gen longfirst = first_name + substr(author2, 1, 1) + last_name

	* check existence of middle initial within group (and in need in replacement)
	gen middle_initial = (strlen(author2) == 2 & strpos(author2, ".")) | (strlen(author2) == 1)
	bys longfirst: egen middle_exist = max(middle_initial)

	* check if replacement candidate exists
	bys longfirst: gen count = _n
	by longfirst: egen num_candidate = max(count)

	* now, keep if there is a middle initial to replace and (exactly one) candidate to make the replacement
	keep if num_candidate == 2 & middle_exist == 1

	bys longfirst: egen longname = max(strlen(author))
	gen replacement = author if longname == strlen(author)
	bys longfirst: replace replacement = replacement[_n-1] if missing(replacement)
	bys longfirst: replace replacement = replacement[_n+1] if missing(replacement)

	keep author replacement
	append using "`longnames'"

	save "${root}/`field'/temp/middle_match.dta", replace


	* from here on, we work on the variable "name" 
	* "author" will be used to merge back to the original dataset
	* update our names with update
	use author year first_name last_name first_initial using "${root}/`field'/temp/unique_author.dta", clear
	merge 1:1 author using "${root}/`field'/temp/middle_match.dta", nogen
	gen name = replacement
	replace name = author if missing(name)

	drop replacement

	* resplit names
	split name, parse(" ")

	* now names with first initial and full middle only
	
	gen middle_initial = (strlen(name2) == 2 & strpos(name2, ".")) | (strlen(name2) == 1)
	keep if (wordcount(name) == 3) & middle_initial != 1

	gen longmiddle = substr(first_name, 1, 1) + name2 + last_name

	* check existence of first initial within group (and in need in replacement)
	bys longmiddle: egen first_exist = max(first_initial)

	* check if replacement candidate exists. 
	* since we have made replacements, the same name can occur multiple times
	bys longmiddle name: gen unique = _n
	by longmiddle: egen num_candidate = total(unique==1) 

	* now, keep if there is a first initial to replace and (exactly one) candidate to make the replacement
	keep if num_candidate == 2 & first_exist == 1

	bys longmiddle: egen longname = max(strlen(name))
	gen replacement = name if longname == strlen(name)
	bys longmiddle: replace replacement = replacement[_n-1] if missing(replacement)
	bys longmiddle: replace replacement = replacement[_n+1] if missing(replacement)

	keep author replacement
	save "${root}/`field'/temp/first_match.dta", replace


	* match first and middle initials
	* update names
	use author year last_name using "${root}/`field'/temp/unique_author.dta", clear

	merge 1:1 author using "${root}/`field'/temp/first_match.dta", nogen
	rename replacement priority1
	merge 1:1 author using "${root}/`field'/temp/middle_match.dta", nogen
	rename replacement priority2
	* mind the order
	gen name = priority1 
	replace name = priority2 if !missing(priority2) & missing(name)
	replace name = author if missing(name)

	drop priority1 priority2

	split name, parse(" ")

	* names with both first and middle initial
	gen first_initial = (strlen(name1) == 2 & strpos(name1, ".")) | (strlen(name1) == 1)
	gen middle_initial = (strlen(name2) == 2 & strpos(name2, ".")) | (strlen(name2) == 1)

	keep if (wordcount(name) == 3) 

	* check for name groups (e.g. AAAlchian) with a name that is first and middle initial
	gen onlylast = substr(name1, 1, 1) + substr(name2, 1, 1) + last_name
	bys onlylast: egen has_first = max(first_initial)
	bys onlylast: egen has_middle = max(middle_initial)


	* check if replacement candidate exists. 
	* since we have made replacements, the same name can occur multiple times
	bys onlylast name: gen unique = _n
	by onlylast: egen num_candidate = total(unique==1) 

	keep if has_first == 1 & has_middle == 1 & num_candidate == 2

	bys onlylast: egen longname = max(strlen(name))
	gen replacement = name if longname == strlen(name)
	bys onlylast: replace replacement = replacement[_n-1] if missing(replacement)
	bys onlylast: replace replacement = replacement[_n+1] if missing(replacement)

	keep author replacement
	save "${root}/`field'/temp/first_middle_match.dta", replace


	* From here, we start to compare names that are just first and last against bigger names. 
	* start with names that are not first initial. We should now also be concerned about 
	* year ranges since there is more ambiguity about who this person could be.

	* update names
	use author year last_name using "${root}/`field'/temp/unique_author.dta", clear
	merge 1:1 author using "${root}/`field'/temp/first_middle_match.dta", nogen
	rename replacement priority1
	merge 1:1 author using "${root}/`field'/temp/first_match.dta", nogen
	rename replacement priority2
	merge 1:1 author using "${root}/`field'/temp/middle_match.dta", nogen
	rename replacement priority3
	gen name = priority1
	replace name = priority2 if !missing(priority2) & missing(name)
	replace name = priority3 if !missing(priority3) & missing(name)
	replace name = author if missing(name)

	drop priority1 priority2

	split name, parse(" ")
	* drop names of the form A. Alchien
	gen first_initial = (strlen(name1) == 2 & strpos(name1, ".")) | (strlen(name1) == 1)
	drop if first_initial & (wordcount(name) == 2) 

	gen firstlast = name1 + last_name

	* check if replacement candidate exists. 

	* since we have made replacements, the same name can occur multiple times
	bys firstlast name: gen unique = _n
	by firstlast: egen num_candidate = total(unique==1) 

	gen short_name = (wordcount(name) == 2) 
	by firstlast: egen has_only_first = max(short_name)

	* since names are now more ambiguous, restrict year range of possible replacement
	by firstlast: egen max_year = max(year)
	by firstlast: egen min_year = min(year)
	gen year_range = max_year - min_year

	keep if num_candidate == 2 & has_only_first == 1 & year_range <= 40

	bys firstlast: egen longname = max(strlen(name))
	gen replacement = name if longname == strlen(name)
	bys firstlast: replace replacement = replacement[_n-1] if missing(replacement)
	bys firstlast: replace replacement = replacement[_n+1] if missing(replacement)


	keep author replacement
	save "${root}/`field'/temp/firstlast_match.dta", replace

	* finally, try to match names that are only first initial and a last name
	* update names
	use author year last_name using "${root}/`field'/temp/unique_author.dta", clear
	merge 1:1 author using "${root}/`field'/temp/firstlast_match.dta", nogen
	rename replacement priority1
	merge 1:1 author using "${root}/`field'/temp/first_middle_match.dta", nogen
	rename replacement priority2
	merge 1:1 author using "${root}/`field'/temp/first_match.dta", nogen
	rename replacement priority3
	merge 1:1 author using "${root}/`field'/temp/middle_match.dta", nogen
	rename replacement priority4

	gen name = priority1
	replace name = priority2 if !missing(priority2) & missing(name)
	replace name = priority3 if !missing(priority3) & missing(name)
	replace name = priority4 if !missing(priority4) & missing(name)

	replace name = author if missing(name)

	drop priority1 priority2 priority3 priority4

	split name, parse(" ")
	gen first_initial_last_name = ((strlen(name1) == 2 & strpos(name1, ".")) | (strlen(name1) == 1)) & (wordcount(name) == 2) 

	gen firstletter_last = substr(name1, 1, 1) + last_name
	bys firstletter_last: egen has_firstletter_last = max(first_initial_last_name)

	* since we have made replacements, the same name can occur multiple times
	bys firstletter_last name: gen unique = _n
	by firstletter_last: egen num_candidate = total(unique==1) 

	* since names are now more ambiguous, restrict year range of possible replacement
	by firstletter: egen max_year = max(year)
	by firstletter: egen min_year = min(year)
	gen year_range = max_year - min_year

	keep if has_firstletter_last & num_candidate == 2 & year_range <= 40

	bys firstletter: egen longname = max(strlen(name)) 
	gen replacement = name if longname == strlen(name)
	bys firstletter: replace replacement = replacement[_n-1] if missing(replacement)
	bys firstletter: replace replacement = replacement[_n+1] if missing(replacement)

	keep author replacement
	save "${root}/`field'/temp/firstinitial_last_match.dta", replace

	use author year last_name using "${root}/`field'/temp/unique_author.dta", clear
	merge 1:1 author using "${root}/`field'/temp/firstinitial_last_match.dta", nogen
	rename replacement priority1
	merge 1:1 author using "${root}/`field'/temp/firstlast_match.dta", nogen
	rename replacement priority2
	merge 1:1 author using "${root}/`field'/temp/first_middle_match.dta", nogen
	rename replacement priority3
	merge 1:1 author using "${root}/`field'/temp/first_match.dta", nogen
	rename replacement priority4
	merge 1:1 author using "${root}/`field'/temp/middle_match.dta", nogen
	rename replacement priority5

	gen name = priority1 
	replace name = priority2 if !missing(priority2) & missing(name)
	replace name = priority3 if !missing(priority3) & missing(name)
	replace name = priority4 if !missing(priority4) & missing(name)
	replace name = priority5 if !missing(priority5) & missing(name)

	replace name = author if missing(name)
	keep if author != name
	rename name replacement


	keep author replacement

	
	save "${root}/`field'/output/replacement_names.dta", replace


end


main

