

clear all
set more off
set trace off

global econ_awards AAAS NBER NAS Sloan AEA EMALEC

* ==================================================================================================================================
* match to the rectangularized dataset
global root "PATH/TO/REPLICATION/"
cd "${root}"
global econ_paper "econ_Paper_Level_clean.dta"

use "${root}/econ/output/fellows_matched_rectangular_citation.dta", clear

* merge the editors
merge 1:1 author year using "${root}/econ/temp/editor.dta", keep(1 3)
gen editor = (_m == 3)
drop _merge

replace editor = . if year == .

* merge the co-editors
merge 1:1 author year using "${root}/econ/temp/coeditor.dta", keep(1 3)
gen coeditor = (_m == 3)
drop _merge

replace coeditor = . if year == .

* merge the associate editors
merge 1:1 author year using "${root}/econ/temp/asso_editor.dta", keep(1 3)
gen asso_editor = (_m == 3)
drop _merge

replace asso_editor = . if year == .

sort author year

compress

* merge past AEA presidents/VP
* these work a bit different from the above
merge m:1 author year using "${root}/econ/temp/aea_president_clean.dta", keep(1 3) 
gen new_AEAP = (_m == 3)
drop _m
bys author: egen year_appointed_AEAP = min(year) if new_AEAP == 1
bysort author (year_appointed_AEAP) : replace year_appointed_AEAP = year_appointed_AEAP[_n-1] if missing(year_appointed_AEAP) 

gen AEAP = (year >= year_appointed_AEAP) 
by author: egen ever_AEAP = max(AEAP) 
* these have AEA presidency prior to our publications data
replace ever_AEAP = 1 if author == "Richard T. Ely"
replace AEAP = 1 if author == "Richard T. Ely"
replace year_appointed_AEAP = 1900 if author == "Richard T. Ely"

replace ever_AEAP = 1 if author == "Henry Walcott Farnam"
replace AEAP = 1 if author == "Henry Walcott Farnam"
replace year_appointed_AEAP = 1911 if author == "Henry Walcott Farnam"

replace ever_AEAP = 1 if author == "Francis A. Walker"
replace AEAP = 1 if author == "Francis A. Walker"
replace year_appointed_AEAP = 1886 if author == "Francis A. Walker"

label variable ever_AEAP "Whether this person is elected to become AEA President"
label variable AEAP "Whether this person is AEA President at this given year"

* fill in panel for presidents prior to pub and add to panel
preserve
	bys author (year): egen max = max(new_AEAP)
	keep if ever_AEAP == 1 & max == 0 
	by author (year): keep if _n == 1
	keep author year year_appointed_AEAP ever_AEAP AEAP new_AEAP ///
		author_nomi first_name middle_name last_name ///
		Male Female Ambiguous female
	
	replace year = year_appointed_AEAP
	replace new_AEAP = 1
	tempfile prepub
	save "`prepub'"
restore
* now return to all fellows and append these obs
preserve
	keep if ever_AEAP == 1
	append using "`prepub'"
	
	egen id = group(author)
	order id author
	tsset id year
	tsfill, full
	order author year 

	* fill in missing years for cumulative ones
	local vars author author_original author_nomi first_name middle_name ///
		last_name Male Female Ambiguous ///
		year_appointed_AEAP AEAP ever_AEAP 
	foreach var of varlist `vars' {
		bysort id (year): carryforward `var', gen(`var'_ex)
		drop `var'
		rename `var'_ex `var'
	}
	drop if author == ""
	* reorder some string vars
	order author year female
	* fill in missing years for non-cumulative ones
	foreach var of varlist nm_paper nm_paper_cumulative fellow_EMALEC-new_AEAP {
		replace `var' = 0 if `var' == .
	}
	drop id
	tempfile fellows
	save "`fellows'"
restore
drop if ever_AEAP == 1
append using "`fellows'"

replace AEAP = (year >= year_appointed_AEAP) & year != . & year_appointed_AEAP < 2020
replace new_AEAP = (year == year_appointed_AEAP) & year != . & year_appointed_AEAP < 2020
replace ever_AEAP = (year_appointed_AEAP != . ) & year != . & year_appointed_AEAP < 2020

* mismatch for President Allyn A. Young
replace Male = 1 if author == "Allyn A. Young"
replace Female = 0 if author == "Allyn A. Young"
replace Ambiguous = 0 if author == "Allyn A. Young"


compress

* merge past AEA vice presidents

* fully matched, including middle names
merge 1:1 author year using "${root}/econ/temp/aea_vp_clean.dta", keep(1 3)
gen new_AEAVP = (_m == 3)
drop _m
bys author: egen year_appointed_AEAVP = min(year) if new_AEAVP == 1
bysort author (year_appointed_AEAVP) : replace year_appointed_AEAVP = year_appointed_AEAVP[_n-1] if missing(year_appointed_AEAVP) 

gen AEAVP = (year >= year_appointed_AEAVP) 
by author: egen ever_AEAVP = max(AEAVP) 


label variable ever_AEAVP "Whether this person is elected to become AEA Vice President"
label variable AEAVP "Whether this person is AEA Vice President at this given year"

*drop no _merge
sort last_name first_name middle_name year


*** merge with the master dataset
* ==============================================================================================================================================
* merge the committee members
merge 1:1 author year using "${root}/econ/output/committee_members_clean.dta", keep(1 3)

gen committee = (_m == 3)
drop _m
bys author (year): gen new_committee = (committee == 1 & committee[_n-1] == 0)
by author: egen ever_committee = max(committee)
gen year_appointed_committee = year if committee == 1

* outside of range
replace ever_committee = 1 if author == "Leonid V. Kantorovich"


* merge the chair
merge 1:1 author year using "${root}/econ/output/committee_chair_clean.dta", keep(1 3) 

gen chair = (_m == 3)
drop _m
bys author (year): gen new_chair = (chair == 1 & chair[_n-1] == 0)
by author: egen ever_chair = max(chair)
gen year_appointed_chair = year if chair == 1


sort last_name first_name middle_name year

* ==============================================================================================================================================
merge m:1 author year using "${root}/../DATA_Nominees/ResearchFilesXlsx/combinedSummary.dta", keep(1 3)

gen nominee = (_m == 3)

bys author: egen ever_nominee = max(nominee)


* create nominee, new_nominee, and ever_nominee variables
gen new_nominee = nominee
replace new_nominee = 1 if new_nominee[_n-1] == 1 & author == author[_n-1]
gsort +last_name +first_name +middle_name -year
replace new_nominee = 0 if new_nominee[_n+1] == 1 & author == author[_n+1]
gsort +last_name +first_name +middle_name +year

* two special cases (nominated before first publication)
replace ever_nominee = 1 if author == "Vadim I. Arkin"
replace ever_nominee = 1 if author == "Igor V. Evstigneev"


rename byCommitty byCommittee 


* merge in the committee information 
tempfile temp
save "`temp'"

import excel "${root}/../DATA_Nominees/NominatingCommittee_Members/Nominating_Committee_Members.xlsx", sheet("Hoja1") firstrow clear

drop if year == . 
gen committee_share_female = total_females/total 
drop members chair  total_females total

merge 1:m year using "`temp'", keep(2 3) nogen
label var committee_share_female "Share female in the nominating committee"

sort last_name first_name middle_name year

* clean up the cases where citation > 0 but paper_cumulative = 0 
replace AER_cite = 0 if AER_cumulative == 0 
replace AER_cite_cumulative = 0 if AER_cumulative == 0

replace ECTA_cite = 0 if ECTA_cumulative == 0 
replace ECTA_cite_cumulative = 0 if ECTA_cumulative == 0

replace QJE_cite = 0 if QJE_cumulative == 0 
replace QJE_cite_cumulative = 0 if QJE_cumulative == 0

replace JPE_cite = 0 if JPE_cumulative == 0 
replace JPE_cite_cumulative = 0 if JPE_cumulative == 0

replace REStud_cite = 0 if REStud_cumulative == 0 
replace REStud_cite_cumulative = 0 if REStud_cumulative == 0

compress
save "${root}/econ/output/position_matched.dta", replace

