clear all
set more off
global root "PATH/TO/REPLICATION/"
cd "${root}"
global econ_paper "econ_Paper_Level_clean.dta"

local field = "econ"
use "${root}/`field'/output/coauthor_matched.dta"

* append back those who are not matched. This file comes from match_fellow.do
append using "${root}/`field'/temp/fellows_unmatched.dta"

* merge back flags
merge m:1 author using "${root}/econ/output/AAAS_fellows_clean.dta", ///
	keepusing(AAAS_flags) keep(1 3) nogen
	
merge m:1 author using "${root}/econ/output/NAS_fellows_clean.dta", ///
	keepusing(primary_NAS) keep(1 3) nogen
drop _m

rename (editor coeditor asso_editor) (editorEMA coeditorEMA asso_editorEMA)

drop if years_lastpub > 18 & fellow_EMA != . & year !=.

gen author_shortmiddle = first_name + " " + substr(middle_name, 1, 1) + ". " + last_name if middle_name != ""
replace author_shortmiddle = first_name + " " + last_name if author_shortmiddle == ""


*** flag those with JASA >= 8 and econ publications <= 2
gen flag = .
gen econ_pub_cumulative = nm_paper_cumulative - JASA_cumulative
by author, sort: egen econ_pub_max = max(econ_pub_cumulative)
by author, sort: egen jasa_max = max(JASA_cumulative)
replace flag = 1 if jasa_max >= 8 & econ_pub_max <= 2
replace flag = 0 if flag != 1 & author != ""
drop econ_pub_max jasa_max
drop flag
label variable econ_pub_cumulative "Total Economic Journal Publications"

* generate a leveled variable for the first letter of last names 
gen lastname_firstletter = substr(last_name, 1, 1)

gen first5_alphabet = 1 if lastname_firstletter == "A" | lastname_firstletter == "B" | lastname_firstletter == "C" | lastname_firstletter == "D" | lastname_firstletter == "E"
replace first5_alphabet = 0 if first5_alphabet != 1

* generate an indicator variable for whether your last name is from "F" to "M"
gen F_M_alphabet = 1 if lastname_firstletter == "F" | lastname_firstletter == "G" | lastname_firstletter == "H" | lastname_firstletter == "I" | lastname_firstletter == "J" |lastname_firstletter == "K"|lastname_firstletter == "L" |lastname_firstletter == "M"
replace F_M_alphabet = 0 if F_M_alphabet != 1

* generate an indicator variable for whether your last name is from "N" to "Z"
gen N_Z_alphabet = 1 if first5_alphabet == 0 & F_M_alphabet == 0 
replace N_Z_alphabet = 0 if N_Z_alphabet != 1

local i = 1
local letters = c(ALPHA)
foreach letter in `letters' {
	replace lastname_firstletter = "`i'" if lastname_firstletter == "`letter'"
	local i = `i' + 1
}

replace lastname_firstletter = "8" if author == "Brian A. 'Hearn"
replace lastname_firstletter = "8" if author == "Steffen Huck (Ucl)"
replace lastname_firstletter = "2" if author == "Moshe Bar Niv (Burnovski)"
replace lastname_firstletter = "7" if author == "A. L. Gaathon (Gruenbaum)"
replace lastname_firstletter = "13" if author == "Maitreyi Chaudhuri (Mukherjee)"
destring lastname_firstletter, replace 


* merge in death info 
preserve 
	import excel using "${root}/econ/input/raw/authors_firstpub_gt75_2019.xlsx", first clear
	drop A investigation year

	append using "${root}/econ/input/raw/new_yod_parse_wikidata_cleaned.dta"

	bysort author: gen dup = _n
	drop if dup > 1 
	drop dup 

	replace gender = "male" if author == "Vela K. Velupillai"
	drop if author == "James M. Snyder"
	replace death = 2013 if author == "Jacob L. Mosak"

	merge m:1 author using "${root}/econ/input/hand_fixed_names.dta", keep(1 3) keepusing(suggested_name)
	replace author = suggested_name if _m == 3
	drop _m suggested_name
	
	merge m:1 author using "${root}/econ/output/replacement_names.dta", nogen keep(1 3) keepusing(replacement)
	replace author = replacement if replacement != ""
	drop replacement
	duplicates drop
	* fill in vars within author
	gsort author -gender
	collapse (first) death gender wiki, by(author)
	
	compress 
	save "${root}/econ/output/author_death_wikipedia.dta", replace 
restore 

merge m:1 author using  "${root}/econ/output/author_death_wikipedia.dta", update replace keep(1 3) nogen
gen dead = 1 if (death < year & !missing(death))
replace death = . if nm_paper>=1 & dead==1 & year>death+10 & author != "Joseph A. Schumpeter" & author != "Thomas Robert Malthus" & author != "Leon Walras"
replace dead = 0 if missing(death) & dead == 1 

replace Female = 1 if gender == "female"
replace Ambiguous = 0 if gender == "female"
replace Male = 0 if gender == "female"

replace Female = 0 if gender == "male"
replace Ambiguous = 0 if gender == "male"
replace Male = 1 if gender == "male"

* merge in final hand-fixed genders
merge m:1 author using "${root}/econ/input/gender_fixes.dta", keep(1 3) nogen
replace Female = old_Female if old_Female != .
replace Male = old_Male if old_Male != .
replace Ambiguous = (Female == 0 & Male == 0)

rename year_appointed year_appointed_EMA 
rename fellow fellow_EMA
rename new_fellow new_fellow_EMA
rename ever_fellow ever_fellow_EMA

rename fellow_AEA fellow_AEAF
rename new_fellow_AEA new_fellow_AEAF
rename ever_fellow_AEA ever_fellow_AEAF 
rename year_appointed_AEA year_appointed_AEAF

drop gender

local varlist EMA AEAF AAAS NAS Sloan NBER EMALEC
foreach var in `varlist' {
	replace fellow_`var' = . if year == .
	replace new_fellow_`var' = . if year == .
}



* merge in additional death check info 
preserve
	import delimited "${root}/econ/input/raw/pred_fellow_death_check_dc.csv", clear
	keep ïauthor comments 
	rename ïauthor author
	replace author = "Kajal Lahiri" if author == "Kajal Lahiri (MALE!)"
	replace author = "Graham Elliott" if author == "Graham A. Elliott"
	drop if author == "Caroline Minter Hoxby"
	
	merge m:1 author using "${root}/econ/input/hand_fixed_names.dta", keep(1 3) keepusing(suggested_name)
	replace author = suggested_name if _m == 3
	drop _m suggested_name
	
	merge m:1 author using "${root}/econ/output/replacement_names.dta", nogen keep(1 3) keepusing(replacement)
	replace author = replacement if replacement != ""
	drop replacement

	gen death_check = ustrregexs(0) if ustrregexm(comments,"[0-9,][0-9,][0-9,][0-9,]+")
	destring death_check, replace 
	drop comments
	
	tempfile temp
	save "`temp'"
restore
merge m:1 author using "`temp'", keep(1 3) nogen 
replace death = death_check if !missing(death_check)
drop death_check
sort last_name first_name middle_name year

replace dead = 1 if death < year & !missing(death)
replace dead = 0 if death >= year & !missing(death)
order death dead wiki_page, after(Ambiguous)


* gen regression variables 
gen asinhREScites=asinh(REStud_cite_cumulative)
gen asinhEMAcites=asinh(ECTA_cite_cumulative)
gen asinhQJEcites=asinh(QJE_cite_cumulative)
gen asinhAERcites=asinh(AER_cite_cumulative)
gen asinhJPEcites=asinh(JPE_cite_cumulative)

* gen string variable for loc/regionID
gen location = ""
replace location = "Europe" if regionID == 7 | loc == 2 | loc == 3 | loc == 4 | loc == 1
replace location = "US Top 5" if TOP5 == 1 
replace location = "US 6-17" if TOP17 == 1
replace location = "US Below 17" if (loc == 0 | regionID == 6) & TOP5 != 1 & TOP17 != 1
replace location = "Asia/Australia" if regionID == 9 | regionID == 10 | loc == 5 
replace location = "Latin America/Africa" if regionID == 8 | regionID == 12 | loc == 6
replace location = "Other" if regionID == 11

drop author_nomi
drop multi_* 
drop single_ECTA_cite single_REStud_cite single_QJE_cite single_AER_cite single_JPE_cite
drop ever_chair ever_committee
drop female_nominee female

* ordering 
order author author_shortmiddle year Female Male Ambiguous wiki_page death dead year_appointed_EMA ///
	fellow_EMA new_fellow_EMA ever_fellow_EMA connection_fellowEMA_cumulative ///
	year_appointed_AAAS fellow_AAAS new_fellow_AAAS ever_fellow_AAAS connection_fellowAAAS_cumulative AAAS_flags ///
	year_appointed_NAS fellow_NAS new_fellow_NAS ever_fellow_NAS connection_fellowNAS_cumulative primary_NAS ///
	year_appointed_AEAF fellow_AEAF new_fellow_AEAF ever_fellow_AEAF ///
	year_appointed_AEAP AEAP new_AEAP ever_AEAP ///
	year_appointed_AEAVP AEAVP new_AEAVP ever_AEAVP ///
	year_appointed_Sloan fellow_Sloan new_fellow_Sloan ever_fellow_Sloan ///
	year_appointed_EMALEC fellow_EMALEC new_fellow_EMALEC ever_fellow_EMALEC ///
	year_appointed_NBER fellow_NBER new_fellow_NBER ever_fellow_NBER  ///
	editor coeditor asso_editor year_appointed_committee committee new_committee nm_connection_committee committee_share_female ///
	year_appointed_chair chair new_chair chairman_female ///
	nominee new_nominee ever_nominee byCommittee numVotes numEndorsed University location TOP5 TOP17 loc regionID lastYearRoll ///
	///
	AER_cumulative AERPP_cumulative ECTA_cumulative ET_cumulative EcT_cumulative ///
	JE_cumulative JET_cumulative JMathE_cumulative JPE_cumulative QJE_cumulative ///
	REStud_cumulative RAND_cumulative IJGT_cumulative AEJ_Applied_cumulative ///
	AEJ_Policy_cumulative AEJ_Micro_cumulative AEJ_Macro_cumulative JEP_cumulative ///
	JEL_cumulative GEB_cumulative IER_cumulative REStat_cumulative ECA_cumulative ///
	EJ_cumulative JASA_cumulative JDE_cumulative JEEA_cumulative JF_cumulative ///
	JHE_cumulative JIE_cumulative JME_cumulative JOLE_cumulative JPubE_cumulative ///
	JEH_cumulative QE_cumulative TE_cumulative nm_paper_cumulative econ_pub_cumulative ///
	///
	AER AERPP ECTA ET EcT JE JET JMathE JPE QJE REStud RAND IJGT AEJ_Applied ///
	AEJ_Policy AEJ_Micro AEJ_Macro JEP JEL GEB IER REStat ECA EJ JASA JDE JEEA ///
	JF JHE JIE JME JOLE JPubE JEH QE TE ///
	///
	single_AER_cumulative single_AERPP_cumulative single_ECTA_cumulative single_ET_cumulative single_EcT_cumulative ///
	single_JE_cumulative single_JET_cumulative single_JMathE_cumulative single_JPE_cumulative single_QJE_cumulative ///
	single_REStud_cumulative single_RAND_cumulative single_IJGT_cumulative single_AEJ_Applied_cumulative ///
	single_AEJ_Policy_cumulative single_AEJ_Micro_cumulative single_AEJ_Macro_cumulative single_JEP_cumulative ///
	single_JEL_cumulative single_GEB_cumulative single_IER_cumulative single_REStat_cumulative single_ECA_cumulative ///
	single_EJ_cumulative single_JASA_cumulative single_JDE_cumulative single_JEEA_cumulative single_JF_cumulative ///
	single_JHE_cumulative single_JIE_cumulative single_JME_cumulative single_JOLE_cumulative single_JPubE_cumulative ///
	single_JEH_cumulative single_QE_cumulative single_TE_cumulative  ///
	///
	nm_paper first_pub years_firstpub last_pub years_lastpub ///
	ECTA_cite ECTA_cite_cumulative asinhEMAcites ///
	REStud_cite REStud_cite_cumulative asinhREScites ///
	QJE_cite QJE_cite_cumulative asinhQJEcites ///
	AER_cite AER_cite_cumulative asinhAERcites ///
	JPE_cite JPE_cite_cumulative asinhJPEcites

order author_original first_name middle_name last_name lastname_firstletter first5_alphabet F_M_alphabet N_Z_alphabet, last 

order single_ECTA_cite_cumulative single_REStud_cite_cumulative single_QJE_cite_cumulative single_AER_cite_cumulative single_JPE_cite_cumulative, after(asinhJPEcites)

* label 
label variable author "Author"
label variable year "Year"
label variable first_name "First name of the author"
label variable middle_name "Middle name of the author"
label variable last_name "Last name of the author"
label variable Female "Female"
label variable Male "Male"
label variable Ambiguous "Unknown gender"
label variable author_original "Original author name"

label variable QE "Quantitative Economics"
label variable TE "Theoretical Economics"
label variable nm_paper_cumulative "Cumulative number of papers published in all journals"
label variable econ_pub_cumulative "Cumulative number of papers published in all journals excluding JASA"

label variable ECTA_cite_cumulative "Cumulative number of citations in Econometrica"
label variable REStud_cite_cumulative "Cumulative number of citations in REStud"
label variable QJE_cite_cumulative "Cumulative number of citations in QJE"
label variable AER_cite_cumulative "Cumulative number of citations in AER"
label variable JPE_cite_cumulative "Cumulative number of citations in JPE"

label variable ECTA_cite "Number of citations in Econometrica"
label variable REStud_cite "Number of citations in REStud"
label variable QJE_cite "Number of citations in QJE"
label variable AER_cite "Number of citations in AER"
label variable JPE_cite "Number of citations in JPE"

label variable lastname_firstletter "Position of the first letter of author last name in the English alphabet"
label variable F_M_alphabet "Whether the person's last name begins in a letter from F to M"
label variable first5_alphabet "Whether the person's last name begins in a letter from A to E"
label variable N_Z_alphabet "Whether the person's last name begins in a letter from N to Z"

label variable byCommittee "Whether this nominee is nominated by the ES Nominating Committee"
label variable numVotes "Number of votes this nominee received"
label variable numEndorsed "Number of endorsements this nominee received"
label variable loc "Geographic region code of this nominee's institute, 1990-2002"
label variable regionID "Geographic region code of this nominee's institute, 2006-2019"
label variable location "Geographic region of this nominee's home institute"

label variable single_ECTA_cite_cumulative "Cumulative number of cites in single-authored Econometrica papers"
label variable single_AER_cite_cumulative "Cumulative number of cites in single-authored AER papers"
label variable single_QJE_cite_cumulative "Cumulative number of cites in single-authored QJE papers"
label variable single_REStud_cite_cumulative "Cumulative number of cites in single-authored REStud papers"
label variable single_JPE_cite_cumulative "Cumulative number of cites in single-authored JPE papers"

unab pub_cumulative: AER_cumulative-TE_cumulative
foreach var in `pub_cumulative'{
	local j = substr("`var'", 1, strrpos("`var'", "_")-1)
	label variable `var' "Cumulative number of papers in `j'"
}

label variable ECTA_cumulative "Cumulative number of papers in Econometrica"
label variable AEJ_Applied_cumulative "Cumulative number of papers in AEJ Applied"
label variable AEJ_Policy_cumulative "Cumulative number of papers in AEJ Policy"
label variable AEJ_Micro_cumulative "Cumulative number of papers in AEJ Micro"
label variable AEJ_Macro_cumulative "Cumulative number of papers in AEJ Macro"

label variable asinhREScites "asinh(REStud_cite_cumulative)"
label variable asinhEMAcites "asinh(ECTA_cite_cumulative)"
label variable asinhQJEcites "asinh(QJE_cite_cumulative)"
label variable asinhAERcites "asinh(AER_cite_cumulative)"
label variable asinhJPEcites "asinh(JPE_cite_cumulative)"

label variable ever_fellow_EMA "Whether this person ever became an ES fellow"
label variable ever_fellow_NBER "Whether this person ever became a NBER fellow"
label variable ever_fellow_NAS "Whether this person ever becomes a NAS fellow"
label variable ever_fellow_Sloan "Whether this person ever becomes a Sloan fellow"
label variable ever_fellow_EMALEC "Whether this person ever gave an ES lecture"
label variable ever_AEAP "Whether this person ever became AEA President"
label variable ever_AEAVP "Whether this person ever became AEA Vice President"
label variable ever_nominee "Whether this person ever became an ES nominee"

label variable new_fellow_AAAS "Whether this person becomes an AAAS fellow at this given year"
label variable new_fellow_AAAS "Whether this person becomes an AAAS fellow at this given year"
label variable new_fellow_AEAF "Whether this person becomes an AEA fellow at this given year"
label variable new_fellow_EMA "Whether this person becomes an ES fellow at this given year"
label variable new_fellow_EMALEC "Whether this person is giving an ES Lecture at this given year"
label variable new_fellow_NAS "Whether this person becomes a NAS fellow at this given year"
label variable new_fellow_NBER "Whether this person becomes a NBER fellow at this given year"
label variable new_fellow_Sloan "Whether this person becomes a Sloan fellow at this given year"
label variable new_AEAP "Whether this person becomes AEA President at this given year"
label variable new_AEAVP "Whether this person becomes AEA Vice President at this given year"
label variable new_nominee "Whether this person becomes a new ES nominee at this given year"
label variable new_chair "Whether this person becomes a new ES Nominating Committee Chair at this given year"
label variable new_committee "Whether this person becomes a new ES Nominating Committee member at this given year"

label variable fellow_EMA "Whether this person is an ES fellow at this given year"
label variable fellow_EMALEC "Whether this person has given an ES lecture at this given year"
label variable fellow_NAS "Whether this person is a NAS fellow at this given year"
label variable fellow_NBER "Whether this person is a NBER fellow at this given year"
label variable fellow_Sloan "Whether this person is a Sloan fellow at this given year"
label variable committee "Whether this person is an ES Nominating Committee member at this given year"
label variable chair "Whether this person is the ES Nominating Committee Chair at this given year"
label variable nominee "Whether this person is nominated to be an ES fellow at this given year"

label variable asso_editor "Whether this person is an associate editor of Econometrica at this given year"
label variable coeditorEMA "Whether this person is a co-editor of Econometrica at this given year"
label variable editorEMA "Whether this person is an editor of Econometrica at this given year"

label variable year_appointed_AAAS "Year appointed to be an AAAS fellow"
label variable year_appointed_AEAF "Year appointed to be an AEA fellow"
label variable year_appointed_AEAP "Year appointed to be AEA President"
label variable year_appointed_AEAVP "Year appointed to be AEA Vice President"
label variable year_appointed_EMA "Year appointed to be an ES fellow"
label variable year_appointed_EMALEC "Year giving an ES Lecture"
label variable year_appointed_NAS "Year appointed to be a NAS fellow" 
label variable year_appointed_NBER "Year appointed to be a NBER fellow" 
label variable year_appointed_Sloan "Year appointed to be a Sloan fellow" 
label variable year_appointed_chair "Year(s) appointed to be the ES Nominating Committee Chair" 
label variable year_appointed_committee "Year(s) appointed to be an ES Nominating Committee member"

label variable TOP5 "Whether this ES nominee belongs to a Top 5 US institute"
label variable TOP17 "Whether this ES nominee belongs to a Top 6-17 US institute"
label variable University "Home institute of this ES nominee"
label variable lastYearRoll "Year this ES nominee is rolled over from"

label variable chairman_female "Whether the ES Nominating Committee has a female chair at this given year"
label variable committee_share_female "Share of female in the ES Nominating Committee at this given year"
label variable nm_paper "Number of papers published in all journals" 

label variable death "Year of Death"
label variable wiki_page "Wikipedia or Wikidata Page"
label variable dead "Whether record is for year after author death"

sort last_name first_name middle_name year

compress
save "${root}/econ/output/regression_dataset.dta", replace


* drop publicly unavailable variables
drop if year == . & year_appointed_NBER != .
drop nominee new_nominee ever_nominee byCommittee numVotes numEndorsed ///
	University location TOP5 TOP17 loc regionID lastYearRoll *_NBER *_EMALEC  

* committee variable membership censorship before 1990
drop year_appointed_committee
foreach var in committee new_committee nm_connection_committee {
	replace `var' = . if year < 1990
}


compress
save "${root}/econ/output/regression_dataset_public.dta", replace








