# If you have not already downloaded the gender data package, 
# enter install_genderdata_package() into console and install the package.


##### Houskeeping #####
rm(list=ls())

options(java.parameters = "-Xmx2048m")

library('dplyr')
library('haven')
library('gender')
library('stringdist')
library('assertthat')
library('readr')
library('rstudioapi')
library('stringr') 

localeToCharset(locale = Sys.getlocale("LC_CTYPE"))

# Set path
setwd('')

print(getwd())

# Timer
startTime<-proc.time()

##################################

# matching gender using preexisting Gender_Names.dta
# input files
gender_names = read_dta("input/Gender_Names.dta")
published_data = read_csv(file = "names.csv")

#take out later
gender_names$in_gendernames = 1

gendered = merge(x = published_data, y = gender_names[, c("Name", "in_gendernames")],
                 by.x = "authors", by.y = "Name", all.x = TRUE, all.y = FALSE)
gendered$in_gendernames[is.na(gendered$in_gendernames)] = 0

split_word = "([[:blank:]])|(-)|(')"

gendered$oneword = ifelse(!grepl("([[:blank:]])|(-)", gendered$authors),
                          1, 0)
gendered$in_gendernames[!grepl("([[:blank:]])|(-)", gendered$authors)] = 1


unmatched = gendered$authors[gendered$in_gendernames == 0]
unmatched = unique(unmatched)
one_word_names = unmatched[!grepl(split_word, unmatched)]
unmatched = unmatched[grepl(split_word, unmatched)] #only keep those with more than one words

#delete unmatched with one word only (need to manually check them)
num_pieces = str_count(unmatched, pattern = split_word)
num_pieces = max(num_pieces) + 1
split_unmatched = str_split_fixed(unmatched, pattern = split_word, n = num_pieces)
split_unmatched = data.frame(authors = unmatched,
                             split_unmatched, stringsAsFactors = FALSE)

for (i in 2:ncol(split_unmatched)){
  colnames(split_unmatched)[i] = paste("name", i - 1, sep = "")
  split_unmatched[i][split_unmatched[i] == ""] = ".+"
}

split_unmatched$match = ""
split_unmatched$EconLit = ""
split_unmatched$Gender_M = ""
split_unmatched$Gender_F = ""
split_unmatched$Gender_A = ""


no_match = c()
more_than_one = c()
more_than_one_matches = list()
for (i in 1:nrow(split_unmatched)){
  
  print(i)
  match_all = TRUE
  
  for (j in 2:ncol(split_unmatched)){
    if (split_unmatched[i, j] == ".+"){break}
    match_piece = grepl(split_unmatched[i, j], gender_names$Name, ignore.case = TRUE)
    match_all = match_all & match_piece
    
  }
  
  pubdata_name = unique(gender_names$Name[match_all])
  EconLit = unique(gender_names$EconLit[match_all])
  Gender_M = unique(gender_names$Gender_M[match_all])
  Gender_F = unique(gender_names$Gender_F[match_all])
  Gender_A = unique(gender_names$Gender_A[match_all])
  
  #retrieve published_data name
  if (length(pubdata_name) == 1){
    
    split_unmatched$match[i] = pubdata_name
    split_unmatched$EconLit[i] = EconLit
    split_unmatched$Gender_M[i] = Gender_M
    split_unmatched$Gender_F[i] = Gender_F
    split_unmatched$Gender_A[i] = Gender_A
    
  } else {
    if(length(pubdata_name) == 0){
      
      split_unmatched$match[i] = "NO_MATCH"
      split_unmatched$EconLit[i] = "NO_MATCH"
      split_unmatched$Gender_M[i] = "NO_MATCH"
      split_unmatched$Gender_F[i] = "NO_MATCH"
      split_unmatched$Gender_A[i] = "NO_MATCH"
      no_match = c(no_match, split_unmatched$authors[i])
      
    } else {
      
      #can make this more sophisticated instead of just selecting the first name
      split_unmatched$match[i] = pubdata_name[1]
      split_unmatched$EconLit[i] = EconLit[1]
      split_unmatched$Gender_M[i] = Gender_M[1]
      split_unmatched$Gender_F[i] = Gender_F[1]
      split_unmatched$Gender_A[i] = Gender_A[1]
      
      #should check the list retrospectively and see if the names are basically the same
      more_than_one = c(more_than_one, split_unmatched$authors[i])
      more_than_one_matches = list(more_than_one_matches, pubdata_name)
      
    }
    
  }
  
}

split_unmatched = split_unmatched[ c("authors", "match", "EconLit", "Gender_M", "Gender_F", "Gender_A")]
write_csv(split_unmatched, path = "temp/unmatched_matches.csv")



#############################################################

#"Katherine Coffman Baldiga"
split_unmatched$match[split_unmatched$authors %in% "Katherine Coffman Baldiga"] = "Katherine Coffman"
split_unmatched$EconLit[split_unmatched$authors %in% "Katherine Coffman Baldiga"] = gender_names$EconLit[gender_names$Name %in% "Katherine Coffman"]
split_unmatched$Gender_M[split_unmatched$authors %in% "Katherine Coffman Baldiga"] = gender_names$Gender_M[gender_names$Name %in% "Katherine Coffman"]
split_unmatched$Gender_F[split_unmatched$authors %in% "Katherine Coffman Baldiga"] = gender_names$Gender_F[gender_names$Name %in% "Katherine Coffman"]
split_unmatched$Gender_A[split_unmatched$authors %in% "Katherine Coffman Baldiga"] = gender_names$Gender_A[gender_names$Name %in% "Katherine Coffman"]

#"Giancarlo Ottaviano"
#this one appears to just be a typo in the original document
split_unmatched$match[split_unmatched$authors %in% "Giancarlo Ottaviano"] = "Gianmarco Ottaviano"
split_unmatched$EconLit[split_unmatched$authors %in% "Giancarlo Ottaviano"] = gender_names$EconLit[gender_names$Name %in% "Gianmarco Ottaviano"]
split_unmatched$Gender_M[split_unmatched$authors %in% "Giancarlo Ottaviano"] = gender_names$Gender_M[gender_names$Name %in% "Gianmarco Ottaviano"]
split_unmatched$Gender_F[split_unmatched$authors %in% "Giancarlo Ottaviano"] = gender_names$Gender_F[gender_names$Name %in% "Gianmarco Ottaviano"]
split_unmatched$Gender_A[split_unmatched$authors %in% "Giancarlo Ottaviano"] = gender_names$Gender_A[gender_names$Name %in% "Gianmarco Ottaviano"]

#############################################################

#merge back

matched_df = merge(x = gendered[gendered$in_gendernames == 1, !(colnames(gendered) %in% "in_gendernames")],
                   y = gender_names[, colnames(gender_names) %in% c("Name", "match", "EconLit", "Gender_M", "Gender_F", "Gender_A")],
                   by.x = "authors", by.y = "Name", all.x = TRUE, all.y = FALSE)
matched_df$match = matched_df$authors
prev_unmatched_df = merge(x = gendered[gendered$in_gendernames == 0, !(colnames(gendered) %in% "in_gendernames")],
                          y = split_unmatched[, colnames(split_unmatched) %in% c("authors", "match", "EconLit", "Gender_M", "Gender_F", "Gender_A")],
                          by = "authors", all.x = TRUE, all.y = FALSE)

published_data_gendered = rbind(matched_df, prev_unmatched_df)


#############################################################
published_data_gendered = published_data_gendered[!(published_data_gendered$match %in% "Ii"), ]

authors = c("Bandi", "Bernheim", "Bhaskar", "Chari", "Donald", "Duggan", "Gneezy", "Gorton", "James", "Joseph", "Kramarz", "Martinelli", "Norets", "Peter", "Russell", "Slavov", "Steven", "Tang", "Thesmar")
authors_full = c("Federico Bandi", "Douglas Bernheim", "Venkataraman Bhaskar", "Amalavoyal Chari", "Donald Davis", "John Duggan", "Uri Gneezy", "Gary Gorton", "James Banks", "Joseph Davis", "Francis Kramarz", "Cesar Martinelli", "Andriy Norets", "Peter Ireland", "Jeffrey Russell", "Sita Nataraj Slavov", "Steven Davis", "Xun Tang", "David Thesmar")

#can modify to include title
for (i in 1:length(authors)){
  published_data_gendered$match[published_data_gendered$authors %in% authors[i]] = authors_full[i]
  published_data_gendered$EconLit[published_data_gendered$authors %in% authors[i]] = gender_names$EconLit[gender_names$Name %in% authors_full[i]]
  published_data_gendered$Gender_M[published_data_gendered$authors %in% authors[i]] = gender_names$Gender_M[gender_names$Name %in% authors_full[i]]
  published_data_gendered$Gender_F[published_data_gendered$authors %in% authors[i]] = gender_names$Gender_F[gender_names$Name %in% authors_full[i]]
  published_data_gendered$Gender_A[published_data_gendered$authors %in% authors[i]] = gender_names$Gender_A[gender_names$Name %in% authors_full[i]]
}

published_data_gendered = published_data_gendered[, !(colnames(published_data_gendered) %in% "oneword")]

write_csv(published_data_gendered, path = "temp/matches_first_run.csv")


