
clear

if !missing("$dropbox_dir") {
	local dropbox_dir = "$dropbox_dir"
}
else {
	local dropbox_dir "C:/Users/Chris/Dropbox"
}
cd "`dropbox_dir'/ECM_Fellow_Study/Replication"
cap log close
log using "figures/avg_top5.log", replace


use "`dropbox_dir'\ECM_Fellow_Study\Paper2\econ\output\regression_dataset.dta"

* take out the deceased authors
drop if (author == "Sherwin Rosen" & year >= death + 2 | dead == 1 & author != "Sherwin Rosen")
* take out the ambiguous gendered economists  
drop if Ambiguous == 1
* keep risk set only 
keep if (fellow_EMA==0|new_fellow_EMA==1)
drop if year < 1960

* author id 
qui egen id = group(author year)

* levels of top5 and cites 
gen top5 = AER_cumulative+QJE_cumulative+REStud_cumulative+ECTA_cumulative+JPE_cumulative
gen top5_cumulative = AER_cumulative+QJE_cumulative+REStud_cumulative+ECTA_cumulative+JPE_cumulative
gen top5_cite=AER_cite+QJE_cite+REStud_cite+ECTA_cite+JPE_cite
gen top5_cite_cumulative=AER_cite_cumulative+QJE_cite_cumulative+REStud_cite_cumulative+ECTA_cite_cumulative+JPE_cite_cumulative

gen top5_1=(top5==1)
gen top5_2=(top5==2)
gen top5_3=(top5==3)
gen top5_4=(top5==4)
gen top5_5=(top5==5)
gen top5_6=(top5==6)
gen top5_7=(top5>=7)

gen ema_1=(ECTA_cumulative==1)
gen ema_2=(ECTA_cumulative==2)
gen ema_3=(ECTA_cumulative>=3)

gen res_1=(REStud_cumulative==1)
gen res_2=(REStud_cumulative==2)
gen res_3=(REStud_cumulative>=3)

gen qje_1=(QJE_cumulative==1)
gen qje_2=(QJE_cumulative==2)
gen qje_3=(QJE_cumulative>=3)

gen aer_1=(AER_cumulative==1)
gen aer_2=(AER_cumulative==2)
gen aer_3=(AER_cumulative>=3)

gen jpe_1=(JPE_cumulative==1)
gen jpe_2=(JPE_cumulative==2)
gen jpe_3=(JPE_cumulative>=3)

* levels of citation 
gen decade = . 
local list_decade 1940 1950 1960 1970 1980 1990 2000 2010 
foreach decade in `list_decade'{
	replace decade = `decade' if floor(year/10)*10 == `decade'
}
replace decade = 1930 if inrange(year, 1933, 1939)

gen if_top5=(top5>=1)
gen if_riskset = (fellow_EMA == 0 | new_fellow_EMA == 1)

gen n = 1 
gsort decade if_top5 if_riskset +top5_cite_cumulative

by decade if_top5 if_riskset: gen cumfreq = sum(n)
by decade if_top5 if_riskset: gen N = _N 
gen freq_cite = (cumfreq/N)*100

by decade if_top5 if_riskset top5_cite_cumulative: egen pctile_cite = max(freq_cite)
drop freq_cite N cumfreq n 

gen topcite1 = 0
gen topcite2 = 0 
gen topcite3 = 0 
gen topcite4 = 0 
gen topcite5 = 0 
gen topcite6 = 0 
gen topcite7 = 0 
gen topcite8 = 0

gen topcite = . 

levelsof decade, local(levels)
foreach d in `levels'{
	
	replace topcite1 = 1 if decade == `d' & pctile_cite < 50 & if_top5 == 1 & if_riskset == 1
	replace topcite2 = 1 if decade == `d' & pctile_cite >= 50 & pctile_cite < 70 & if_top5 == 1 & if_riskset == 1
	replace topcite3 = 1 if decade == `d' & pctile_cite >= 70 & pctile_cite < 80 & if_top5 == 1 & if_riskset == 1
	replace topcite4 = 1 if decade == `d' & pctile_cite >= 80 & pctile_cite < 90 & if_top5 == 1 & if_riskset == 1
	replace topcite5 = 1 if decade == `d' & pctile_cite >= 90 & pctile_cite < 95 & if_top5 == 1 & if_riskset == 1
	replace topcite6 = 1 if decade == `d' & pctile_cite >= 95 & pctile_cite < 97.5 & if_top5 == 1 & if_riskset == 1
	replace topcite7 = 1 if decade == `d' & pctile_cite >= 97.5 & pctile_cite < 99 & if_top5 == 1 & if_riskset == 1
	replace topcite8 = 1 if decade == `d' & pctile_cite >= 99 & if_top5 == 1 & if_riskset == 1
	
	replace topcite = 1 if decade == `d' & pctile_cite < 50 & if_top5 == 1 & if_riskset == 1
	replace topcite = 2 if decade == `d' & pctile_cite >= 50 & pctile_cite < 70 & if_top5 == 1 & if_riskset == 1
	replace topcite = 3 if decade == `d' & pctile_cite >= 70 & pctile_cite < 80 & if_top5 == 1 & if_riskset == 1
	replace topcite = 4 if decade == `d' & pctile_cite >= 80 & pctile_cite < 90 & if_top5 == 1 & if_riskset == 1
	replace topcite = 5 if decade == `d' & pctile_cite >= 90 & pctile_cite < 95 & if_top5 == 1 & if_riskset == 1
	replace topcite = 6 if decade == `d' & pctile_cite >= 95 & pctile_cite < 97.5 & if_top5 == 1 & if_riskset == 1
	replace topcite = 7 if decade == `d' & pctile_cite >= 97.5 & pctile_cite < 99 & if_top5 == 1 & if_riskset == 1
	replace topcite = 8 if decade == `d' & pctile_cite >= 99 & if_top5 == 1 & if_riskset == 1
	
	tab topcite if decade == `d' & if_top5 == 1 & if_riskset == 1
}

gen firstpub_10 = (years_firstpub < 20 & years_firstpub >= 10)
gen firstpub_20 = (years_firstpub < 30 & years_firstpub >= 20)
gen firstpub_30 = (years_firstpub >= 30)

drop decade topcite

* ==============================================================================
preserve 

* decade 
gen decade = "1960-1979" if inrange(year, 1960, 1979)
replace decade = "1980-1999" if inrange(year, 1980, 1999)
replace decade = "2000-2019" if inrange(year, 2000, 2019)

unab controls: AER_cumulative-TE_cumulative asinh*cites ///
top5_1-top5_7 ema_* res_* aer_* qje_* jpe_* topcite2-topcite8 ///
firstpub_10-firstpub_30

levelsof decade, local(levels)
foreach d in `levels'{
	
	local str_d = substr("`d'", 1, 4) + "_" + substr("`d'", strpos("`d'", "-")+1, .)
	
	qui logit new_fellow_EMA `controls' i.year ///
	if (fellow_EMA==0|new_fellow_EMA==1) & decade == "`d'" & Female == 0, cluster(author)
	
	predict prob_fellow_EMA_`str_d'
	
}	


* gen overall variable for prob_fellow_EMA 
gen prob_fellow_EMA = .
unab decade_prob_fellow: prob_fellow_EMA_* /* disjoint set */
foreach p in `decade_prob_fellow'{
	replace prob_fellow_EMA = `p' if !missing(`p')
}

drop prob_fellow_EMA_* 

* gen prob_fellow_EMA percentile, by index 
bysort decade: egen p90_new_fellow_EMA = pctile(prob_fellow_EMA), p(90)
bysort decade: egen p95_new_fellow_EMA = pctile(prob_fellow_EMA), p(95)
bysort decade: egen p97_new_fellow_EMA = pctile(prob_fellow_EMA), p(97.5)
bysort decade: egen p99_new_fellow_EMA = pctile(prob_fellow_EMA), p(99)

* gen qrange by percentile, and rank by top 5 
gen qrange = . 
gen top5_qrange = . 

levelsof decade, local(levels)
foreach d in `levels'{
	
	* qrange 
	replace qrange = 1 if prob_fellow_EMA < p90_new_fellow_EMA & !missing(prob_fellow_EMA) & decade == "`d'"
	
	replace qrange = 2 if prob_fellow_EMA >= p90_new_fellow_EMA & prob_fellow_EMA < p95_new_fellow_EMA ///
	& !missing(prob_fellow_EMA) & decade == "`d'"
	
	replace qrange = 3 if prob_fellow_EMA >= p95_new_fellow_EMA & prob_fellow_EMA < p97_new_fellow_EMA ///
	& !missing(prob_fellow_EMA) & decade == "`d'"
	
	replace qrange = 4 if prob_fellow_EMA >= p97_new_fellow_EMA & prob_fellow_EMA < p99_new_fellow_EMA ///
	& !missing(prob_fellow_EMA) & decade == "`d'"
	
	replace qrange = 5 if prob_fellow_EMA >= p99_new_fellow_EMA & !missing(prob_fellow_EMA) & decade == "`d'"
		
}	

gen decade_comb = "1960-1999" if inrange(year, 1960, 1999)
replace decade_comb = "2000-2019" if inrange(year, 2000, 2019)

* summary statistics 
bysort decade: gen n = _n 

* top 5 summary stat
tempfile temp_top5
drop if missing(decade_comb)
collapse (mean) top5_cumulative (count) n, by(decade_comb qrange)
drop if qrange == . 
sort decade_comb qrange 
save "`temp_top5'"

restore 

* ==============================================================================
preserve 

* regenerate qrange decade 
gen decade = "2000-2009" if inrange(year, 2000, 2009)
replace decade = "2010-2019" if inrange(year, 2010, 2019)

unab controls: AER_cumulative-TE_cumulative asinh*cites ///
top5_1-top5_7 ema_* res_* aer_* qje_* jpe_* topcite2-topcite8 ///
firstpub_10-firstpub_30

levelsof decade, local(levels)
foreach d in `levels'{
	
	local str_d = substr("`d'", 1, 4) + "_" + substr("`d'", strpos("`d'", "-")+1, .)
	
	qui logit new_fellow_EMA `controls' i.year ///
	if (fellow_EMA==0|new_fellow_EMA==1) & decade == "`d'" & Female == 0, cluster(author)
	
	predict prob_fellow_EMA_`str_d'
	
}	


* gen overall variable for prob_fellow_EMA 
gen prob_fellow_EMA = .
unab decade_prob_fellow: prob_fellow_EMA_* /* disjoint set */
foreach p in `decade_prob_fellow'{
	replace prob_fellow_EMA = `p' if !missing(`p')
}

drop prob_fellow_EMA_* 

* gen prob_fellow_EMA percentile, by index 
bysort decade: egen p90_new_fellow_EMA = pctile(prob_fellow_EMA), p(90)
bysort decade: egen p95_new_fellow_EMA = pctile(prob_fellow_EMA), p(95)
bysort decade: egen p97_new_fellow_EMA = pctile(prob_fellow_EMA), p(97.5)
bysort decade: egen p99_new_fellow_EMA = pctile(prob_fellow_EMA), p(99)

* gen qrange by percentile, and rank by top 5 
gen qrange = . 
gen top5_qrange = . 

levelsof decade, local(levels)
foreach d in `levels'{
	
	* qrange 
	replace qrange = 1 if prob_fellow_EMA < p90_new_fellow_EMA & !missing(prob_fellow_EMA) & decade == "`d'"
	
	replace qrange = 2 if prob_fellow_EMA >= p90_new_fellow_EMA & prob_fellow_EMA < p95_new_fellow_EMA ///
	& !missing(prob_fellow_EMA) & decade == "`d'"
	
	replace qrange = 3 if prob_fellow_EMA >= p95_new_fellow_EMA & prob_fellow_EMA < p97_new_fellow_EMA ///
	& !missing(prob_fellow_EMA) & decade == "`d'"
	
	replace qrange = 4 if prob_fellow_EMA >= p97_new_fellow_EMA & prob_fellow_EMA < p99_new_fellow_EMA ///
	& !missing(prob_fellow_EMA) & decade == "`d'"
	
	replace qrange = 5 if prob_fellow_EMA >= p99_new_fellow_EMA & !missing(prob_fellow_EMA) & decade == "`d'"
	
}	

* summary statistics 
bysort decade: gen n = _n 
drop if missing(decade) | missing(qrange)
collapse (mean) top5_cumulative (count) n, by(decade qrange)
rename decade decade_comb 
append using "`temp_top5'"
tempfile update_temp_top5 
save "`update_temp_top5'"

restore 

* ==============================================================================
preserve 

gen decade = "1995-2019" if inrange(year, 1995, 2005) & year != 2003 
replace decade = "1995-2019" if inrange(year, 2012, 2019) 

unab controls: AER_cumulative-TE_cumulative asinh*cites ///
top5_1-top5_7 ema_* res_* aer_* qje_* jpe_* topcite2-topcite8 ///
firstpub_10-firstpub_30

levelsof decade, local(levels)
foreach d in `levels'{
	
	local str_d = substr("`d'", 1, 4) + "_" + substr("`d'", strpos("`d'", "-")+1, .)
	
	qui logit nominee `controls' i.year ///
	if (fellow_EMA==0|nominee==1) & decade == "`d'" & Female == 0, cluster(author)
	
	predict prob_fellow_EMA_`str_d'
	
}	


* gen overall variable for prob_fellow_EMA 
gen prob_fellow_EMA = .
unab decade_prob_fellow: prob_fellow_EMA_* /* disjoint set */
foreach p in `decade_prob_fellow'{
	replace prob_fellow_EMA = `p' if !missing(`p')
}

drop prob_fellow_EMA_* 

* gen prob_fellow_EMA percentile, by index 
bysort decade: egen p90_new_fellow_EMA = pctile(prob_fellow_EMA), p(90)
bysort decade: egen p95_new_fellow_EMA = pctile(prob_fellow_EMA), p(95)
bysort decade: egen p97_new_fellow_EMA = pctile(prob_fellow_EMA), p(97.5)
bysort decade: egen p99_new_fellow_EMA = pctile(prob_fellow_EMA), p(99)

* gen qrange by percentile, and rank by top 5 
gen qrange = . 
gen top5_qrange = . 

levelsof decade, local(levels)
foreach d in `levels'{
	
	* qrange 
	replace qrange = 1 if prob_fellow_EMA < p90_new_fellow_EMA & !missing(prob_fellow_EMA) & decade == "`d'"
	
	replace qrange = 2 if prob_fellow_EMA >= p90_new_fellow_EMA & prob_fellow_EMA < p95_new_fellow_EMA ///
	& !missing(prob_fellow_EMA) & decade == "`d'"
	
	replace qrange = 3 if prob_fellow_EMA >= p95_new_fellow_EMA & prob_fellow_EMA < p97_new_fellow_EMA ///
	& !missing(prob_fellow_EMA) & decade == "`d'"
	
	replace qrange = 4 if prob_fellow_EMA >= p97_new_fellow_EMA & prob_fellow_EMA < p99_new_fellow_EMA ///
	& !missing(prob_fellow_EMA) & decade == "`d'"
	
	replace qrange = 5 if prob_fellow_EMA >= p99_new_fellow_EMA & !missing(prob_fellow_EMA) & decade == "`d'"
	
}	

* summary statistics 
bysort decade: gen n = _n 
drop if missing(decade) | missing(qrange)
collapse (mean) top5_cumulative (count) n, by(decade qrange)
rename decade decade_comb 
append using "`update_temp_top5'"
export delimited using "figures/avg_top5.csv", replace
restore 

log off
log close
