
clear

if !missing("$dropbox_dir") {
	local dropbox_dir = "$dropbox_dir"
}
else {
	local dropbox_dir "C:/Users/Chris/Dropbox"
}
cd "`dropbox_dir'/ECM_Fellow_Study/Replication"
cap log close
log using "figures/figure3AB.log", replace

tempfile building_logit
save `building_logit', emptyok replace

use "`dropbox_dir'\ECM_Fellow_Study\Paper2\econ\output\regression_dataset_public.dta"

* take out the ambiguous gendered economists  
drop if Ambiguous == 1
* take out the deceased authors
drop if (author == "Sherwin Rosen" & year >= death + 2 | dead == 1 & author != "Sherwin Rosen")
* keep risk set only 
keep if (fellow_EMA==0|new_fellow_EMA==1)
drop if year < 1960

* author id 
qui egen id = group(author year)

* levels of top5 and cites 
gen top5 = AER_cumulative+QJE_cumulative+REStud_cumulative+ECTA_cumulative+JPE_cumulative
gen top5_cite_cumulative=AER_cite_cumulative+QJE_cite_cumulative+REStud_cite_cumulative+ECTA_cite_cumulative+JPE_cite_cumulative

gen top5_1=(top5==1)
gen top5_2=(top5==2)
gen top5_3=(top5==3)
gen top5_4=(top5==4)
gen top5_5=(top5==5)
gen top5_6=(top5==6)
gen top5_7=(top5>=7)

gen ema_1=(ECTA_cumulative==1)
gen ema_2=(ECTA_cumulative==2)
gen ema_3=(ECTA_cumulative>=3)

gen res_1=(REStud_cumulative==1)
gen res_2=(REStud_cumulative==2)
gen res_3=(REStud_cumulative>=3)

gen qje_1=(QJE_cumulative==1)
gen qje_2=(QJE_cumulative==2)
gen qje_3=(QJE_cumulative>=3)

gen aer_1=(AER_cumulative==1)
gen aer_2=(AER_cumulative==2)
gen aer_3=(AER_cumulative>=3)

gen jpe_1=(JPE_cumulative==1)
gen jpe_2=(JPE_cumulative==2)
gen jpe_3=(JPE_cumulative>=3)

* levels of citation 
gen if_top5=(top5>=1)
gen if_riskset = (fellow_EMA == 0 | new_fellow_EMA == 1)

gen decade = . 
local list_decade 1940 1950 1960 1970 1980 1990 2000 2010 
foreach decade in `list_decade'{
	replace decade = `decade' if floor(year/10)*10 == `decade'
}
replace decade = 1930 if inrange(year, 1931, 1939)

gen topcite = . 

levelsof decade, local(levels)
foreach d in `levels'{
	
	_pctile top5_cite_cumulative if decade == `d' & if_top5 == 1 & if_riskset == 1, p(50 70 80 90 95 97.5 99)
	return list
	
	replace topcite = 1 if top5_cite_cumulative < r(r1) & decade == `d'
	replace topcite = 2 if top5_cite_cumulative < r(r2) & top5_cite_cumulative >= r(r1) & decade == `d'
	replace topcite = 3 if top5_cite_cumulative < r(r3) & top5_cite_cumulative >= r(r2) & decade == `d'
	replace topcite = 4 if top5_cite_cumulative < r(r4) & top5_cite_cumulative >= r(r3) & decade == `d'
	replace topcite = 5 if top5_cite_cumulative < r(r5) & top5_cite_cumulative >= r(r4) & decade == `d'
	replace topcite = 6 if top5_cite_cumulative < r(r6) & top5_cite_cumulative >= r(r5) & decade == `d'
	replace topcite = 7 if top5_cite_cumulative < r(r7) & top5_cite_cumulative >= r(r6) & decade == `d'
	replace topcite = 8 if top5_cite_cumulative >= r(r7) & decade == `d'
	
}

gen topcite1 = (topcite == 1)
gen topcite2 = (topcite == 2)
gen topcite3 = (topcite == 3)
gen topcite4 = (topcite == 4)
gen topcite5 = (topcite == 5)
gen topcite6 = (topcite == 6) 
gen topcite7 = (topcite == 7) 
gen topcite8 = (topcite == 8)


gen firstpub_10 = (years_firstpub < 20 & years_firstpub >= 10)
gen firstpub_20 = (years_firstpub < 30 & years_firstpub >= 20)
gen firstpub_30 = (years_firstpub >= 30)

drop decade topcite

* ==============================================================================
* logit model 
* ==============================================================================

unab controls: AER_cumulative-TE_cumulative asinh*cites ///
top5_1-top5_7 ema_* res_* aer_* qje_* jpe_* topcite2-topcite8 ///
firstpub_10-firstpub_30
	
* 1960-1979 
preserve 
	keep if inrange(year, 1960, 1979)
		
	* gen predicted probability 
	logit new_fellow_EMA Female `controls' i.year if (fellow_EMA==0|new_fellow_EMA==1), cluster(author)
	predict pred_prob
		
	* levels of top 5 
	logit new_fellow_EMA `controls' i.year ///
	if (fellow_EMA==0|new_fellow_EMA==1) & Female == 0, cluster(author)
	* extract post-estimation y_hat 
	predict podds 
		
	* gen qrange 
	egen p90_new_fellow_EMA = pctile(podds), p(90)
	egen p95_new_fellow_EMA = pctile(podds), p(95)
	egen p97_new_fellow_EMA = pctile(podds), p(97.5)
	egen p99_new_fellow_EMA = pctile(podds), p(99)
		
	sum p*_new_fellow_EMA

	qui gen qrange = 1 if podds < p90_new_fellow_EMA ///
	& !missing(podds)
	qui replace qrange = 2 if podds >= p90_new_fellow_EMA & podds < p95_new_fellow_EMA ///
	& !missing(podds)
	qui replace qrange = 3 if podds >= p95_new_fellow_EMA & podds < p97_new_fellow_EMA ///
	& !missing(podds)
	qui replace qrange = 4 if podds >= p97_new_fellow_EMA & podds < p99_new_fellow_EMA ///
	& !missing(podds)
	qui replace qrange = 5 if podds >= p99_new_fellow_EMA & !missing(podds)
	
	* collapse by qrange and gender 
	collapse (mean) new_fellow_EMA pred_prob (count) id, by (Female qrange)
	drop if Female == . | qrange == . 
	gen sample = "1960-1979"
		
	tempfile temp
	save `temp', replace
		
	use "`building_logit'"
	append using `temp'
	save "`building_logit'", replace 
restore 

* 1980-1999
preserve 
	keep if inrange(year, 1980, 1999)
		
	* gen predicted probability 
	logit new_fellow_EMA Female `controls' i.year if (fellow_EMA==0|new_fellow_EMA==1), cluster(author)
	predict pred_prob
		
	* levels of top 5 
	logit new_fellow_EMA `controls' i.year if (fellow_EMA==0|new_fellow_EMA==1) & Female == 0, cluster(author)
	* extract post-estimation y_hat 
	predict podds 
		
	* gen qrange 
	egen p90_new_fellow_EMA = pctile(podds), p(90)
	egen p95_new_fellow_EMA = pctile(podds), p(95)
	egen p97_new_fellow_EMA = pctile(podds), p(97.5)
	egen p99_new_fellow_EMA = pctile(podds), p(99)
		
	sum p*_new_fellow_EMA

	qui gen qrange = 1 if podds < p90_new_fellow_EMA ///
	& !missing(podds)
	qui replace qrange = 2 if podds >= p90_new_fellow_EMA & podds < p95_new_fellow_EMA ///
	& !missing(podds)
	qui replace qrange = 3 if podds >= p95_new_fellow_EMA & podds < p97_new_fellow_EMA ///
	& !missing(podds)
	qui replace qrange = 4 if podds >= p97_new_fellow_EMA & podds < p99_new_fellow_EMA ///
	& !missing(podds)
	qui replace qrange = 5 if podds >= p99_new_fellow_EMA & !missing(podds)
	
	* collapse by qrange and gender 
	collapse (mean) new_fellow_EMA pred_prob (count) id, by (Female qrange)
	drop if Female == . | qrange == . 
	gen sample = "1980-1999"
		
	tempfile temp
	save `temp', replace
		
	use "`building_logit'"
	append using `temp'
	save "`building_logit'", replace 
restore 


* 2000 + 

preserve 
	keep if inrange(year, 2000, 2019)

	gen Female_2000 = (Female == 1 & year <= 2009 & year >= 2000)
	gen Female_2010 = (Female == 1 & year <= 2019 & year >= 2010)
		
	* gen predicted probability
	logit new_fellow_EMA Female_2000 Female_2010 `controls' i.year if (fellow_EMA==0|new_fellow_EMA==1), cluster(author)
	predict pred_prob 
		
	* levels of top 5 
	logit new_fellow_EMA `controls' i.year if (fellow_EMA==0|new_fellow_EMA==1) & Female == 0, cluster(author)
	* extract post-estimation y_hat 
	predict podds

	keep if inrange(year, 2000, 2009)

	* gen qrange 
	egen p90_new_fellow_EMA = pctile(podds), p(90)
	egen p95_new_fellow_EMA = pctile(podds), p(95)
	egen p97_new_fellow_EMA = pctile(podds), p(97.5)
	egen p99_new_fellow_EMA = pctile(podds), p(99)
		
	sum p*_new_fellow_EMA

	qui gen qrange = 1 if podds < p90_new_fellow_EMA ///
	& !missing(podds)
	qui replace qrange = 2 if podds >= p90_new_fellow_EMA & podds < p95_new_fellow_EMA ///
	& !missing(podds)
	qui replace qrange = 3 if podds >= p95_new_fellow_EMA & podds < p97_new_fellow_EMA ///
	& !missing(podds)
	qui replace qrange = 4 if podds >= p97_new_fellow_EMA & podds < p99_new_fellow_EMA ///
	& !missing(podds)
	qui replace qrange = 5 if podds >= p99_new_fellow_EMA & !missing(podds)
	
	* collapse by qrange and gender 
	collapse (mean) new_fellow_EMA pred_prob (count) id, by (Female qrange)
	drop if Female == . | qrange == . 
	gen sample = "2000-2009"
		
	tempfile temp
	save `temp', replace
		
	use "`building_logit'"
	append using `temp'
	save "`building_logit'", replace 
restore 


*2010+ 
keep if inrange(year, 2000, 2019)

gen Female_2000 = (Female == 1 & year <= 2009 & year >= 2000)
gen Female_2010 = (Female == 1 & year <= 2019 & year >= 2010)
	
* gen predicted probability
logit new_fellow_EMA Female_2000 Female_2010 `controls' i.year if (fellow_EMA==0|new_fellow_EMA==1), cluster(author)
predict pred_prob 
	
* levels of top 5 
logit new_fellow_EMA `controls' i.year if (fellow_EMA==0|new_fellow_EMA==1) & Female == 0, cluster(author)
* extract post-estimation y_hat 
predict podds

keep if inrange(year, 2010, 2019)

* gen qrange 
egen p90_new_fellow_EMA = pctile(podds), p(90)
egen p95_new_fellow_EMA = pctile(podds), p(95)
egen p97_new_fellow_EMA = pctile(podds), p(97.5)
egen p99_new_fellow_EMA = pctile(podds), p(99)
	
sum p*_new_fellow_EMA

qui gen qrange = 1 if podds < p90_new_fellow_EMA ///
& !missing(podds)
qui replace qrange = 2 if podds >= p90_new_fellow_EMA & podds < p95_new_fellow_EMA ///
& !missing(podds)
qui replace qrange = 3 if podds >= p95_new_fellow_EMA & podds < p97_new_fellow_EMA ///
& !missing(podds)
qui replace qrange = 4 if podds >= p97_new_fellow_EMA & podds < p99_new_fellow_EMA ///
& !missing(podds)
qui replace qrange = 5 if podds >= p99_new_fellow_EMA & !missing(podds)

* collapse by qrange and gender 
collapse (mean) new_fellow_EMA pred_prob (count) id, by (Female qrange)
drop if Female == . | qrange == . 
gen sample = "2010-2019"

tempfile temp
save `temp', replace
	
use "`building_logit'"
append using `temp'
rename id numObs 
export delimited using "figures/logit_fellow_EMA_qrange.csv", replace

log off
log close 


