
clear

if !missing("$dropbox_dir") {
	local dropbox_dir = "$dropbox_dir"
}
else {
	local dropbox_dir "C:/Users/Chris/Dropbox"
}
cd "`dropbox_dir'/ECM_Fellow_Study/Replication"
log using "figures/figure3C.log", replace

use "`dropbox_dir'\ECM_Fellow_Study\Paper2\econ\output\regression_dataset_public.dta"

* take out the deceased authors
drop if (author == "Sherwin Rosen" & year >= death + 2 | dead == 1 & author != "Sherwin Rosen")
* take out the ambiguous gendered economists  
drop if Ambiguous == 1
* keep risk set only 
keep if (fellow_EMA==0|new_fellow_EMA==1)
drop if year < 1960

* author id 
qui egen id = group(author year)

* coefficients for levels of top5 and cites 
gen top5 = AER_cumulative+QJE_cumulative+REStud_cumulative+ECTA_cumulative+JPE_cumulative
gen top5_cite_cumulative=AER_cite_cumulative+QJE_cite_cumulative+REStud_cite_cumulative+ECTA_cite_cumulative+JPE_cite_cumulative

gen top5_1=(top5==1)
gen top5_2=(top5==2)
gen top5_3=(top5==3)
gen top5_4=(top5==4)
gen top5_5=(top5==5)
gen top5_6=(top5==6)
gen top5_7=(top5>=7)

gen ema_1=(ECTA_cumulative==1)
gen ema_2=(ECTA_cumulative==2)
gen ema_3=(ECTA_cumulative>=3)

gen res_1=(REStud_cumulative==1)
gen res_2=(REStud_cumulative==2)
gen res_3=(REStud_cumulative>=3)

gen qje_1=(QJE_cumulative==1)
gen qje_2=(QJE_cumulative==2)
gen qje_3=(QJE_cumulative>=3)

gen aer_1=(AER_cumulative==1)
gen aer_2=(AER_cumulative==2)
gen aer_3=(AER_cumulative>=3)

gen jpe_1=(JPE_cumulative==1)
gen jpe_2=(JPE_cumulative==2)
gen jpe_3=(JPE_cumulative>=3)

* levels of citation 
gen decade = . 
local list_decade 1940 1950 1960 1970 1980 1990 2000 2010 
foreach decade in `list_decade'{
	replace decade = `decade' if floor(year/10)*10 == `decade'
}
replace decade = 1930 if inrange(year, 1931, 1939)

gen if_top5=(top5>=1)
gen if_riskset = (fellow_EMA == 0 | new_fellow_EMA == 1)

gen n = 1 
gsort decade if_top5 if_riskset +top5_cite_cumulative

by decade if_top5 if_riskset: gen cumfreq = sum(n)
by decade if_top5 if_riskset: gen N = _N 
gen freq_cite = (cumfreq/N)*100

by decade if_top5 if_riskset top5_cite_cumulative: egen pctile_cite = max(freq_cite)
drop freq_cite N cumfreq n 

gen topcite1 = 0
gen topcite2 = 0 
gen topcite3 = 0 
gen topcite4 = 0 
gen topcite5 = 0 
gen topcite6 = 0 
gen topcite7 = 0 
gen topcite8 = 0

gen topcite = . 

levelsof decade, local(levels)
foreach d in `levels'{
	
	replace topcite1 = 1 if decade == `d' & pctile_cite < 50 & if_top5 == 1 & if_riskset == 1
	replace topcite2 = 1 if decade == `d' & pctile_cite >= 50 & pctile_cite < 70 & if_top5 == 1 & if_riskset == 1
	replace topcite3 = 1 if decade == `d' & pctile_cite >= 70 & pctile_cite < 80 & if_top5 == 1 & if_riskset == 1
	replace topcite4 = 1 if decade == `d' & pctile_cite >= 80 & pctile_cite < 90 & if_top5 == 1 & if_riskset == 1
	replace topcite5 = 1 if decade == `d' & pctile_cite >= 90 & pctile_cite < 95 & if_top5 == 1 & if_riskset == 1
	replace topcite6 = 1 if decade == `d' & pctile_cite >= 95 & pctile_cite < 97.5 & if_top5 == 1 & if_riskset == 1
	replace topcite7 = 1 if decade == `d' & pctile_cite >= 97.5 & pctile_cite < 99 & if_top5 == 1 & if_riskset == 1
	replace topcite8 = 1 if decade == `d' & pctile_cite >= 99 & if_top5 == 1 & if_riskset == 1
	
	replace topcite = 1 if decade == `d' & pctile_cite < 50 & if_top5 == 1 & if_riskset == 1
	replace topcite = 2 if decade == `d' & pctile_cite >= 50 & pctile_cite < 70 & if_top5 == 1 & if_riskset == 1
	replace topcite = 3 if decade == `d' & pctile_cite >= 70 & pctile_cite < 80 & if_top5 == 1 & if_riskset == 1
	replace topcite = 4 if decade == `d' & pctile_cite >= 80 & pctile_cite < 90 & if_top5 == 1 & if_riskset == 1
	replace topcite = 5 if decade == `d' & pctile_cite >= 90 & pctile_cite < 95 & if_top5 == 1 & if_riskset == 1
	replace topcite = 6 if decade == `d' & pctile_cite >= 95 & pctile_cite < 97.5 & if_top5 == 1 & if_riskset == 1
	replace topcite = 7 if decade == `d' & pctile_cite >= 97.5 & pctile_cite < 99 & if_top5 == 1 & if_riskset == 1
	replace topcite = 8 if decade == `d' & pctile_cite >= 99 & if_top5 == 1 & if_riskset == 1
	
	tab topcite if decade == `d' & if_top5 == 1 & if_riskset == 1
}

gen firstpub_10 = (years_firstpub < 20 & years_firstpub >= 10)
gen firstpub_20 = (years_firstpub < 30 & years_firstpub >= 20)
gen firstpub_30 = (years_firstpub >= 30)

drop decade topcite



* ==============================================================================
* logit model 
* ==============================================================================

* 1960-1979 	

unab model: AER_cumulative-TE_cumulative asinh*cites ///
top5_1-top5_7 ema_* res_* aer_* qje_* jpe_* ///
topcite2-topcite8 firstpub_10-firstpub_30 

preserve 

keep if inrange(year, 1960, 1979)

* basic model 
logit new_fellow_EMA `model' i.year if (fellow_EMA==0|new_fellow_EMA==1) & Female == 0, cluster(author)

* extract post-estimation y_hat 
predict prob_fellow_EMA
gen pred_log_odds_EMA = ln(prob_fellow_EMA/(1-prob_fellow_EMA))

* gen qrange 
egen p90_new_fellow_EMA = pctile(prob_fellow_EMA), p(90)
egen p95_new_fellow_EMA = pctile(prob_fellow_EMA), p(95)
egen p97_new_fellow_EMA = pctile(prob_fellow_EMA), p(97.5)
egen p99_new_fellow_EMA = pctile(prob_fellow_EMA), p(99)
	
sum p*_new_fellow_EMA

qui gen qrange = 1 if prob_fellow_EMA < p90_new_fellow_EMA ///
& !missing(prob_fellow_EMA)
qui replace qrange = 2 if prob_fellow_EMA >= p90_new_fellow_EMA & prob_fellow_EMA < p95_new_fellow_EMA ///
& !missing(prob_fellow_EMA)
qui replace qrange = 3 if prob_fellow_EMA >= p95_new_fellow_EMA & prob_fellow_EMA < p97_new_fellow_EMA ///
& !missing(prob_fellow_EMA)
qui replace qrange = 4 if prob_fellow_EMA >= p97_new_fellow_EMA & prob_fellow_EMA < p99_new_fellow_EMA ///
& !missing(prob_fellow_EMA)
qui replace qrange = 5 if prob_fellow_EMA >= p99_new_fellow_EMA & !missing(prob_fellow_EMA)

* regressions
eststo labor_qrange_1960_1: logit new_fellow_EMA pred_log_odds_EMA if (fellow_EMA==0|new_fellow_EMA==1), cluster(author)
eststo labor_qrange_1960_2: logit new_fellow_EMA pred_log_odds_EMA Female if (fellow_EMA==0|new_fellow_EMA==1), cluster(author)
eststo labor_qrange_1960_3: logit new_fellow_EMA pred_log_odds_EMA c.Female#i.qrange if (fellow_EMA==0|new_fellow_EMA==1), cluster(author)
eststo labor_qrange_1960_4: logit new_fellow_EMA pred_log_odds_EMA i.qrange i.qrange#c.Female ///
if (fellow_EMA==0|new_fellow_EMA==1), cluster(author)

restore 
	
* 1980-1999 
preserve 
keep if inrange(year, 1980, 1999)

* basic model 
logit new_fellow_EMA `model' i.year if (fellow_EMA==0|new_fellow_EMA==1) & Female == 0, cluster(author)

* extract post-estimation y_hat 
predict prob_fellow_EMA
gen pred_log_odds_EMA = ln(prob_fellow_EMA/(1-prob_fellow_EMA))

* gen qrange 
egen p90_new_fellow_EMA = pctile(prob_fellow_EMA), p(90)
egen p95_new_fellow_EMA = pctile(prob_fellow_EMA), p(95)
egen p97_new_fellow_EMA = pctile(prob_fellow_EMA), p(97.5)
egen p99_new_fellow_EMA = pctile(prob_fellow_EMA), p(99)
	
sum p*_new_fellow_EMA

qui gen qrange = 1 if prob_fellow_EMA < p90_new_fellow_EMA ///
& !missing(prob_fellow_EMA)
qui replace qrange = 2 if prob_fellow_EMA >= p90_new_fellow_EMA & prob_fellow_EMA < p95_new_fellow_EMA ///
& !missing(prob_fellow_EMA)
qui replace qrange = 3 if prob_fellow_EMA >= p95_new_fellow_EMA & prob_fellow_EMA < p97_new_fellow_EMA ///
& !missing(prob_fellow_EMA)
qui replace qrange = 4 if prob_fellow_EMA >= p97_new_fellow_EMA & prob_fellow_EMA < p99_new_fellow_EMA ///
& !missing(prob_fellow_EMA)
qui replace qrange = 5 if prob_fellow_EMA >= p99_new_fellow_EMA & !missing(prob_fellow_EMA)

* regressions
eststo labor_qrange_1980_1: logit new_fellow_EMA pred_log_odds_EMA if (fellow_EMA==0|new_fellow_EMA==1), cluster(author)
eststo labor_qrange_1980_2: logit new_fellow_EMA pred_log_odds_EMA Female if (fellow_EMA==0|new_fellow_EMA==1), cluster(author)
eststo labor_qrange_1980_3: logit new_fellow_EMA pred_log_odds_EMA c.Female#i.qrange if (fellow_EMA==0|new_fellow_EMA==1), cluster(author)
eststo labor_qrange_1980_4: logit new_fellow_EMA pred_log_odds_EMA i.qrange i.qrange#c.Female ///
if (fellow_EMA==0|new_fellow_EMA==1), cluster(author)

restore 


* 2000+ 

preserve 
keep if inrange(year, 2000, 2019)

* basic model 
logit new_fellow_EMA `model' i.year if (fellow_EMA==0|new_fellow_EMA==1) & Female == 0, cluster(author)
	
* extract post-estimation y_hat 
predict prob_fellow_EMA
gen pred_log_odds_EMA = ln(prob_fellow_EMA/(1-prob_fellow_EMA))

* gen qrange 
egen p90_new_fellow_EMA = pctile(prob_fellow_EMA), p(90)
egen p95_new_fellow_EMA = pctile(prob_fellow_EMA), p(95)
egen p97_new_fellow_EMA = pctile(prob_fellow_EMA), p(97.5)
egen p99_new_fellow_EMA = pctile(prob_fellow_EMA), p(99)
	
sum p*_new_fellow_EMA

qui gen qrange = 1 if prob_fellow_EMA < p90_new_fellow_EMA ///
& !missing(prob_fellow_EMA)
qui replace qrange = 2 if prob_fellow_EMA >= p90_new_fellow_EMA & prob_fellow_EMA < p95_new_fellow_EMA ///
& !missing(prob_fellow_EMA)
qui replace qrange = 3 if prob_fellow_EMA >= p95_new_fellow_EMA & prob_fellow_EMA < p97_new_fellow_EMA ///
& !missing(prob_fellow_EMA)
qui replace qrange = 4 if prob_fellow_EMA >= p97_new_fellow_EMA & prob_fellow_EMA < p99_new_fellow_EMA ///
& !missing(prob_fellow_EMA)
qui replace qrange = 5 if prob_fellow_EMA >= p99_new_fellow_EMA & !missing(prob_fellow_EMA)

* regressions 
eststo labor_qrange_2000_1: logit new_fellow_EMA pred_log_odds_EMA if (fellow_EMA==0|new_fellow_EMA==1), cluster(author)
eststo labor_qrange_2000_2: logit new_fellow_EMA pred_log_odds_EMA Female if (fellow_EMA==0|new_fellow_EMA==1), cluster(author)
eststo labor_qrange_2000_3: logit new_fellow_EMA pred_log_odds_EMA c.Female#i.qrange if (fellow_EMA==0|new_fellow_EMA==1), cluster(author)
eststo labor_qrange_2000_4: logit new_fellow_EMA pred_log_odds_EMA i.qrange i.qrange#c.Female ///
if (fellow_EMA==0|new_fellow_EMA==1), cluster(author)

restore 


* output file 
esttab labor_qrange_1960_2 labor_qrange_1960_3 labor_qrange_1960_4 ///
labor_qrange_1980_2 labor_qrange_1980_3 labor_qrange_1980_4 ///
labor_qrange_2000_2 labor_qrange_2000_3 labor_qrange_2000_4 using "figures/reg_qrange_labor.csv", ///
csv se(%9.3f) b(%9.3f) pr2 scalars(N) sfmt(%9.0fc) extracols(4 8 12) ///
title("Figure 3 Regressions") nogaps nodepvars nostar label replace

log off
log close 


