* figure 4

clear 
if !missing("$dropbox_dir") {
	local dropbox_dir = "$dropbox_dir"
}
else {
	local dropbox_dir "C:/Users/Chris/Dropbox"
}
cd "`dropbox_dir'/ECM_Fellow_Study/Replication"
use "`dropbox_dir'\ECM_Fellow_Study\Paper2\econ\output\regression_dataset.dta"

cap log close
log using "figures/figure4.log", replace

rename byCommittee byCommitty

drop if year < 1960 | year == . | missing(nominee) /* drop if before 1960 or unmatched */
drop if Ambiguous == 1 /* take out unknown gender */
drop if (author == "Sherwin Rosen" & year >= death + 2 | dead == 1 & author != "Sherwin Rosen")

gen ecta_restud = ECTA_cumulative + REStud_cumulative 
gen top_5 = ecta_restud + AER_cumulative + QJE_cumulative + JPE_cumulative 
gen aqj = AER_cumulative + QJE_cumulative + JPE_cumulative

gen byFellow = (byCommitty == 0)
replace byFellow = . if byCommitty == .

gen asnyf = (fellow_EMA == 0)
gen f_asnyf = (fellow_EMA == 0 & Female == 1)

gen ecta_restud_asnyf = (asnyf == 1 & ecta_restud >= 1)
gen f_ecta_restud_asnyf = (f_asnyf == 1 & ecta_restud_asnyf == 1)

gen top5_asnyf = (asnyf == 1 & top_5 >= 3)
gen f_top5_asnyf = (f_asnyf == 1 & top5_asnyf == 1)

gen aqj_asnyf = (asnyf == 1 & aqj >= 1)
gen f_aqj_asnyf = (f_asnyf == 1 & aqj_asnyf == 1)

gen qje_asnyf = (asnyf == 1 & QJE_cumulative >= 1)
gen f_qje_asnyf = (f_asnyf == 1 & QJE_cumulative == 1)

gen new_ema=new_fellow_EMA
gen f_new_ema=Female*new_ema

gen f_nominee = (Female == 1 & nominee == 1) 

gen nominee_byCommitty = (byCommitty == 1 & nominee == 1) 
gen f_nominee_byCommitty = (nominee_byCommitty == 1 & Female == 1)

gen nominee_byFellow = (byFellow == 1 & nominee == 1)
gen f_nominee_byFellow = (nominee_byFellow == 1 & Female == 1)

gen elect_nominee_byCommitty = (nominee_byCommitty == 1 & new_fellow_EMA == 1)
gen elect_f_nominee_byCommitty = (elect_nominee_byCommitty & Female == 1)

gen elect_nominee_byFellow = (nominee_byFellow == 1 & new_fellow_EMA == 1)
gen elect_f_nominee_byFellow = (elect_nominee_byFellow == 1 & Female == 1)


local sum_stat asnyf f_asnyf ecta_restud_asnyf f_ecta_restud_asnyf top5_asnyf f_top5_asnyf ///
	  aqj_asnyf f_aqj_asnyf qje_asnyf f_qje_asnyf new_ema f_new_ema ///
	  nominee f_nominee nominee_byCommitty f_nominee_byCommitty nominee_byFellow f_nominee_byFellow ///
	  elect_nominee_byCommitty elect_f_nominee_byCommitty elect_nominee_byFellow elect_f_nominee_byFellow
	  
sum `sum_stat'


collapse (sum) `sum_stat', by(year)

* gen share vars 
local varlist asnyf ecta_restud_asnyf top5_asnyf aqj_asnyf qje_asnyf ///
	  new_ema nominee nominee_byCommitty nominee_byFellow 
	  
foreach var in `varlist'{
	
	gen fshare_`var' = f_`var'/`var'
}


local varlist nominee_byCommitty f_nominee_byCommitty nominee_byFellow f_nominee_byFellow

foreach var in `varlist'{
	
	gen share_elect_`var' = elect_`var'/`var'
}


drop f_* 
drop elect_* 
sort year 
order year asnyf fshare_asnyf ecta_restud_asnyf fshare_ecta_restud_asnyf ///
top5_asnyf fshare_top5_asnyf aqj_asnyf fshare_aqj_asnyf qje_asnyf fshare_qje_asnyf ///
new_ema fshare_new_ema nominee fshare_nominee ///
nominee_byCommitty fshare_nominee_byCommitty nominee_byFellow fshare_nominee_byFellow ///
share_elect_nominee_byCommitty share_elect_f_nominee_byCommitty share_elect_nominee_byFellow share_elect_f_nominee_byFellow


label var fshare_asnyf "share female of ASNYF in year t"
label var fshare_ecta_restud_asnyf  "share female among ASNYF with  at least 1 ECTA or RESTUD"
label var fshare_top5_asnyf "share female among ASNYF with at least 3 top 5"
label var fshare_aqj_asnyf "share female among ASNYF with at least 1 AER/QJE/JPE"
label var fshare_qje_asnyf "share female among ASNYF with at least 1 QJE"
label var fshare_new_ema "share female among new fellows in year t"
label var fshare_nominee "share female among nominees in year t"
label var fshare_nominee_byCommitty "share female among nominees BY COMMITTEE in year t"
label var fshare_nominee_byFellow "share female among nominees BY FELLOWS in year t"
label var asnyf "total # of active-scholars-not-yet-fellows (ASNYF) in year t (t>=1960) "
label var ecta_restud_asnyf "total # of ASNYF's in year t who have at least 1 ECTA or RESTUD"
label var top5_asnyf "total # of ASNYF's in year t who have at least 3 top 5"
label var aqj_asnyf "total # of ASNYF's in year t who have at least 1 AER/QJE/JPE"
label var qje_asnyf "total # of ASNYF's in year t who have at least 1 QJE"
label var new_ema "total # new fellows in year t"
label var nominee "total # nominated for fellow in year t"
label var nominee_byCommitty "total # nominated BY COMMITTEE for fellow in year t"
label var nominee_byFellow "total # nominated BY FELLOWS for fellow in year t"
label var share_elect_nominee_byFellow "share of all fellow nominees that are elected"
label var share_elect_f_nominee_byFellow "share of all FEMALE fellow nominees that are elected"
label var share_elect_nominee_byCommitty "share of all committee nominees that are elected"
label var share_elect_f_nominee_byCommitty "share of all FEMALE committee nominees that are elected"

keep new_ema fshare_new_ema nominee fshare_nominee nominee_byCommitty fshare_nominee_byCommitty nominee_byFellow fshare_nominee_byFellow

compress 
save "figures/figure4.dta", replace
export excel "figures/figure4.xlsx", replace

log off 

log close 
