* figure 5

clear 
if !missing("$dropbox_dir") {
	local dropbox_dir = "$dropbox_dir"
}
else {
	local dropbox_dir "C:/Users/Chris/Dropbox"
}
cd "`dropbox_dir'/ECM_Fellow_Study/Replication"
use "`dropbox_dir'\ECM_Fellow_Study\Paper2\econ\output\regression_dataset.dta"

cap log close
log using "figures/figure5.log", replace

rename byCommittee byCommitty

drop if Ambiguous == 1 
drop if (author == "Sherwin Rosen" & year >= death + 2 | dead == 1 & author != "Sherwin Rosen")
drop if year < 1960 | year == . | missing(nominee) /* drop if before 1960 or unmatched */

gen byFellow = (byCommitty == 0)
replace byFellow = . if byCommitty == .

** regions / institutions 
gen UStop5 = (location == "US Top 5")
gen UStop17 = (location == "US 6-17")
gen USother = (location == "US Below 17")
gen Europe = (location == "Europe")
gen AsiaAustr = (location == "Asia/Australia")
gen LatinAfrica = (location == "Latin America/Africa")

gen minority = (AsiaAustr == 1 |LatinAfrica == 1)

** fellowships ** 
gen new_ema=new_fellow_EMA
gen m_new_ema=minority*new_ema

gen m_nominee = (minority == 1 & nominee == 1) 

gen nominee_byCommitty = (byCommitty == 1 & nominee == 1) 
gen m_nominee_byCommitty = (nominee_byCommitty == 1 & minority == 1)

gen nominee_byFellow = (byFellow == 1 & nominee == 1)
gen m_nominee_byFellow = (nominee_byFellow == 1 & minority == 1)

gen elect_nominee_byCommitty = (nominee_byCommitty == 1 & new_fellow_EMA == 1)
gen elect_m_nominee_byCommitty = (elect_nominee_byCommitty & minority == 1)

gen elect_nominee_byFellow = (nominee_byFellow == 1 & new_fellow_EMA == 1)
gen elect_m_nominee_byFellow = (elect_nominee_byFellow == 1 & minority == 1)


local sum_stat new_ema m_new_ema nominee m_nominee ///
	  nominee_byCommitty m_nominee_byCommitty nominee_byFellow m_nominee_byFellow ///
	  elect_nominee_byCommitty elect_m_nominee_byCommitty elect_nominee_byFellow elect_m_nominee_byFellow
	  
sum `sum_stat'


collapse (sum) `sum_stat', by(year)


* gen share vars 
local varlist new_ema nominee nominee_byCommitty nominee_byFellow 
	  
foreach var in `varlist'{
	
	gen mshare_`var' = m_`var'/`var'
}


local varlist nominee_byCommitty m_nominee_byCommitty nominee_byFellow m_nominee_byFellow

foreach var in `varlist'{
	
	gen share_elect_`var' = elect_`var'/`var'
}


drop elect_* 
sort year 
order year new_ema mshare_new_ema nominee mshare_nominee nominee_byCommitty mshare_nominee_byCommitty ///
	nominee_byFellow mshare_nominee_byFellow ///
	share_elect_nominee_byCommitty share_elect_m_nominee_byCommitty share_elect_nominee_byFellow share_elect_m_nominee_byFellow


label var mshare_new_ema "share minority among new fellows in year t"
label var mshare_nominee "share minority among nominees in year t"
label var mshare_nominee_byCommitty "share minority among nominees BY COMMITTEE in year t"
label var mshare_nominee_byFellow "share minority among nominees BY FELLOWS in year t"
label var new_ema "total # new fellows in year t"
label var nominee "total # nominated for fellow in year t"
label var nominee_byCommitty "total # nominated BY COMMITTEE for fellow in year t"
label var nominee_byFellow "total # nominated BY FELLOWS for fellow in year t"
label var share_elect_nominee_byFellow "share of all fellow nominees that are elected"
label var share_elect_m_nominee_byFellow "share of all minority fellow nominees that are elected"
label var share_elect_nominee_byCommitty "share of all committee nominees that are elected"
label var share_elect_m_nominee_byCommitty "share of all minority committee nominees that are elected"


compress 
save "figures/figure5.dta", replace
export excel "figures/figure5.xlsx", replace

log off 

log close 
