* Table 1 

eststo clear
clear

if !missing("$dropbox_dir") {
	local dropbox_dir = "$dropbox_dir"
}
else {
	local dropbox_dir "C:/Users/Chris/Dropbox"
}
cd "`dropbox_dir'/ECM_Fellow_Study/Replication"
use "`dropbox_dir'\ECM_Fellow_Study\Paper2\econ\output\regression_dataset_public.dta"

cap log close 
log using "tables/table1.log", replace

* exclude deceased authors
drop if (author == "Sherwin Rosen" & year >= death + 2 | dead == 1 & author != "Sherwin Rosen")

* do not count secondary NAS
replace new_fellow_NAS = 0 if primary_NAS == 0
replace fellow_NAS = 0 if primary_NAS == 0

* do not count secondary AAAS
replace new_fellow_AAAS = 0 if AAAS_flags == 3
replace fellow_AAAS = 0 if AAAS_flags == 3
* keep fellows 1931+
replace fellow_AAAS = 0 if year_appointed_AAAS < 1931

* generate first initial variable
split author, parse(" ")
local nsplit = r(nvars)
gen first_initial = (strlen(author1) == 2 & strpos(author1, ".")) | (strlen(author1) == 1)
gen Ambig_first_initial = (Ambiguous == 1 & first_initial == 1)
gen Ambig_full_name = (Ambiguous == 1 & first_initial != 1)
drop author1-author`nsplit'
* cumulative publication variables 
gen JEP_JEL_cumulative = JEP_cumulative + JEL_cumulative 
gen ECA_IER_cumulative = ECA_cumulative + IER_cumulative 
gen Theory_cumulative = JET_cumulative + ET_cumulative + GEB_cumulative + IJGT_cumulative + JMathE_cumulative + TE_cumulative 
gen Econometrics_cumulative = EcT_cumulative + JE_cumulative + JASA_cumulative 
gen Macro_cumulative = AEJ_Macro_cumulative + JME_cumulative 
gen Public_cumulative = JPubE_cumulative + AEJ_Policy_cumulative

* gen year range variable
gen decade = "." /* drop if not in the range */
replace decade = "1933-1979" if inrange(year, 1933, 1979) /* pre - 1980 */
replace decade = "1980-1999" if inrange(year, 1980, 1999)
replace decade = "2000-2019" if inrange(year, 2000, 2019)
drop if decade == "."

bysort author decade: gen id = (_n == 1) /* number of unique authors in each decade */

* summary stat locals 
local fellowships fellow_EMA fellow_AAAS fellow_NAS fellow_AEAF fellow_Sloan 

local pubstat ECTA_cumulative REStud_cumulative AER_cumulative QJE_cumulative JPE_cumulative ///
ECTA_cite_cumulative REStud_cite_cumulative AER_cite_cumulative QJE_cite_cumulative JPE_cite_cumulative ///
JEP_JEL_cumulative AERPP_cumulative JEEA_cumulative EJ_cumulative REStat_cumulative ECA_IER_cumulative ///
Theory_cumulative Econometrics_cumulative AEJ_Micro_cumulative Macro_cumulative AEJ_Applied_cumulative QE_cumulative ///
JDE_cumulative JF_cumulative JHE_cumulative JEH_cumulative JIE_cumulative RAND_cumulative JOLE_cumulative Public_cumulative ///
years_firstpub 

* ==============================================================================
* summary statistics 
levelsof decade, local(levels) 

foreach decade in `levels'{	
	
	local years = substr("`decade'", 1, 4)+"_"+substr("`decade'", 6, 9)
	
	* gender summary statistics
	eststo f_`years': qui estpost tabstat Female Ambig_first_initial Ambig_full_name ///
	if decade == "`decade'", s(mean) c(statistics) listwise
	
	* fellowship specific summary statistics
	eststo tab1_`years': qui estpost tabstat `fellowships' ///
	if decade == "`decade'", s(mean) c(statistics) listwise
	
	* journal specific summary statistics
	eststo tab2_`years': qui estpost tabstat `pubstat' ///
	if decade == "`decade'", s(mean) c(statistics) listwise
	
	* journal specific summary statistics
	eststo tab3_`years': qui estpost tabstat id ///
	if decade == "`decade'", s(sum) c(statistics) listwise
	
	local list_gender Male Female 
	
	foreach gender in `list_gender'{
				
		local g = lower("`gender'")
		
		eststo f_`years'_`g': qui estpost tabstat Female Ambig_first_initial Ambig_full_name ///
		if decade == "`decade'" & `gender' == 1, s(mean) c(statistics) listwise
		
		eststo tab1_`years'_`g': qui estpost tabstat `fellowships' ///
		if decade == "`decade'" & `gender' == 1, s(mean) c(statistics) listwise
		
		eststo tab2_`years'_`g': qui estpost tabstat `pubstat' ///
		if decade == "`decade'" & `gender' == 1, s(mean) c(statistics) listwise
		
		eststo tab3_`years'_`g': qui estpost tabstat id ///
		if decade == "`decade'" & `gender' == 1, s(sum) c(statistics) listwise
		
	}
	
}

* ==============================================================================
* output file 

label variable Female "Percent Female"
label variable Ambiguous "Percent Unknown Gender"
label variable Ambig_first_initial "Percent Unknown First Initial Name"
label variable Ambig_full_name "Percent Unknown Full First Name"
label variable fellow_EMA "Fellow of Econometric Society (1933-2019)"
label variable fellow_AAAS "Fellow of AAAS (1942-2019)"
label variable fellow_NAS "Fellow of NAS (1968-2019)"
label variable fellow_AEAF "Fellow of AEA (1965-2019)"
label variable fellow_Sloan "Sloan Fellow (1981-2019)"

label variable ECTA_cite_cumulative "Econometrica"
label variable REStud_cite_cumulative "REStud"
label variable AER_cite_cumulative "AER"
label variable QJE_cite_cumulative "QJE"
label variable JPE_cite_cumulative "JPE"

label variable ECTA_cumulative "Econometrica"
label variable REStud_cumulative "REStud"
label variable AER_cumulative "AER"
label variable QJE_cumulative "QJE"
label variable JPE_cumulative "JPE"

label variable JEEA_cumulative "JEEA"
label variable EJ_cumulative "EJ"
label variable REStat_cumulative "REStat"
label variable AEJ_Micro_cumulative "Micro (AEJMicro)"
label variable AEJ_Applied_cumulative "AEJApplied"
label variable QE_cumulative "QE"
label variable JDE_cumulative "Development (JDE)"
label variable JF_cumulative "Finance (JF)"
label variable JHE_cumulative "Health (JHE)"
label variable JEH_cumulative "History (JEH)"
label variable JIE_cumulative "International (JIE)"
label variable RAND_cumulative "Industrial Organization (RAND)"
label variable JOLE_cumulative "Labor (JoLE)"

label variable JEP_JEL_cumulative "JEP+JEL"
label variable AERPP_cumulative "AER (AEA) Papers and Proceedings"
label variable ECA_IER_cumulative "Economica+IER"
label variable Theory_cumulative "Theory (JET+ET+GEB+IJGT+JMathE)"
label variable Econometrics_cumulative "Econometrics (EcT+JEc+JASA)"
label variable Macro_cumulative "Macro (AEJMacro+JME)"
label variable Public_cumulative "Public (JPubE+AEJPolicy)"

label variable id "Number of Authors"


local numbers ",'(1),'(2),'(3),,'(4),'(5),'(6),,'(7),'(8),'(9)"
esttab f_1933_1979* f_1980_1999* f_2000_2019* using "tables/table1.csv", ///
main(mean %12.4fc) nodepvars noobs nostar unstack nonote nogaps nonumbers onecell eqlabels(none) ///
title("TABLE I") ///
mgroups(1933-1979 1980-1999 2000-2019, pattern(1 0 0 1 0 0 1 0 0)) ///
mtitles("All" "Male" "Female" "All" "Male" "Female" "All" "Male" "Female") posthead(`numbers') ///
extracols(4 7 10) label replace 

esttab tab1_1933_1979* tab1_1980_1999* tab1_2000_2019* using "tables/table1.csv", ///
main(mean %12.4fc) nodepvars noobs nostar unstack nonote nonumbers nogaps onecell nomtitle eqlabels(none) ///
refcat(fellow_EMA "Fellowships (at Election)", nolabel) ///
extracols(4 7 10) label append 

esttab tab2_1933_1979* tab2_1980_1999* tab2_2000_2019* using "tables/table1.csv", ///
unstack main(mean %12.2fc) nodepvars nostar nomtitle nonumbers nonote nogaps onecell ///
refcat(ECTA_cumulative "Cumulative publications in top-5 journals" ECTA_cite_cumulative "Cum. citations in top-5 journals" JEP_JEL_cumulative "Cum. publications in general interest journals" Theory_cumulative "Cum. publications in field journals" years_firstpub "", nolabel) ///
extracols(4 7 10) label append 

esttab tab3_1933_1979* tab3_1980_1999* tab3_2000_2019* using "tables/table1.csv", ///
unstack main(sum) nodepvars nostar noobs nomtitle nonumbers nonote nogaps onecell ///
refcat(id "", nolabel) ///
extracols(4 7 10) label append 


** rescale shares to percentages
import delimited "tables/table1.csv", clear

* define locals to convert to percentage
local Female "Percent Female"
local Ambiguous "Percent Unknown Gender"
local Ambig_first_initial "Percent Unknown First Initial Name"
local Ambig_full_name "Percent Unknown Full First Name"
local fellow_EMA "Fellow of Econometric Society (1933-2019)"
local fellow_AAAS "Fellow of AAAS (1942-2019)"
local fellow_NAS "Fellow of NAS (1968-2019)"
local fellow_AEAF "Fellow of AEA (1965-2019)"
local fellow_Sloan "Sloan Fellow (1981-2019)"

* Convert to percent 
foreach var in v2 v3 v4 v6 v7 v8 v10 v11 v12 {

	replace `var' = subinstr(`var', ".", "", .) ///
		if strpos(v1, "`Female'") | strpos(v1, "`Ambiguous'") ///
		 | strpos(v1, "`Ambig_first_initial'") | strpos(v1, "`Ambig_full_name'") ///
		 | strpos(v1, "`fellow_EMA'") | strpos(v1, "`fellow_AAAS'") ///
		 | strpos(v1, "`fellow_NAS'") | strpos(v1, "`fellow_AEAF'") | strpos(v1, "`fellow_Sloan'")
	replace `var' = substr(`var', 1, 5) + "." + substr(`var', 6, 9) ///
		if strpos(v1, "`Female'") | strpos(v1, "`Ambiguous'") ///
		 | strpos(v1, "`Ambig_first_initial'") | strpos(v1, "`Ambig_full_name'") ///
		 | strpos(v1, "`fellow_EMA'") | strpos(v1, "`fellow_AAAS'") ///
		 | strpos(v1, "`fellow_NAS'") | strpos(v1, "`fellow_AEAF'") | strpos(v1, "`fellow_Sloan'")
}
export delimited "tables/table1.csv", replace
log close 
