* table 3

clear 
eststo clear

if !missing("$dropbox_dir") {
	local dropbox_dir = "$dropbox_dir"
}
else {
	local dropbox_dir "C:/Users/Chris/Dropbox"
}
cd "`dropbox_dir'/ECM_Fellow_Study/Replication"
use "`dropbox_dir'\ECM_Fellow_Study\Paper2\econ\output\regression_dataset.dta"

cap log close 
log using "tables/table3.log", replace

* ==============================================================================

* exclude deceased authors
drop if (author == "Sherwin Rosen" & year >= death + 2 | dead == 1 & author != "Sherwin Rosen")


* cumulative publication variables 

gen JEP_JEL_cumulative = JEP_cumulative + JEL_cumulative 

gen ECA_IER_cumulative = ECA_cumulative + IER_cumulative 

gen Theory_cumulative = JET_cumulative + ET_cumulative + GEB_cumulative + IJGT_cumulative + JMathE_cumulative + TE_cumulative 

gen Econometrics_cumulative = EcT_cumulative + JE_cumulative + JASA_cumulative 

gen Macro_cumulative = AEJ_Macro_cumulative + JME_cumulative 

gen Public_cumulative = JPubE_cumulative + AEJ_Policy_cumulative

gen Micro_cumulative = AEJ_Applied_cumulative + JOLE_cumulative + JEH_cumulative + JHE_cumulative + JPubE_cumulative + JDE_cumulative + AEJ_Policy_cumulative 

** regions / institutions 
gen UStop5 = (location == "US Top 5")
gen UStop17 = (location == "US 6-17")
gen USother = (location == "US Below 17")
gen Europe = (location == "Europe")
gen AsiaAustr = (location == "Asia/Australia")
gen LatinAfrica = (location == "Latin America/Africa")

** byFellow / byCommittee
gen byFellow = 1 if byCommittee == 0 
replace byFellow = 0 if byCommittee == 1 

* endorsement missing encode 
replace numEndorsed = . if numEndorsed == 0 

* time intervals 
gen decade = "." /* drop if not in the range */
replace decade = "1990-2005" if inrange(year, 1990, 2005) 
replace decade = "2006-2019" if inrange(year, 2006, 2019)
drop if decade == "."

* ==============================================================================
* reg locals 

levelsof decade, local(levels)

local sumstat ECTA_cumulative REStud_cumulative AER_cumulative QJE_cumulative JPE_cumulative ///
ECTA_cite_cumulative REStud_cite_cumulative AER_cite_cumulative QJE_cite_cumulative JPE_cite_cumulative ///
Theory_cumulative Econometrics_cumulative Micro_cumulative years_firstpub

local region UStop5 UStop17 USother Europe AsiaAustr LatinAfrica 

local fellowships fellow_AAAS fellow_NAS fellow_AEAF fellow_Sloan

local sumstat_extended ECTA_cumulative REStud_cumulative AER_cumulative QJE_cumulative JPE_cumulative ///
ECTA_cite_cumulative REStud_cite_cumulative AER_cite_cumulative QJE_cite_cumulative JPE_cite_cumulative ///
JEP_JEL_cumulative AERPP_cumulative JEEA_cumulative EJ_cumulative REStat_cumulative ECA_IER_cumulative ///
Theory_cumulative Econometrics_cumulative AEJ_Micro_cumulative Macro_cumulative AEJ_Applied_cumulative QE_cumulative ///
JDE_cumulative JF_cumulative JHE_cumulative JEH_cumulative JIE_cumulative RAND_cumulative JOLE_cumulative Public_cumulative ///
years_firstpub


* ==============================================================================
* summary statistics

local new_fellow new_fellow_EMA nominee

foreach new_fellow in `new_fellow'{
	
	foreach decade in `levels'{
		
		preserve 
		
		keep if `new_fellow' == 1 & decade == "`decade'" 
		
		* count unique author 
		bysort author: gen count_author = (_n == 1)
			
		local fellow = substr("`new_fellow'", strrpos("`new_fellow'", "_")+1, .)
		
		local year = substr("`decade'", 1, 4)
		
		
		* nominee statistics
		* numVotes is only available for 2006+ data 
		if "`decade'" == "1990-2005"{
			
			eststo `fellow'_1_`year': qui estpost tabstat byFellow byCommittee numEndorsed ///
			if decade == "`decade'", s(mean) c(statistics) /* Male Only */
			
			eststo `fellow'_1m_`year': qui estpost tabstat byFellow byCommittee numEndorsed ///
			if Male == 1 & decade == "`decade'", s(mean) c(statistics) /* Male Only */
		
			eststo `fellow'_1f_`year': qui estpost tabstat byFellow byCommittee numEndorsed ///
			if Female == 1 & decade == "`decade'", s(mean) c(statistics) /* Female Only */
			
			} 
		else if "`decade'" == "2006-2019"{
			
			eststo `fellow'_1_`year': qui estpost tabstat byFellow byCommittee numVotes numEndorsed ///
			if decade == "`decade'", s(mean) c(statistics) /* Male Only */
			
			eststo `fellow'_1m_`year': qui estpost tabstat byFellow byCommittee numVotes numEndorsed ///
			if Male == 1 & decade == "`decade'", s(mean) c(statistics) /* Male Only */
		
			eststo `fellow'_1f_`year': qui estpost tabstat byFellow byCommittee numVotes numEndorsed ///
			if Female == 1 & decade == "`decade'", s(mean) c(statistics) /* Female Only */
			
			}
		
		
		* regions 
		eststo `fellow'_2_`year': qui estpost tabstat `region' ///
		if decade == "`decade'", statistics(mean) columns(statistics)  
		
		eststo `fellow'_2m_`year': qui estpost tabstat `region' ///
		if Male == 1 & decade == "`decade'", statistics(mean) columns(statistics)  
		
		eststo `fellow'_2f_`year': qui estpost tabstat `region' ///
		if Female == 1 & decade == "`decade'", statistics(mean) columns(statistics)  
		
		* journal stats 
		eststo `fellow'_3_`year': qui estpost tabstat `sumstat' ///
		if decade == "`decade'", statistics(mean) columns(statistics) listwise 
		
		eststo `fellow'_3m_`year': qui estpost tabstat `sumstat' ///
		if Male == 1 & decade == "`decade'", statistics(mean) columns(statistics) listwise 
		
		eststo `fellow'_3f_`year': qui estpost tabstat `sumstat' ///
		if Female == 1 & decade == "`decade'", statistics(mean) columns(statistics) listwise 
				
		
		* unique number of authors 
		eststo `fellow'_4m_`year': qui estpost tabstat count_author  ///
		if Male == 1 & decade == "`decade'", statistics(sum) columns(statistics) listwise 
		
		eststo `fellow'_4f_`year': qui estpost tabstat count_author ///
		if Female == 1 & decade == "`decade'", statistics(sum) columns(statistics) listwise 
		
		restore 
				
	}
		
}

	
* ==============================================================================
* some labeling 

* gender variables 
label variable Female "Fraction Female"

* fellowship variables
label variable fellow_AAAS "Fellow of AAAS (1942-2019)"
label variable fellow_NAS "Fellow of NAS (1968-2019)"
label variable fellow_AEAF "Fellow of AEA (1965-2019)"
label variable fellow_Sloan "Sloan Fellow (1981-2019)"

label variable JEP_JEL_cumulative "JEP+JEL"
label variable AERPP_cumulative "AER (AEA) Papers and Proceedings"
label variable ECA_IER_cumulative "Economica+IER"
label variable Theory_cumulative "Theory (JET+ET+GEB+IJGT+JMaE)"
label variable Econometrics_cumulative "Econometrics (EcT+JEc+JASA)"
label variable Macro_cumulative "Macro (AEJMacro+JME)"
label variable Public_cumulative "Public (JPubE+AEJPolicy)"
label variable Micro_cumulative "Empirical Micro (AEJApplied+JoLE+JEH+JHE+JPube+JDE+AEJPolicy)"
label variable ECTA_cite_cumulative "Econometrica"
label variable REStud_cite_cumulative "REStud"
label variable AER_cite_cumulative "AER"
label variable QJE_cite_cumulative "QJE"
label variable JPE_cite_cumulative "JPE"

label variable ECTA_cumulative "Econometrica"
label variable REStud_cumulative "REStud"
label variable AER_cumulative "AER"
label variable QJE_cumulative "QJE"
label variable JPE_cumulative "JPE"

label variable JEEA_cumulative "JEEA"
label variable EJ_cumulative "EJ"
label variable REStat_cumulative "REStat"
label variable AEJ_Micro_cumulative "Micro (AEJMicro)"
label variable AEJ_Applied_cumulative "AEJApplied"
label variable QE_cumulative "QE"
label variable JDE_cumulative "Development (JDE)"
label variable JF_cumulative "Finance (JF)"
label variable JHE_cumulative "Health (JHE)"
label variable JEH_cumulative "History (JEH)"
label variable JIE_cumulative "International (JIE)"
label variable RAND_cumulative "Industrial Organization (RAND)"
label variable JOLE_cumulative "Labor (JoLE)"

label variable UStop5 "Percent US Top5"
label variable UStop17 "Percent US Top17"
label variable USother "Percent US non-Top17"
label variable Europe "Percent Europe"
label variable AsiaAustr "Percent Asia and Australia"
label variable LatinAfrica "Percent Latin America and Africa"

label variable byFellow "Percent Nominated by Fellows (1995-)"
label variable byCommittee "Percent Nominated by Committee (1995-)"
label variable numVotes "Number of Votes (2006-)"
label variable numEndorsed "Number of Endorsements (if nom. By Fellows)"
	

* ==============================================================================
* export 

local output1 nominee_1m_1990 nominee_1f_1990 nominee_1m_2006 nominee_1f_2006 EMA_1m_1990 EMA_1f_1990 EMA_1m_2006 EMA_1f_2006

local output2 nominee_2m_1990 nominee_2f_1990 nominee_2m_2006 nominee_2f_2006 EMA_2m_1990 EMA_2f_1990 EMA_2m_2006 EMA_2f_2006

local output3 nominee_3m_1990 nominee_3f_1990 nominee_3m_2006 nominee_3f_2006 EMA_3m_1990 EMA_3f_1990 EMA_3m_2006 EMA_3f_2006

local output4 nominee_4m_1990 nominee_4f_1990 nominee_4m_2006 nominee_4f_2006 EMA_4m_1990 EMA_4f_1990 EMA_4m_2006 EMA_4f_2006

local numbers ",'(1),'(2),,'(3),'(4),,'(5),'(6),,'(7),'(8)"

local format1 onecell nodepvars nostar unstack noobs nonotes nogaps nonumbers eqlabels(none)
local format2 nodepvars nostar nomtitle unstack nonumbers nogaps onecell
local format3 nodepvars nostar unstack nonumbers nogaps onecell nonotes noobs eqlabels(none)

local groups Nominated Elected 

local mtitles "Male" "Female" "Male" "Female" "Male" "Female" "Male" "Female"

esttab `output1' using "tables/table3.csv", ///
main(mean %12.4fc) `format1' ///
title("TABLE III") sfmt(%9.4fc %9.4fc) ///
mgroups(`groups', pattern(1 0 0 0 1 0 0 0)) ///
mtitles(`mtitles') posthead(`numbers') ///
refcat(byFellow "Nomination", nolabel) ///
extracols(3 5 7 9) label replace 

esttab `output2' using "tables/table3.csv", ///
main(mean %12.4fc) `format2' sfmt(%9.4fc %9.4fc) ///
refcat(UStop5 "Institutional Affiliation", nolabel) ///
extracols(3 5 7 9) nonotes noobs label append 

esttab `output3' using "tables/table3.csv", ///
main(mean %12.2fc) `format2' sfmt(%9.4fc) ///
refcat(fellow_AAAS "Fellowships (at Election)" ECTA_cumulative "Cumulative publications in top-5 journals" ///
ECTA_cite_cumulative "Cum.citations in top-5 journals" ///
Theory_cumulative "Cum. publications in field journals", nolabel) ///
extracols(3 5 7 9) nonotes label append 

esttab `output4' using "tables/table3.csv", ///
main(sum) `format2' sfmt(%9.4fc) ///
extracols(3 5 7 9) nonotes noobs label append 


log close

import delimited "tables/table3.csv", clear
* Reorder votes and endorsements to match table

gen n = _n
replace n = 9 if _n == 8
replace n = 8 if _n == 9
sort n
drop n


foreach var in v2 v3 v5 v6 v7 v8 v10 v11 v12 {

	replace `var' = subinstr(`var', ".", "", .) if strpos(v1, "Percent") 
	replace `var' = substr(`var', 1, 5) + "." + substr(`var', 6, 9) if strpos(v1, "Percent")
}

foreach var in v4 v7 v10 {
	replace `var' = ""
} 
* confidential entries
replace v3 = "*" if strpos(v1, "Percent Asia") | strpos(v1, "Percent Latin America")
replace v6 = "*" if strpos(v1, "Percent Asia") | strpos(v1, "Percent Latin America")


export delimited "tables/table3.csv", replace

