* table 4  

clear
eststo clear

if !missing("$dropbox_dir") {
	local dropbox_dir = "$dropbox_dir"
}
else {
	local dropbox_dir "C:/Users/Chris/Dropbox"
}
cd "`dropbox_dir'/ECM_Fellow_Study/Replication"
use "`dropbox_dir'\ECM_Fellow_Study\Paper2\econ\output\regression_dataset_public.dta"


cap log close
log using "tables/table4.log", replace


* exclude unknown gender 
drop if Ambiguous == 1
* exclude deceased authors
drop if (author == "Sherwin Rosen" & year >= death + 2 | dead == 1 & author != "Sherwin Rosen")

* ==============================================================================
* Female*decade coefficient
local list_decade 1980 1990 2000 2010
foreach decade in `list_decade'{
	gen year_`decade' = (floor(year/10)*10== `decade')
	gen Female_`decade' = Female * year_`decade'
}

drop year_*

* levels of top5 and cites 
gen top5 = AER_cumulative+QJE_cumulative+REStud_cumulative+ECTA_cumulative+JPE_cumulative
gen top5_cite=AER_cite+QJE_cite+REStud_cite+ECTA_cite+JPE_cite
gen top5_cite_cumulative=AER_cite_cumulative+QJE_cite_cumulative+REStud_cite_cumulative+ECTA_cite_cumulative+JPE_cite_cumulative
drop if missing(top5_cite) /* unmatched fellows */

gen top5_1=(top5==1)
gen top5_2=(top5==2)
gen top5_3=(top5==3)
gen top5_4=(top5==4)
gen top5_5=(top5==5)
gen top5_6=(top5==6)
gen top5_7=(top5>=7)

gen ema_1=(ECTA_cumulative==1)
gen ema_2=(ECTA_cumulative==2)
gen ema_3=(ECTA_cumulative>=3)

gen res_1=(REStud_cumulative==1)
gen res_2=(REStud_cumulative==2)
gen res_3=(REStud_cumulative>=3)

gen qje_1=(QJE_cumulative==1)
gen qje_2=(QJE_cumulative==2)
gen qje_3=(QJE_cumulative>=3)

gen aer_1=(AER_cumulative==1)
gen aer_2=(AER_cumulative==2)
gen aer_3=(AER_cumulative>=3)

gen jpe_1=(JPE_cumulative==1)
gen jpe_2=(JPE_cumulative==2)
gen jpe_3=(JPE_cumulative>=3)

* levels of citation 
gen if_top5=(top5>=1)
gen if_riskset = (fellow_EMA == 0 | new_fellow_EMA == 1)

gen decade = . 
local list_decade 1940 1950 1960 1970 1980 1990 2000 2010 
foreach decade in `list_decade'{
	replace decade = `decade' if floor(year/10)*10 == `decade'
}
replace decade = 1930 if inrange(year, 1931, 1939)

gen topcite = . 
levelsof decade, local(levels)
foreach d in `levels'{
	
	/* cumulative citations in top 5 pubs for authors with at least 1 top 5 and are in the riskset */
	_pctile top5_cite_cumulative if decade == `d' & if_top5 == 1 & if_riskset == 1, p(50 70 80 90 95 97.5 99)
	return list
	
	replace topcite = 1 if top5_cite_cumulative < r(r1) & decade == `d'
	replace topcite = 2 if top5_cite_cumulative < r(r2) & top5_cite_cumulative >= r(r1) & decade == `d'
	replace topcite = 3 if top5_cite_cumulative < r(r3) & top5_cite_cumulative >= r(r2) & decade == `d'
	replace topcite = 4 if top5_cite_cumulative < r(r4) & top5_cite_cumulative >= r(r3) & decade == `d'
	replace topcite = 5 if top5_cite_cumulative < r(r5) & top5_cite_cumulative >= r(r4) & decade == `d'
	replace topcite = 6 if top5_cite_cumulative < r(r6) & top5_cite_cumulative >= r(r5) & decade == `d'
	replace topcite = 7 if top5_cite_cumulative < r(r7) & top5_cite_cumulative >= r(r6) & decade == `d'
	replace topcite = 8 if top5_cite_cumulative >= r(r7) & decade == `d'
	
}

gen topcite1 = (topcite == 1)
gen topcite2 = (topcite == 2)
gen topcite3 = (topcite == 3)
gen topcite4 = (topcite == 4)
gen topcite5 = (topcite == 5)
gen topcite6 = (topcite == 6) 
gen topcite7 = (topcite == 7) 
gen topcite8 = (topcite == 8)


* years since first publication
gen firstpub_10 = (years_firstpub < 20 & years_firstpub >= 10)
gen firstpub_20 = (years_firstpub < 30 & years_firstpub >= 20)
gen firstpub_30 = (years_firstpub >= 30)

drop decade topcite
* ==============================================================================
* logit model for fellowships 

* top 5 only 
local top5 ECTA_cumulative QJE_cumulative AER_cumulative JPE_cumulative REStud_cumulative 
* all journals 
unab journal: AER_cumulative-TE_cumulative
unab citations: asinh*cites
* number of top 5/cites 
unab levels_top5: top5_1-top5_7 
unab levels_cite: topcite2-topcite8
* top 5 dummies
unab top5_dum: ema_1 ema_2 ema_3 res_1 res_2 res_3 ///
qje_1 qje_2 qje_3 aer_1 aer_2 aer_3 jpe_1 jpe_2 jpe_3
* years_firstpub dummies 
unab years_firstpub: firstpub_10 firstpub_20 firstpub_30

* specifications 
local spec1 `top5' 
local spec2 `citations' `journal' 
local spec3 `citations' `journal' `levels_top5' `levels_cite' `top5_dum' `years_firstpub'

noisily capture erase "tables/table4_fullreg.xls"
noisily capture erase "tables/table4_fullreg.txt" 
	
* pre-1980 
eststo fellow_EMA_start_1: logit new_fellow_EMA Female `spec1' i.year ///
if (fellow_EMA==0|new_fellow_EMA==1)& year < 1980 & year > 1932, cluster(author) iter(20)	
	
eststo fellow_EMA_start_2: logit new_fellow_EMA Female `spec2' i.year ///
if (fellow_EMA==0|new_fellow_EMA==1)& year < 1980 & year > 1932, cluster(author) iter(20)	

eststo fellow_EMA_start_3: logit new_fellow_EMA Female `spec3' i.year ///
if (fellow_EMA==0|new_fellow_EMA==1)& year < 1980 & year > 1932, cluster(author) iter(20)	
outreg2 using "tables/table4_fullreg.xls", append sdec(4) bdec(4)

* 1980 - 1999
eststo fellow_EMA_1980_1: logit new_fellow_EMA Female_1980 Female_1990 `spec1' i.year ///
if (fellow_EMA==0|new_fellow_EMA==1)& year < 2000 & year >= 1980, cluster(author) iter(20)	

eststo fellow_EMA_1980_2: logit new_fellow_EMA Female_1980 Female_1990 `spec2' i.year ///
if (fellow_EMA==0|new_fellow_EMA==1)& year < 2000 & year >= 1980, cluster(author) iter(20)

eststo fellow_EMA_1980_3: logit new_fellow_EMA Female_1980 Female_1990 `spec3' i.year /// 
if (fellow_EMA==0|new_fellow_EMA==1)& year < 2000 & year >= 1980, cluster(author) iter(20)	
outreg2 using "tables/table4_fullreg.xls", append sdec(4) bdec(4)

* 2000 - 2019
eststo fellow_EMA_2000_1: logit new_fellow_EMA Female_2000 Female_2010 `spec1' i.year ///
if (fellow_EMA==0|new_fellow_EMA==1)& year >= 2000, cluster(author) iter(20)	

eststo fellow_EMA_2000_2: logit new_fellow_EMA Female_2000 Female_2010 `spec2' i.year ///
if (fellow_EMA==0|new_fellow_EMA==1)& year >= 2000, cluster(author) iter(20)	

eststo fellow_EMA_2000_3: logit new_fellow_EMA Female_2000 Female_2010 `spec3' i.year ///
if (fellow_EMA==0|new_fellow_EMA==1)& year >= 2000, cluster(author) iter(20)	
outreg2 using "tables/table4_fullreg.xls", append sdec(4) bdec(4)
	


* ==============================================================================
* some labeling 

label variable Female "Female Economist*(pre-1980)"
label variable Female_1980 "Female Economist*(1980-89)"
label variable Female_1990 "Female Economist*(1990-99)"
label variable Female_2000 "Female Economist*(2000-09)"
label variable Female_2010 "Female Economist*(2010-19)"

label variable ECTA_cite_cumulative "Asinh citations in Econometrica"
label variable REStud_cite_cumulative "Asinh citations in REStud"
label variable AER_cite_cumulative "Asinh citations in AER"
label variable QJE_cite_cumulative "Asinh citations in QJE"
label variable JPE_cite_cumulative "Asinh citations in JPE"

label variable ECTA_cumulative "Papers in Econometrica"
label variable REStud_cumulative "Papers in Review of Economic Studies"
label variable AER_cumulative "Papers in American Economic Review"
label variable QJE_cumulative "Papers in Quarterly Journal of Eco."
label variable JPE_cumulative "Papers in JPE"

* labeling for journal controls 
unab list_journal: AER-JEH
foreach journal in `list_journal'{

	local old_label: var label `journal'
	label variable `journal'_cumulative "Papers in `old_label'"
}

* ==============================================================================
* export 

*ordering for EMA regression variables
unab ordering_EMA: Female Female_1980 Female_1990 Female_2000 Female_2010 ECTA_cumulative asinhEMAcites REStud_cumulative asinhREScites AER_cumulative asinhAERcites QJE_cumulative asinhQJEcites JPE_cumulative asinhJPEcites 
unab top5: top5_1 top5_2


* output file for table 4
esttab fellow_EMA_start_* fellow_EMA_1980_* fellow_EMA_2000_* using "tables/table4.csv", ///
order(`ordering_EMA' `top5') csv se(%9.3f) b(%9.3f) pr2 scalars(N) sfmt(%9.0fc) ///
refcat(Female "Authors' Genders (Omitted: Male Author)" ///
ECTA_cumulative "Cumulative Publications and Citations Received in top-5 journals" ///
top5_1 "Levels of Top5 and Top 5 Citations", nolabel) ///
mgroups(1933-79 1980-99 2000-19, pattern(1 0 0 1 0 0 1 0 0)) ///
title("Table IV") keep(`ordering_EMA' `top5') label nostar nogaps nodepvars extracols(4 7 10) replace

log off
log close 
