
clear
eststo clear
set matsize 11000
if !missing("$dropbox_dir") {
	local dropbox_dir = "$dropbox_dir"
}
else {
	local dropbox_dir "C:/Users/Chris/Dropbox"
}
cd "`dropbox_dir'/ECM_Fellow_Study/Replication"
use "`dropbox_dir'\ECM_Fellow_Study\Paper2\econ\output\regression_dataset.dta"

cap log close _all
log using "tables/table6.log", replace


* ==============================================================================
drop if Ambiguous == 1
drop if year == 2003 /* drop the 2003 observations */
drop if year < 1995 | year == . | missing(nominee)
drop if (author == "Sherwin Rosen" & year >= death + 2 | dead == 1 & author != "Sherwin Rosen")

replace numEndorsed = . if numEndorsed == 0 

* nomination time period dummy 
gen d_1995_2005 = (inrange(year, 1995, 2005))
gen d_2006_2011 = (inrange(year, 2006, 2011))
gen d_2012_2019 = (inrange(year, 2012, 2019))

* committee x female interaction term 
gen byCommittee_female = Female * byCommittee 

* variables for gender*decade 
local gender Female byCommittee byCommittee_female
foreach g in `gender'{
	gen `g'_1995_2005 = (d_1995_2005 == 1 & `g' == 1)
	gen `g'_2006_2011 = (d_2006_2011 == 1 & `g' == 1)
	gen `g'_2012_2019 = (d_2012_2019 == 1 & `g' == 1)
}

* nomination type 
gen nomi_fellow = (byCommittee == 0)
gen nomi_committy = (byCommittee == 1)

* author id 
egen id = group(author)
order id author

* levels of top5 and cites 
gen top5 = AER_cumulative+QJE_cumulative+REStud_cumulative+ECTA_cumulative+JPE_cumulative
gen top5_cite_cumulative=AER_cite_cumulative+QJE_cite_cumulative+REStud_cite_cumulative+ECTA_cite_cumulative+JPE_cite_cumulative

gen top5_1=(top5==1)
gen top5_2=(top5==2)
gen top5_3=(top5==3)
gen top5_4=(top5==4)
gen top5_5=(top5==5)
gen top5_6=(top5==6)
gen top5_7=(top5>=7)

gen ema_1=(ECTA_cumulative==1)
gen ema_2=(ECTA_cumulative==2)
gen ema_3=(ECTA_cumulative>=3)

gen res_1=(REStud_cumulative==1)
gen res_2=(REStud_cumulative==2)
gen res_3=(REStud_cumulative>=3)

gen qje_1=(QJE_cumulative==1)
gen qje_2=(QJE_cumulative==2)
gen qje_3=(QJE_cumulative>=3)

gen aer_1=(AER_cumulative==1)
gen aer_2=(AER_cumulative==2)
gen aer_3=(AER_cumulative>=3)

gen jpe_1=(JPE_cumulative==1)
gen jpe_2=(JPE_cumulative==2)
gen jpe_3=(JPE_cumulative>=3)


* levels of citation 
gen if_top5=(top5>=1)
gen if_riskset = (fellow_EMA == 0 | new_fellow_EMA == 1)

gen decade = . 
local list_decade 1990 2000 2010 
foreach decade in `list_decade'{
	replace decade = `decade' if floor(year/10)*10 == `decade'
}
replace decade = 1930 if inrange(year, 1931, 1939)
gen topcite = . 

levelsof decade, local(levels)
foreach d in `levels'{
	
	_pctile top5_cite_cumulative if decade == `d' & if_top5 == 1 & if_riskset == 1, p(50 70 80 90 95 97.5 99)
	return list
	
	replace topcite = 1 if top5_cite_cumulative < r(r1) & decade == `d'
	replace topcite = 2 if top5_cite_cumulative < r(r2) & top5_cite_cumulative >= r(r1) & decade == `d'
	replace topcite = 3 if top5_cite_cumulative < r(r3) & top5_cite_cumulative >= r(r2) & decade == `d'
	replace topcite = 4 if top5_cite_cumulative < r(r4) & top5_cite_cumulative >= r(r3) & decade == `d'
	replace topcite = 5 if top5_cite_cumulative < r(r5) & top5_cite_cumulative >= r(r4) & decade == `d'
	replace topcite = 6 if top5_cite_cumulative < r(r6) & top5_cite_cumulative >= r(r5) & decade == `d'
	replace topcite = 7 if top5_cite_cumulative < r(r7) & top5_cite_cumulative >= r(r6) & decade == `d'
	replace topcite = 8 if top5_cite_cumulative >= r(r7) & decade == `d'
	
}

gen topcite1 = (topcite == 1)
gen topcite2 = (topcite == 2)
gen topcite3 = (topcite == 3)
gen topcite4 = (topcite == 4)
gen topcite5 = (topcite == 5)
gen topcite6 = (topcite == 6) 
gen topcite7 = (topcite == 7) 
gen topcite8 = (topcite == 8)

* years since first publication 
gen firstpub_10 = (years_firstpub < 20 & years_firstpub >= 10)
gen firstpub_20 = (years_firstpub < 30 & years_firstpub >= 20)
gen firstpub_30 = (years_firstpub >= 30)

drop decade topcite


* ==============================================================================
* reg locals 
local gender1 Female_1995_2005 Female_2006_2011 Female_2012_2019
unab journal: AER_cumulative-TE_cumulative top5_1-top5_7 ema_* res_* aer_* qje_* jpe_* 
unab citations: asinh*cites topcite2-topcite8 
unab years_firstpub: firstpub_10 firstpub_20 firstpub_30 

local committee byCommittee byCommittee_female 
local committee_pooled byCommittee_1995_2005-byCommittee_2012_2019 byCommittee_female_1995_2005-byCommittee_female_2012_2019 

local year_fe i.year 


local spec1  `gender1' `journal' `citations' `years_firstpub' `year_fe' 

local spec2 `gender1' `journal' `citations' `years_firstpub' `year_fe' 
local spec3 `gender1' `journal' `citations' `years_firstpub' `year_fe' `committee_pooled'

local spec4 `gender1' `journal' `citations' `years_firstpub' `year_fe' 
local spec5 `gender1' `journal' `citations' `years_firstpub' `year_fe' `committee_pooled'

local spec6 `gender1' `journal' `citations' `years_firstpub' `year_fe' 


* panel A 

local varlist new_fellow_EMA nominee nomi_committy nomi_fellow 
foreach var in `varlist'{
	
	local v = substr("`var'", strrpos("`var'", "_")+1, .)
	
	eststo `v'_1: logit `var' `spec1' if (fellow_EMA==0|new_fellow_EMA==1) & year >= 1995, cluster(author) 
	
}

* panel B 

eststo new_fellow_EMA_1: logit new_fellow_EMA `spec2' if nominee == 1 & year >= 1995, cluster(author)
eststo new_fellow_EMA_2: logit new_fellow_EMA `spec3' if nominee == 1 & year >= 1995, cluster(author)

eststo numVotes_1: poisson numVotes `spec4' if nominee == 1 & year >= 1995, vce(cluster id)	
eststo numVotes_2: poisson numVotes `spec5' if nominee == 1 & year >= 1995, vce(cluster id)

eststo numEndorsed_1: poisson numEndorsed `spec6' if nominee == 1 & byCommittee == 0 & year >= 1995, vce(cluster id)	


* ==============================================================================

* some formatting 
label variable Female "Female Economist"
label variable byCommittee "Committee Nominee"
label variable numEndorsed "Number of Endorsements"
label variable byCommittee_female "Committee Nominee*Female"

* output file for table 6
* without regional controls 
local format1 csv se(%9.3f) b(%9.3f) scalars(N) sfmt(%9.0fc) label nostar nogaps nodep nonote nom
local format2 csv se(%9.3f) b(%9.3f) scalars(N) sfmt(%9.0fc) label nodepvars nostar nomtitle nonumbers nogaps nonote 

local varlist1 Female_1995_2005 Female_2006_2011 Female_2012_2019 
local committee_pooled byCommittee_1995_2005 byCommittee_2006_2011 byCommittee_2012_2019  ///
byCommittee_female_1995_2005 byCommittee_female_2006_2011 byCommittee_female_2012_2019 

esttab EMA_1 nominee_1 committy_1 fellow_1 using "tables/table6.csv", ///
`format1' title("Table VI") keep(`varlist1') replace

esttab new_fellow_EMA_1 new_fellow_EMA_2 numVotes_1 numVotes_2 numEndorsed_1 using "tables/table6.csv", ///
`format2' keep(`varlist1' `committee_pooled') append


log off 
log close 

