* table 7

set matsize 10000

clear
eststo clear
if !missing("$dropbox_dir") {
	local dropbox_dir = "$dropbox_dir"
}
else {
	local dropbox_dir "C:/Users/Chris/Dropbox"
}
cd "`dropbox_dir'/ECM_Fellow_Study/Replication"
use "`dropbox_dir'\ECM_Fellow_Study\Paper2\econ\output\regression_dataset.dta"

cap log close 
log using "tables/table7.log", replace

* ==============================================================================
drop if Ambiguous == 1
drop if (author == "Sherwin Rosen" & year >= death + 2 | dead == 1 & author != "Sherwin Rosen")
drop if year < 1990 

* time interval for nomination by Fellow/Committee (1990 on, except 2003)
gen nomi_time = (inrange(year, 1995, 2019) & year != 2003) 

* per decade * female interaction term 
local list_decade 1990 2000 2010
foreach decade in `list_decade'{
	gen year_`decade' = 0 
	replace year_`decade' = 1 if floor(year/10)*10== `decade'
	gen Female_`decade' = Female * year_`decade'
}

* nomination type 
gen nomi_fellow = (byCommittee == 0) 
gen nomi_committy = (byCommittee == 1)

* quantiles of letter in alphabet
cumul lastname_firstletter, gen(cum_dist_letter)
bysort lastname_firstletter: egen quantile_firstletter = max(cum_dist_letter)

* Female * Committe_share_female 
gen Female_committee_share_woman = committee_share_female * Female 

* levels of top5 and cites 
gen top5 = AER_cumulative+QJE_cumulative+REStud_cumulative+ECTA_cumulative+JPE_cumulative
gen top5_cite_cumulative=AER_cite_cumulative+QJE_cite_cumulative+REStud_cite_cumulative+ECTA_cite_cumulative+JPE_cite_cumulative

gen top5_1=(top5==1)
gen top5_2=(top5==2)
gen top5_3=(top5==3)
gen top5_4=(top5==4)
gen top5_5=(top5==5)
gen top5_6=(top5==6)
gen top5_7=(top5>=7)

gen ema_1=(ECTA_cumulative==1)
gen ema_2=(ECTA_cumulative==2)
gen ema_3=(ECTA_cumulative>=3)

gen res_1=(REStud_cumulative==1)
gen res_2=(REStud_cumulative==2)
gen res_3=(REStud_cumulative>=3)

gen qje_1=(QJE_cumulative==1)
gen qje_2=(QJE_cumulative==2)
gen qje_3=(QJE_cumulative>=3)

gen aer_1=(AER_cumulative==1)
gen aer_2=(AER_cumulative==2)
gen aer_3=(AER_cumulative>=3)

gen jpe_1=(JPE_cumulative==1)
gen jpe_2=(JPE_cumulative==2)
gen jpe_3=(JPE_cumulative>=3)

* levels of citation 
gen if_top5=(top5>=1)
gen if_riskset = (fellow_EMA == 0 | new_fellow_EMA == 1)

gen decade = . 
local list_decade 1940 1950 1960 1970 1980 1990 2000 2010 
foreach decade in `list_decade'{
	replace decade = `decade' if floor(year/10)*10 == `decade'
}
replace decade = 1930 if inrange(year, 1931, 1939)

gen topcite = . 

levelsof decade, local(levels)
foreach d in `levels'{
	
	_pctile top5_cite_cumulative if decade == `d' & if_top5 == 1 & if_riskset == 1, p(50 70 80 90 95 97.5 99)
	return list
	
	replace topcite = 1 if top5_cite_cumulative < r(r1) & decade == `d'
	replace topcite = 2 if top5_cite_cumulative < r(r2) & top5_cite_cumulative >= r(r1) & decade == `d'
	replace topcite = 3 if top5_cite_cumulative < r(r3) & top5_cite_cumulative >= r(r2) & decade == `d'
	replace topcite = 4 if top5_cite_cumulative < r(r4) & top5_cite_cumulative >= r(r3) & decade == `d'
	replace topcite = 5 if top5_cite_cumulative < r(r5) & top5_cite_cumulative >= r(r4) & decade == `d'
	replace topcite = 6 if top5_cite_cumulative < r(r6) & top5_cite_cumulative >= r(r5) & decade == `d'
	replace topcite = 7 if top5_cite_cumulative < r(r7) & top5_cite_cumulative >= r(r6) & decade == `d'
	replace topcite = 8 if top5_cite_cumulative >= r(r7) & decade == `d'
	
}

gen topcite1 = (topcite == 1)
gen topcite2 = (topcite == 2)
gen topcite3 = (topcite == 3)
gen topcite4 = (topcite == 4)
gen topcite5 = (topcite == 5)
gen topcite6 = (topcite == 6) 
gen topcite7 = (topcite == 7) 
gen topcite8 = (topcite == 8)

* years since first publication
gen firstpub_10 = (years_firstpub < 20 & years_firstpub >= 10)
gen firstpub_20 = (years_firstpub < 30 & years_firstpub >= 20)
gen firstpub_30 = (years_firstpub >= 30)

drop decade topcite

* ==============================================================================
* controls 
unab journal: AER_cumulative-TE_cumulative top5_1-top5_7 ema_* res_* aer_* qje_* jpe_* 
unab citations: asinh*cites topcite2-topcite8 
unab years_firstpub: firstpub_10-firstpub_30
local connections connection_fellowEMA_cumulative asso_editorEMA 
local committee nm_connection_committee Female_committee_share_woman
local initial quantile_firstletter

* gender*decade
local female Female_1990 Female_2000 Female_2010 

* ==============================================================================
* new fellow/new nominee 
local varlist new_fellow_EMA nominee

foreach var in `varlist'{
	eststo `var'_1: logit `var' `female' `journal' `citations' `years_firstpub' i.year ///
	if (nominee == 1|fellow_EMA == 0),  cluster(author)
	
	eststo `var'_2: logit `var' `female' `journal' `citations' `years_firstpub' `initial' `connections' `committee' i.year ///
	if (nominee == 1|fellow_EMA == 0),  cluster(author)	
}


* nomination by fellow/committee
local varlist nomi_fellow nomi_committy

foreach var in `varlist'{
	
	eststo `var'_1: logit `var' `female' `journal' `citations' `years_firstpub' i.year ///
	if nomi_time == 1 & (nominee == 1|fellow_EMA == 0),  cluster(author)
	
	eststo `var'_2: logit `var' `female' `journal' `citations' `years_firstpub' `initial' `connections' `committee' i.year ///
	if nomi_time == 1 & (nominee == 1|fellow_EMA == 0),  cluster(author)
	
}



* ==============================================================================
label variable Female_1990 "Female Economist*(1990-99)"
label variable Female_2000 "Female Economist*(2000-09)"
label variable Female_2010 "Female Economist*(2010-19)"
label variable quantile_firstletter "Quantile of First Letter"
label variable asso_editorEMA "Associate Editor at Econometrica"
label variable connection_fellowEMA_cumulative "Number of Connections with Econometric Society Fellows"
label variable nm_connection_committee "Number of Connections with ES Nominating Committee"
label variable Female_committee_share_woman "Share Women in Nominating Committee×Female"

* list of variables displayed in table 7 and their ordering 
local ordering Female_1990 Female_2000 Female_2010 ///
asso_editorEMA quantile_firstletter ///
connection_fellowEMA_cumulative ///
nm_connection_committee Female_committee_share_woman

* output file 
esttab new_fellow_EMA* nominee* nomi_fellow* nomi_committy* ///
using "tables/table7.csv", keep(`ordering') order(`ordering') ///
csv se(%9.3f) b(%9.3f) pr2 scalars(N) sfmt(%9.0fc) label ///
refcat(Female_1990 "Authors' Gender (Omitted: Male Author)" ///
quantile_firstletter "Impact of First Initials of Last Names" ///
asso_editorEMA "Visibility -- Associate Editor at EMA" ///
connection_fellowEMA_cumulative "Connections to Econometric Soc. Fellows" ///
nm_connection_committee "Impact of Nominating Committee", nolabel) ///
title("Table VII") nogaps nostar nodepvars extracols(3 5 7 9) replace

import delimited using "tables/table7.csv", clear

log off 
log close 
