* table 8

clear all
set more off

if !missing("$dropbox_dir") {
	local dropbox_dir = "$dropbox_dir"
}
else {
	local dropbox_dir "C:/Users/Chris/Dropbox"
}
cd "`dropbox_dir'/ECM_Fellow_Study/Replication"
use "`dropbox_dir'\ECM_Fellow_Study\Paper2\econ\output\regression_dataset.dta"

cap log close
log using "tables/table8.log", replace

* ==============================================================================
drop if !inrange(year, 1995, 2019)| year == 2003 
drop if Ambiguous == 1
drop if (author == "Sherwin Rosen" & year >= death + 2 | dead == 1 & author != "Sherwin Rosen")


* regions / institutions 
gen UStop5 = (location == "US Top 5")
gen UStop17 = (location == "US 6-17")
gen USother = (location == "US Below 17")
gen Europe = (location == "Europe")
gen AsiaAustr = (location == "Asia/Australia")
gen LatinAfrica = (location == "Latin America/Africa")

gen minority = (AsiaAustr == 1 | LatinAfrica == 1)


* time dummy 
gen d_1995_2005 = (inrange(year, 1995, 2005) & year != 2003)
gen d_2006_2011 = (inrange(year, 2006, 2011))
gen d_2012_2019 = (inrange(year, 2012, 2019))


* author id 
egen id = group(author)
order id author

* variables by decade 
local varlist Female byCommittee UStop5 UStop17 Europe AsiaAustr ///
LatinAfrica minority

foreach g in `varlist'{
	
	gen `g'_1995_2005 = (d_1995_2005 == 1 & `g' == 1)
	gen `g'_2006_2011 = (d_2006_2011 == 1 & `g' == 1)
	gen `g'_2012_2019 = (d_2012_2019 == 1 & `g' == 1)
	
}

* levels of top5 and cites 
gen top5 = AER_cumulative+QJE_cumulative+REStud_cumulative+ECTA_cumulative+JPE_cumulative
gen top5_cite_cumulative=AER_cite_cumulative+QJE_cite_cumulative+REStud_cite_cumulative+ECTA_cite_cumulative+JPE_cite_cumulative

gen top5_1=(top5==1)
gen top5_2=(top5==2)
gen top5_3=(top5==3)
gen top5_4=(top5==4)
gen top5_5=(top5==5)
gen top5_6=(top5==6)
gen top5_7=(top5>=7)

gen ema_1=(ECTA_cumulative==1)
gen ema_2=(ECTA_cumulative==2)
gen ema_3=(ECTA_cumulative>=3)

gen res_1=(REStud_cumulative==1)
gen res_2=(REStud_cumulative==2)
gen res_3=(REStud_cumulative>=3)

gen qje_1=(QJE_cumulative==1)
gen qje_2=(QJE_cumulative==2)
gen qje_3=(QJE_cumulative>=3)

gen aer_1=(AER_cumulative==1)
gen aer_2=(AER_cumulative==2)
gen aer_3=(AER_cumulative>=3)

gen jpe_1=(JPE_cumulative==1)
gen jpe_2=(JPE_cumulative==2)
gen jpe_3=(JPE_cumulative>=3)

* levels of citation 
gen if_top5=(top5>=1)
gen if_riskset = (fellow_EMA == 0 | new_fellow_EMA == 1)

gen decade = . 
local list_decade 1940 1950 1960 1970 1980 1990 2000 2010 
foreach decade in `list_decade'{
	replace decade = `decade' if floor(year/10)*10 == `decade'
}
replace decade = 1930 if inrange(year, 1931, 1939)

gen topcite = . 

levelsof decade, local(levels)
foreach d in `levels'{
	
	_pctile top5_cite_cumulative if decade == `d' & if_top5 == 1 & if_riskset == 1, p(50 70 80 90 95 97.5 99)
	return list
	
	replace topcite = 1 if top5_cite_cumulative < r(r1) & decade == `d'
	replace topcite = 2 if top5_cite_cumulative < r(r2) & top5_cite_cumulative >= r(r1) & decade == `d'
	replace topcite = 3 if top5_cite_cumulative < r(r3) & top5_cite_cumulative >= r(r2) & decade == `d'
	replace topcite = 4 if top5_cite_cumulative < r(r4) & top5_cite_cumulative >= r(r3) & decade == `d'
	replace topcite = 5 if top5_cite_cumulative < r(r5) & top5_cite_cumulative >= r(r4) & decade == `d'
	replace topcite = 6 if top5_cite_cumulative < r(r6) & top5_cite_cumulative >= r(r5) & decade == `d'
	replace topcite = 7 if top5_cite_cumulative < r(r7) & top5_cite_cumulative >= r(r6) & decade == `d'
	replace topcite = 8 if top5_cite_cumulative >= r(r7) & decade == `d'
	
}

gen topcite1 = (topcite == 1)
gen topcite2 = (topcite == 2)
gen topcite3 = (topcite == 3)
gen topcite4 = (topcite == 4)
gen topcite5 = (topcite == 5)
gen topcite6 = (topcite == 6) 
gen topcite7 = (topcite == 7) 
gen topcite8 = (topcite == 8)

* years since first publication 
gen firstpub_10 = (years_firstpub < 20 & years_firstpub >= 10)
gen firstpub_20 = (years_firstpub < 30 & years_firstpub >= 20)
gen firstpub_30 = (years_firstpub >= 30)

drop decade topcite

* ========================================================================================================
* reg locals 
unab journal: AER_cumulative-TE_cumulative top5_1-top5_7 ema_* res_* aer_* qje_* jpe_* 
unab citations: asinh*cites topcite2-topcite8
unab years_firstpub: firstpub_10-firstpub_30
local year_fe i.year 

local gender Female_1995_2005 Female_2006_2011 Female_2012_2019 

local region1 UStop5_1995_2005-UStop5_2012_2019 UStop17_1995_2005-UStop17_2012_2019 ///
Europe_1995_2005-Europe_2012_2019 AsiaAustr_1995_2005-AsiaAustr_2012_2019 ///
LatinAfrica_1995_2005-LatinAfrica_2012_2019

local region2 UStop5_1995_2005-UStop5_2012_2019 UStop17_1995_2005-UStop17_2012_2019 Europe_1995_2005-Europe_2012_2019 ///
minority_1995_2005-minority_2012_2019 

local committee byCommittee_1995_2005-byCommittee_2012_2019 

local spec1  `gender' `region1' `journal' `citations' `years_firstpub' `year_fe'

local spec2  `gender' `region2'  `committee' `journal' `citations' `years_firstpub' `year_fe'


eststo cond_EMA: logit new_fellow_EMA `spec1' if nominee == 1 , vce(cluster id)

eststo min_EMA: logit new_fellow_EMA `spec2' if nominee == 1, vce(cluster id)


* ========================================================================================================
* export 

* some formatting 
local var1 Female_1995_2005 UStop5_1995_2005 UStop17_1995_2005 Europe_1995_2005 ///
AsiaAustr_1995_2005 LatinAfrica_1995_2005 ///
Female_2006_2011 UStop5_2006_2011 UStop17_2006_2011 Europe_2006_2011 ///
AsiaAustr_2006_2011 LatinAfrica_2006_2011 ///
Female_2012_2019 UStop5_2012_2019 UStop17_2012_2019 Europe_2012_2019 ///
AsiaAustr_2012_2019 LatinAfrica_2012_2019

local var2 Female_1995_2005 minority_1995_2005 ///
byCommittee_1995_2005  ///
Female_2006_2011 minority_2006_2011 ///
byCommittee_2006_2011 ///
Female_2012_2019 minority_2012_2019 ///
byCommittee_2012_2019


local format1 csv se(%9.3f) b(%9.3f) scalars(N) sfmt(%9.0fc) label nostar nogaps nodep nonote nom
local format2 csv se(%9.3f) b(%9.3f) scalars(N) sfmt(%9.0fc) label nodepvars nostar nomtitle nonumbers nogaps nonote 

* output file for table 8
esttab cond_EMA using "tables/table8.csv", ///
`format1' mgroups(1995-2002 2003-2005 2006-2011 2012-2019, pattern(1 1 1)) ///
title("Table VIX") keep(`var1') order(`var1') extracols(2 3 4) replace

esttab min_EMA using "tables/table8.csv", ///
`format2' keep(`var2') order(`var2') extracols(2 3 4)  coeflabels(none) append 

log off 
log close 
