* table 9

eststo clear
clear

if !missing("$dropbox_dir") {
	local dropbox_dir = "$dropbox_dir"
}
else {
	local dropbox_dir "C:/Users/Chris/Dropbox"
}
cd "`dropbox_dir'/ECM_Fellow_Study/Replication"
use "`dropbox_dir'\ECM_Fellow_Study\Paper2\econ\output\regression_dataset_public.dta"

cap log close
log using "tables/table9.log", replace

* ============================================================================== 

drop if Ambiguous == 1
drop if (author == "Sherwin Rosen" & year >= death + 2 | dead == 1 & author != "Sherwin Rosen")

* generate filter for NAS primary fellows. For secondary fellows, we keep them in 
* the risk set up to and including the year they are elected, but are not counted as
* a fellow and then dropped after that year
gen NAS_sample = 1
replace new_fellow_NAS = 0 if primary_NAS_econ == 0
replace NAS_sample = 0 if year > year_appointed_NAS & primary_NAS_econ == 0

* same for AAAS 
gen AAAS_sample = 1
replace new_fellow_AAAS = 0 if AAAS_flags == 3
replace AAAS_sample = 0 if year > year_appointed_AAAS & AAAS_flags == 3

* variables for gender*decade 
gen year_start_1970 = 0 

** start - 1970 
local list_decade 1880 1890 1900 1910 1920 1930 1940 1950 1960 1970
foreach decade in `list_decade'{
	replace year_start_1970 = 1 if floor(year/10)*10== `decade'
}

gen Female_start_1970 = 0 
replace Female_start_1970 = 1 if year_start_1970 * Female == 1

** per decade * female interaction term 
local list_decade 1980 1990 2000 2010
foreach decade in `list_decade'{
	gen year_`decade' = 0 
	replace year_`decade' = 1 if floor(year/10)*10== `decade'
	gen Female_`decade' = Female * year_`decade'
}


* levels of top5 and cites 
gen ema_1=(ECTA_cumulative==1)
gen ema_2=(ECTA_cumulative==2)
gen ema_3=(ECTA_cumulative>=3)

gen res_1=(REStud_cumulative==1)
gen res_2=(REStud_cumulative==2)
gen res_3=(REStud_cumulative>=3)

gen qje_1=(QJE_cumulative==1)
gen qje_2=(QJE_cumulative==2)
gen qje_3=(QJE_cumulative>=3)

gen aer_1=(AER_cumulative==1)
gen aer_2=(AER_cumulative==2)
gen aer_3=(AER_cumulative>=3)

gen jpe_1=(JPE_cumulative==1)
gen jpe_2=(JPE_cumulative==2)
gen jpe_3=(JPE_cumulative>=3)

gen top5 = AER_cumulative+QJE_cumulative+REStud_cumulative+ECTA_cumulative+JPE_cumulative
gen top5_cite_cumulative=AER_cite_cumulative+QJE_cite_cumulative+REStud_cite_cumulative+ECTA_cite_cumulative+JPE_cite_cumulative

gen ema_top5_1=(top5==1)
gen ema_top5_2=(top5==2)
gen ema_top5_3=(top5==3)
gen ema_top5_4=(top5==4)
gen ema_top5_5=(top5==5)
gen ema_top5_6=(top5==6)
gen ema_top5_7=(top5>=7)

gen sloan_top5_1=(top5<=1)
gen sloan_top5_2=(top5==2)
gen sloan_top5_3=(top5==3)
gen sloan_top5_4=(top5==4)
gen sloan_top5_5=(top5>=5)

gen top5_1=(top5 <= 3)
gen top5_2=(top5 >= 4 & top5 <= 5)
gen top5_3=(top5 >= 6 & top5 <= 7)
gen top5_4=(top5 >= 8 & top5 <= 9)
gen top5_5=(top5 >= 10 & top5 <= 11)
gen top5_6=(top5 >= 12 & top5 <= 13)
gen top5_7=(top5 >= 14 & top5 <= 15)
gen top5_8=(top5 >= 16)

* levels of citation 
gen if_top5=(top5>=1)
gen if_riskset = (fellow_EMA == 0 | new_fellow_EMA == 1)

gen decade = . 
local list_decade 1940 1950 1960 1970 1980 1990 2000 2010 
foreach decade in `list_decade'{
	replace decade = `decade' if floor(year/10)*10 == `decade'
}
replace decade = 1930 if inrange(year, 1931, 1939)

gen topcite = . 

levelsof decade, local(levels)
foreach d in `levels'{
	
	_pctile top5_cite_cumulative if decade == `d' & if_top5 == 1 & if_riskset == 1, p(50 70 80 90 95 97.5 99)
	return list
	
	replace topcite = 1 if top5_cite_cumulative < r(r1) & decade == `d'
	replace topcite = 2 if top5_cite_cumulative < r(r2) & top5_cite_cumulative >= r(r1) & decade == `d'
	replace topcite = 3 if top5_cite_cumulative < r(r3) & top5_cite_cumulative >= r(r2) & decade == `d'
	replace topcite = 4 if top5_cite_cumulative < r(r4) & top5_cite_cumulative >= r(r3) & decade == `d'
	replace topcite = 5 if top5_cite_cumulative < r(r5) & top5_cite_cumulative >= r(r4) & decade == `d'
	replace topcite = 6 if top5_cite_cumulative < r(r6) & top5_cite_cumulative >= r(r5) & decade == `d'
	replace topcite = 7 if top5_cite_cumulative < r(r7) & top5_cite_cumulative >= r(r6) & decade == `d'
	replace topcite = 8 if top5_cite_cumulative >= r(r7) & decade == `d'
	
}

gen topcite1 = (topcite == 1)
gen topcite2 = (topcite == 2)
gen topcite3 = (topcite == 3)
gen topcite4 = (topcite == 4)
gen topcite5 = (topcite == 5)
gen topcite6 = (topcite == 6) 
gen topcite7 = (topcite == 7) 
gen topcite8 = (topcite == 8)


gen firstpub_10 = (years_firstpub < 20 & years_firstpub >= 10)
gen firstpub_20 = (years_firstpub < 30 & years_firstpub >= 20)
gen firstpub_30 = (years_firstpub >= 30)

drop decade topcite

* Controls * 3 20-year time intervals 
** time interval dummy  
gen decades_1980 = 0 
replace decades_1980 = 1 if year < 2000 & year > 1979 
gen decades_2000 = 0
replace decades_2000 = 1 if year > 1999  

unab list_var: AER_cumulative-TE_cumulative top5_1-top5_8 sloan_top5_* ///
ema_* res_* aer_* qje_* jpe_* asinh*cites topcite2-topcite8 ///
firstpub_10-firstpub_30

foreach var in `list_var'{
	gen `var'_1970 = `var'*year_start_1970
	gen `var'_1980 = `var'*decades_1980
	gen `var'_2000 = `var'*decades_2000
}


* logit by fellowships 
* ============================================================================== 
* pooling all years since 1932 

* controls 
local female Female_start_1970 Female_1980 Female_1990 Female_2000 Female_2010 
unab journal: *_cumulative_1970 *_cumulative_1980 *_cumulative_2000
unab asinhcites: asinhREScites_* asinhEMAcites_* asinhQJEcites_* asinhAERcites_* asinhJPEcites_* 
unab percentcites: topcite2_* topcite3_* topcite4_* topcite5_* topcite6_* topcite7_* topcite8_* 

unab levels_top5: ema_1_* ema_2_* ema_3_* res_1_* res_2_* res_3_* aer_1_* aer_2_* aer_3_* ///
qje_1_* qje_2_* qje_3_* jpe_1_* jpe_2_* jpe_3_* /* EMA only */

unab sloan_top5: sloan_top5_2_1970-sloan_top5_5_2000  /* for Sloan only */
unab ema_top5: ema_top5_1_1970-ema_top5_7_2000  /* for EMA only */
unab other_top5: top5_2_1970-top5_8_2000 /* AAAS, NAS, AEAF */

* EMA 
* spec 1
eststo new_fellow_EMA_1: logit new_fellow_EMA `female' `journal' `asinhcites' i.year ///
if (fellow_EMA==0|new_fellow_EMA==1) & year > 1932, cluster(author) iter(20)

* spec 2 
eststo new_fellow_EMA_2: logit new_fellow_EMA `female' `journal' `asinhcites' `ema_top5' `levels_top5' `percentcites' ///
firstpub_10_* firstpub_20_* firstpub_30_* i.year ///
if (fellow_EMA==0|new_fellow_EMA==1) &  year > 1932, cluster(author) iter(20)

* AAAS 
eststo new_fellow_AAAS_1: logit new_fellow_AAAS `female' `journal' `asinhcites' i.year ///
if (fellow_AAAS==0|new_fellow_AAAS==1) & year >= 1931 & AAAS_sample, cluster(author) iter(20)

eststo new_fellow_AAAS_2: logit new_fellow_AAAS `female' `journal' `asinhcites' `other_top5' `percentcites' ///
firstpub_20_* firstpub_30_*  i.year ///
if (fellow_AAAS==0|new_fellow_AAAS==1) & year >= 1931 & AAAS_sample, cluster(author) iter(20)

* NAS 
eststo new_fellow_NAS_1: logit new_fellow_NAS `female' `journal' `asinhcites' i.year ///
if (fellow_NAS==0|new_fellow_NAS==1) & year > 1932 & NAS_sample, cluster(author) iter(20)

eststo new_fellow_NAS_2: logit new_fellow_NAS `female' `journal' `asinhcites' `other_top5' `percentcites' ///
firstpub_30_*  i.year ///
if (fellow_NAS==0|new_fellow_NAS==1) & year > 1932 & NAS_sample, cluster(author) iter(20)

* AEAF 
eststo new_fellow_AEAF_1: logit new_fellow_AEAF `female' `journal' `asinhcites' i.year ///
if (fellow_AEAF==0|new_fellow_AEAF==1) & year > 1932, cluster(author) iter(20)

eststo new_fellow_AEAF_2: logit new_fellow_AEAF `female' `journal' `asinhcites' `other_top5' `percentcites' ///
firstpub_30_*  i.year ///
if (fellow_AEAF==0|new_fellow_AEAF==1) & year > 1932, cluster(author) iter(20)

* Sloan 	
eststo new_fellow_Sloan_1: logit new_fellow_Sloan `female' `journal' `asinhcites' i.year ///
if (fellow_Sloan==0|new_fellow_Sloan==1) & years_firstpub <= 8 & year >= 1980, cluster(author) iter(20)

eststo new_fellow_Sloan_2: logit new_fellow_Sloan `female' `journal' `asinhcites' `sloan_top5' i.year ///
if (fellow_Sloan==0|new_fellow_Sloan==1) & years_firstpub <= 8 & year >= 1980, cluster(author) iter(20)

* ============================================================================== 
* export 
label variable Female_start_1970 "Female Economist*(pre-1980)"
label variable Female_1980 "Female Economist*(1980-89)"
label variable Female_1990 "Female Economist*(1990-99)"
label variable Female_2000 "Female Economist*(2000-09)"
label variable Female_2010 "Female Economist*(2010-19)"


local ordering Female_start_1970 Female_1980 Female_1990 Female_2000 Female_2010 
* output file for t9 
esttab new_fellow_EMA_1 new_fellow_EMA_2 new_fellow_AAAS_1 new_fellow_AAAS_2 new_fellow_NAS_1 new_fellow_NAS_2 ///
new_fellow_AEAF_1 new_fellow_AEAF_2 new_fellow_Sloan_1 new_fellow_Sloan_2 ///
using "tables/table9.csv", keep(`ordering') order(`ordering') ///
csv se(%9.3f) b(%9.3f) pr2 scalars(N) sfmt(%9.0fc) label ///
refcat(Female_start_1970 "Authors' Gender (Omitted: Male Author)", nolabel) ///
title("Table IX") nostar nogaps nodepvars extracols(3 5 7 9 11) replace


log off
log close 

