* table A10

clear all
set more off

 if !missing("$dropbox_dir") {
	local dropbox_dir = "$dropbox_dir"
}
else {
	local dropbox_dir "C:/Users/Chris/Dropbox"
}
cd "`dropbox_dir'/ECM_Fellow_Study/Replication"
use "`dropbox_dir'\ECM_Fellow_Study\Paper2\econ\output\regression_dataset.dta"

cap log close 
log using "tables/tableA10.log", replace

* ==============================================================================

drop if (author == "Sherwin Rosen" & year >= death + 2 | dead == 1 & author != "Sherwin Rosen")
drop if Ambiguous == 1 
drop if year == 2003
drop if year < 1995

* time dummy 
gen d_1995_2005 = (inrange(year, 1995, 2005))
gen d_2006_2011 = (inrange(year, 2006, 2011))
gen d_2012_2019 = (inrange(year, 2012, 2019))

* variables for gender*decade 	
gen Female_1995_2005 = (d_1995_2005 == 1 & Female == 1)
gen Female_2006_2011 = (d_2006_2011 == 1 & Female == 1)
gen Female_2012_2019 = (d_2012_2019 == 1 & Female == 1)

* regions / institutions 
gen UStop5 = (location == "US Top 5")
gen UStop17 = (location == "US 6-17")
gen USother = (location == "US Below 17")
gen Europe = (location == "Europe")
gen AsiaAustr = (location == "Asia/Australia")
gen LatinAfrica = (location == "Latin America/Africa")

* endorsement missing encode 
replace numEndorsed = . if numEndorsed == 0 

* author id 
egen id = group(author)
order id author

* variables for levels of top5 and cites 
gen top5 = AER_cumulative+QJE_cumulative+REStud_cumulative+ECTA_cumulative+JPE_cumulative
gen top5_cite_cumulative=AER_cite_cumulative+QJE_cite_cumulative+REStud_cite_cumulative+ECTA_cite_cumulative+JPE_cite_cumulative

gen top5_1=(top5==1)
gen top5_2=(top5==2)
gen top5_3=(top5==3)
gen top5_4=(top5==4)
gen top5_5=(top5==5)
gen top5_6=(top5==6)
gen top5_7=(top5>=7)

gen ema_1=(ECTA_cumulative==1)
gen ema_2=(ECTA_cumulative==2)
gen ema_3=(ECTA_cumulative>=3)

gen res_1=(REStud_cumulative==1)
gen res_2=(REStud_cumulative==2)
gen res_3=(REStud_cumulative>=3)

gen qje_1=(QJE_cumulative==1)
gen qje_2=(QJE_cumulative==2)
gen qje_3=(QJE_cumulative>=3)

gen aer_1=(AER_cumulative==1)
gen aer_2=(AER_cumulative==2)
gen aer_3=(AER_cumulative>=3)

gen jpe_1=(JPE_cumulative==1)
gen jpe_2=(JPE_cumulative==2)
gen jpe_3=(JPE_cumulative>=3)

* levels of citation 
gen if_top5=(top5>=1)
gen if_riskset = (fellow_EMA == 0 | new_fellow_EMA == 1)

gen decade = . 
local list_decade 1940 1950 1960 1970 1980 1990 2000 2010 
foreach decade in `list_decade'{
	replace decade = `decade' if floor(year/10)*10 == `decade'
}
replace decade = 1930 if inrange(year, 1931, 1939)

gen topcite = . 

levelsof decade, local(levels)
foreach d in `levels'{
	
	_pctile top5_cite_cumulative if decade == `d' & if_top5 == 1 & if_riskset == 1, p(50 70 80 90 95 97.5 99)
	return list
	
	replace topcite = 1 if top5_cite_cumulative < r(r1) & decade == `d'
	replace topcite = 2 if top5_cite_cumulative < r(r2) & top5_cite_cumulative >= r(r1) & decade == `d'
	replace topcite = 3 if top5_cite_cumulative < r(r3) & top5_cite_cumulative >= r(r2) & decade == `d'
	replace topcite = 4 if top5_cite_cumulative < r(r4) & top5_cite_cumulative >= r(r3) & decade == `d'
	replace topcite = 5 if top5_cite_cumulative < r(r5) & top5_cite_cumulative >= r(r4) & decade == `d'
	replace topcite = 6 if top5_cite_cumulative < r(r6) & top5_cite_cumulative >= r(r5) & decade == `d'
	replace topcite = 7 if top5_cite_cumulative < r(r7) & top5_cite_cumulative >= r(r6) & decade == `d'
	replace topcite = 8 if top5_cite_cumulative >= r(r7) & decade == `d'
	
}

gen topcite1 = (topcite == 1)
gen topcite2 = (topcite == 2)
gen topcite3 = (topcite == 3)
gen topcite4 = (topcite == 4)
gen topcite5 = (topcite == 5)
gen topcite6 = (topcite == 6) 
gen topcite7 = (topcite == 7) 
gen topcite8 = (topcite == 8)

* years since first pub 
gen firstpub_10 = (years_firstpub < 20 & years_firstpub >= 10)
gen firstpub_20 = (years_firstpub < 30 & years_firstpub >= 20)
gen firstpub_30 = (years_firstpub >= 30)

drop decade topcite

* ==============================================================================
* controls 

local gender Female_1995_2005 Female_2006_2011 Female_2012_2019
local region UStop5 UStop17 Europe AsiaAustr LatinAfrica
unab journal: AER_cumulative-TE_cumulative top5_1-top5_7 ema_* res_* aer_* qje_* jpe_* 
unab citations: asinh*cites topcite2-topcite8
unab years_firstpub: firstpub_10-firstpub_30
local year_fe i.year 

eststo new_fellow_EMA_1: logit new_fellow_EMA `gender' ///
`journal' `citations' `years_firstpub' `year_fe' if nominee == 1, cluster(author) 
eststo new_fellow_EMA_2: logit new_fellow_EMA `gender' `region' ///
`journal' `citations' `years_firstpub' `year_fe' if nominee == 1, cluster(author) 

eststo numVotes_1: poisson numVotes Female_2006_2011 Female_2012_2019 ///
`journal' `citations' `years_firstpub' `year_fe' if (fellow_EMA==0|nominee==1), vce(cluster id)	
eststo numVotes_2: poisson numVotes Female_2006_2011 Female_2012_2019 `region' ///
`journal' `citations' `years_firstpub' `year_fe' if (fellow_EMA==0|nominee==1), vce(cluster id)	

eststo numEndorsed_1: poisson numEndorsed `gender' ///
`journal' `citations' `years_firstpub' `year_fe' if nominee == 1 & byCommittee == 0, vce(cluster id)	
eststo numEndorsed_2: poisson numEndorsed `gender' `region' ///
`journal' `citations' `years_firstpub' `year_fe' if nominee == 1 & byCommittee == 0, vce(cluster id)	


* ==============================================================================
* some formatting 
label variable asinhEMAcites "Asinh citations in Econometrica"
label variable asinhREScites "Asinh citations in REStud"
label variable asinhAERcites "Asinh citations in AER"
label variable asinhQJEcites "Asinh citations in QJE"
label variable asinhJPEcites "Asinh citations in JPE"

label variable ECTA_cumulative "Papers in Econometrica"
label variable REStud_cumulative "Papers in Review of Economic Studies"
label variable AER_cumulative "Papers in American Economic Review"
label variable QJE_cumulative "Papers in Quarterly Journal of Eco."
label variable JPE_cumulative "Papers in JPE"

* output file 
unab ordering: Female_1995_2005 Female_2006_2011 Female_2012_2019 ///
	ECTA_cumulative asinhEMAcites REStud_cumulative asinhREScites ///
	AER_cumulative asinhAERcites QJE_cumulative asinhQJEcites /// 
	JPE_cumulative asinhJPEcites
	
local ext_t10 new_fellow_EMA_* numVotes_* numEndorsed_*

local format csv se(%9.3f) b(%9.3f) pr2 scalars(N) sfmt(%9.0fc) label nostar nogaps nodepvars


esttab `ext_t10' using "tables/tableA10.csv", ///
order(`ordering') `format' mgroups(slection numVotes numEndorsed, pattern(1 0 1 0 1 0)) ///
refcat(Female "Authors' Genders (Omitted: Male Author)" ///
	   ECTA_cumulative "Cumulative Publications and Citations Received in top-5 journals", nolabel) ///
title("Table A10") keep(`ordering') extracols(3 5 7) replace

log off 
log close 

