* table A12

eststo clear
clear

if !missing("$dropbox_dir") {
	local dropbox_dir = "$dropbox_dir"
}
else {
	local dropbox_dir "C:/Users/Chris/Dropbox"
}
cd "`dropbox_dir'/ECM_Fellow_Study/Replication"
use "`dropbox_dir'\ECM_Fellow_Study\Paper2\econ\output\regression_dataset.dta"

cap log close 
log using "tables/tableA12.log", replace

* ==============================================================================
rename (asinhREScites asinhEMAcites) (asinhREStudcites asinhECTAcites)
drop if Ambiguous == 1
drop if (author == "Sherwin Rosen" & year >= death + 2 | dead == 1 & author != "Sherwin Rosen")

* generate filter for NAS primary fellows. For secondary fellows, we keep them in 
* the risk set up to and including the year they are elected, but are not counted as
* a fellow and then dropped after that year
gen NAS_sample = 1
replace new_fellow_NAS = 0 if primary_NAS_econ == 0
replace NAS_sample = 0 if year > year_appointed_NAS & primary_NAS_econ == 0

* same for AAAS 
gen AAAS_sample = 1
replace new_fellow_AAAS = 0 if AAAS_flags == 3
replace AAAS_sample = 0 if year > year_appointed_AAAS & AAAS_flags == 3

* indicator for nominated by a fellow 
gen nomiFellow = 1 if byCommittee == 0 
replace nomiFellow = 0 if byCommittee != 0 

gen nomiCommittee = 1 if byCommittee == 1
replace nomiCommittee = 0 if byCommittee != 1 

* levels of top5 and cites 
gen top5 = AER_cumulative+QJE_cumulative+REStud_cumulative+ECTA_cumulative+JPE_cumulative
gen top5_cite_cumulative=AER_cite_cumulative+QJE_cite_cumulative+REStud_cite_cumulative+ECTA_cite_cumulative+JPE_cite_cumulative
drop if missing(top5_cite_cumulative) /* unmatched fellows */

gen top5_1=(top5==1)
gen top5_2=(top5==2)
gen top5_3=(top5==3)
gen top5_4=(top5==4)
gen top5_5=(top5==5)
gen top5_6=(top5==6)
gen top5_7=(top5>=7)

gen other_top5_1=(top5 <= 3)
gen other_top5_2=(top5 >= 4 & top5 <= 5)
gen other_top5_3=(top5 >= 6 & top5 <= 7)
gen other_top5_4=(top5 >= 8 & top5 <= 9)
gen other_top5_5=(top5 >= 10 & top5 <= 11)
gen other_top5_6=(top5 >= 12 & top5 <= 13)
gen other_top5_7=(top5 >= 14 & top5 <= 15)
gen other_top5_8=(top5 >= 16)

gen ema_1=(ECTA_cumulative==1)
gen ema_2=(ECTA_cumulative==2)
gen ema_3=(ECTA_cumulative>=3)

gen res_1=(REStud_cumulative==1)
gen res_2=(REStud_cumulative==2)
gen res_3=(REStud_cumulative>=3)

gen qje_1=(QJE_cumulative==1)
gen qje_2=(QJE_cumulative==2)
gen qje_3=(QJE_cumulative>=3)

gen aer_1=(AER_cumulative==1)
gen aer_2=(AER_cumulative==2)
gen aer_3=(AER_cumulative>=3)

gen jpe_1=(JPE_cumulative==1)
gen jpe_2=(JPE_cumulative==2)
gen jpe_3=(JPE_cumulative>=3)

* levels of citation 
gen if_top5=(top5>=1)
gen if_riskset = (fellow_EMA == 0 | new_fellow_EMA == 1)

gen decade = . 
local list_decade 1940 1950 1960 1970 1980 1990 2000 2010 
foreach decade in `list_decade'{
	replace decade = `decade' if floor(year/10)*10 == `decade'
}
replace decade = 1930 if inrange(year, 1931, 1939)

gen topcite = . 

levelsof decade, local(levels)
foreach d in `levels'{
	
	_pctile top5_cite_cumulative if decade == `d' & if_top5 == 1 & if_riskset == 1, p(50 70 80 90 95 97.5 99)
	return list
	
	replace topcite = 1 if top5_cite_cumulative < r(r1) & decade == `d'
	replace topcite = 2 if top5_cite_cumulative < r(r2) & top5_cite_cumulative >= r(r1) & decade == `d'
	replace topcite = 3 if top5_cite_cumulative < r(r3) & top5_cite_cumulative >= r(r2) & decade == `d'
	replace topcite = 4 if top5_cite_cumulative < r(r4) & top5_cite_cumulative >= r(r3) & decade == `d'
	replace topcite = 5 if top5_cite_cumulative < r(r5) & top5_cite_cumulative >= r(r4) & decade == `d'
	replace topcite = 6 if top5_cite_cumulative < r(r6) & top5_cite_cumulative >= r(r5) & decade == `d'
	replace topcite = 7 if top5_cite_cumulative < r(r7) & top5_cite_cumulative >= r(r6) & decade == `d'
	replace topcite = 8 if top5_cite_cumulative >= r(r7) & decade == `d'
	
}

gen topcite1 = (topcite == 1)
gen topcite2 = (topcite == 2)
gen topcite3 = (topcite == 3)
gen topcite4 = (topcite == 4)
gen topcite5 = (topcite == 5)
gen topcite6 = (topcite == 6) 
gen topcite7 = (topcite == 7) 
gen topcite8 = (topcite == 8)

* years since first pub 
gen firstpub_10 = (years_firstpub < 20 & years_firstpub >= 10)
gen firstpub_20 = (years_firstpub < 30 & years_firstpub >= 20)
gen firstpub_30 = (years_firstpub >= 30)

drop decade topcite

* new_fellow_EMA (cols 1-3)
* ============================================================================== 
* generate index for top 5, non-top5 publications/citations 

* gender by decade interaction terms 
local list_decade 1990 2000 2010
foreach decade in `list_decade'{
	gen year_`decade' = 0 
	replace year_`decade' = 1 if floor(year/10)*10== `decade'
	gen Female_`decade' = Female * year_`decade'
}


preserve 

* run logit regression 
logit new_fellow_EMA Female_1990 Female_2000 Female_2010 ///
AER_cumulative-TE_cumulative asinh*cites ///
aer_* qje_* jpe_* ema_* res_*  ///
top5_1-top5_7 topcite2-topcite8 firstpub_10-firstpub_30 i.year ///
if (fellow_EMA==0|new_fellow_EMA==1) & year >= 1990, cluster(author)

mat b = e(b)
mat lis b

* extract the weights as scalars 
unab journal: AER_cumulative-TE_cumulative asinh*cites ///
aer_* qje_* jpe_* ema_* res_*  ///
top5_* topcite2-topcite8 firstpub_10-firstpub_30

foreach j in `journal'{
	scalar w_`j' =el(matrix(b), 1, colnumb(matrix(b),"`j'"))
}


* gen weighted number of top5s /non-top5s, by single/all-author
unab journal_list: single_AER_cumulative-single_TE_cumulative
foreach j in `journal_list'{
	
	local journal = substr("`j'", strpos("`j'", "_")+1, .)
	gen w_`j' = `j' * scalar(w_`journal')
}

unab journal_list: AER_cumulative-TE_cumulative 
foreach j in `journal_list'{
	
	gen w_`j' = `j' * scalar(w_`j')
}

* gen weighted number of top5 asinh citations 
unab citation: asinh*cites
foreach c in `citation'{
	
	local journal = substr("`c'", 6, strrpos("`c'", "cites")-6)
	
	gen w_`journal'_cite_cumulative = asinh(`journal'_cite_cumulative) * scalar(w_`c') 
}

* gen weighted levels of top5 and cites and years_firstpub
unab levels_top5: aer_* qje_* jpe_* ema_* res_* top5_* topcite2-topcite8 firstpub_10-firstpub_30
foreach j in `levels_top5'{
	
	gen w_`j' = `j' * scalar(w_`j')
	
}


 * gen weighted number of top5 asinh citations, by single/multi-author
unab citations: single_ECTA_cite_cumulative single_AER_cite_cumulative ///
single_QJE_cite_cumulative single_REStud_cite_cumulative single_JPE_cite_cumulative  

foreach j in `citations'{
	
	local c = substr("`j'", strpos("`j'", "_")+1, strrpos("`j'", "_cite")-strpos("`j'", "_")-1)

	gen w_`j' = asinh(`j') * scalar(w_asinh`c'cites) 
}
 
* weighted number of top 5s, single_author 
gen single_top5 = w_single_AER_cumulative + w_single_QJE_cumulative +w_single_JPE_cumulative + w_single_ECTA_cumulative + w_single_REStud_cumulative
replace single_top5 = 0 if single_top5 == . 

* weighted number of non-top5s, single author
egen single_other = rowtotal(w_single_AER_cumulative-w_single_TE_cumulative)
replace single_other = single_other - single_top5

* weighted number of top5s 
gen all_top5 = w_AER_cumulative + w_QJE_cumulative + w_JPE_cumulative + w_ECTA_cumulative + w_REStud_cumulative 
replace all_top5 = 0 if all_top5 == . 

* weighted number of non-top5s
egen all_other = rowtotal(w_AER_cumulative-w_TE_cumulative)
replace all_other = all_other - all_top5

* weighted number of citations
gen w_citations = w_AER_cite_cumulative + w_QJE_cite_cumulative + w_JPE_cite_cumulative + w_ECTA_cite_cumulative + w_REStud_cite_cumulative
replace w_citations = 0 if w_citations == . 

* weighted number of citations, single author 
gen w_single_citations = w_single_AER_cite_cumulative + w_single_ECTA_cite_cumulative + w_single_JPE_cite_cumulative + w_single_QJE_cite_cumulative + w_single_REStud_cite_cumulative
replace w_single_citations = 0 if w_single_citations == .


* weighted number of levels of top5s 
gen w_l_top5 = w_aer_1 + w_aer_2 + w_aer_3 + w_qje_1 + w_qje_2 + w_qje_3 + w_jpe_1 + w_jpe_2 + w_jpe_3 + w_ema_1 + w_ema_2 + w_ema_3 + w_res_1 + w_res_2 + w_res_3 + ///
w_top5_1 + w_top5_2 + w_top5_3 + w_top5_4 + w_top5_5 + w_top5_6 + w_top5_7 

* weighted  number of levels of cites 
gen w_l_cite = w_topcite2 + w_topcite3 + w_topcite4 + w_topcite5 + w_topcite6 + w_topcite7 + w_topcite8 

* index 
gen journal_index = all_top5 + w_citations+all_other
gen single_journal_index = single_top5 + w_single_citations + single_other
gen control_index = w_l_top5 + w_l_cite + w_firstpub_10 + w_firstpub_20 + w_firstpub_30 

* female x index (centered around mean)
local list_coauthorship journal_index single_journal_index control_index
foreach coauthorship in `list_coauthorship'{
	egen mean_`coauthorship' = mean(`coauthorship'/ (new_fellow_EMA == 1))
	gen female_`coauthorship' = Female * (`coauthorship' - mean_`coauthorship')
}


* logit regressions (cols 1-3)
* reg locals 
local gender Female_1990 Female_2000 Female_2010
local index journal_index single_journal_index control_index
local female_index female_journal_index female_single_journal_index
local year i.year

logit new_fellow_EMA `gender' journal_index control_index `year' ///
if (fellow_EMA==0|new_fellow_EMA==1) & year >= 1990, cluster(author)

* specification 1: only the index 
eststo new_fellow_EMA_1: logit new_fellow_EMA `gender' `index' `year' ///
if (fellow_EMA==0|new_fellow_EMA==1) & year >= 1990, cluster(author)

* specification 2: specification 1 plus female*coauthorship variables 
eststo new_fellow_EMA_2: logit new_fellow_EMA `gender' `index' `female_index' `year' ///
if (fellow_EMA==0|new_fellow_EMA==1) & year >= 1990, cluster(author)

* specification 3: specification 2 plus female_other_index
eststo new_fellow_EMA_3: logit new_fellow_EMA `gender' `index' `female_index' female_control_index `year' ///
if (fellow_EMA==0|new_fellow_EMA==1) & year >= 1990, cluster(author)

restore 


* nomination/other fellowships (col 3 on)
* ==============================================================================
* index weighted by the same model as col 1/2

gen decade_nominee = (inrange(year, 1990, 2019))
gen decade_nomiFellow = (inrange(year, 1995, 2019) & year != 2003)
gen decade_nomiCommittee =  (inrange(year, 1995, 2019) & year != 2003)

local decade decade_nominee decade_nomiFellow decade_nomiCommittee 
foreach decade in `decade'{
	
	preserve 
	
	local v = substr("`decade'", strpos("`decade'", "_")+1, .)
	
	keep if `decade' == 1
	
	* time interval dummy  
	gen decades_1990 = 0 
	replace decades_1990 = 1 if year < 2000 & year >= 1990 
	gen decades_2000 = 0
	replace decades_2000 = 1 if year >= 2000   


	* run logit regression 
	logit `v' Female_1990 Female_2000 Female_2010 ///
	AER_cumulative-TE_cumulative asinh*cites  ///
	aer_* qje_* jpe_* ema_* res_* top5_1-top5_7 ///
	topcite2-topcite8 firstpub_10-firstpub_30 i.year ///
	if (nominee == 1|fellow_EMA == 0)& `decade' == 1, cluster(author)

	mat b = e(b)
	mat lis b

	* extract the weights as scalars 
	unab journal: AER_cumulative-TE_cumulative asinh*cites ///
	aer_* qje_* jpe_* ema_* res_*  ///
	top5_* topcite2-topcite8 firstpub_10-firstpub_30

	foreach j in `journal'{
		scalar w_`j' =el(matrix(b), 1, colnumb(matrix(b),"`j'"))
	}

	* gen weighted number of top5s /non-top5s, by single/all-author
	unab journal_list: single_AER_cumulative-single_TE_cumulative
	foreach j in `journal_list'{
		
		local journal = substr("`j'", strpos("`j'", "_")+1, .)
		gen w_`j' = `j' * scalar(w_`journal')
	}

	unab journal_list: AER_cumulative-TE_cumulative 
	foreach j in `journal_list'{
		
		gen w_`j' = `j' * scalar(w_`j')
	}

	* gen weighted number of top5 asinh citations 
	unab citation: asinh*cites
	foreach c in `citation'{
		
		local journal = substr("`c'", 6, strrpos("`c'", "cites")-6)
		
		gen w_`journal'_cite_cumulative = asinh(`journal'_cite_cumulative) * scalar(w_`c') 
	}

	* gen weighted levels of top5 and cites and years_firstpub
	unab levels_top5: aer_* qje_* jpe_* ema_* res_* top5_* topcite2-topcite8 firstpub_10-firstpub_30
	foreach j in `levels_top5'{
		
		gen w_`j' = `j' * scalar(w_`j')
		
	}


	 * gen weighted number of top5 asinh citations, by single/multi-author
	unab citations: single_ECTA_cite_cumulative single_AER_cite_cumulative single_QJE_cite_cumulative  ///
	single_REStud_cite_cumulative single_JPE_cite_cumulative  

	foreach j in `citations'{
		
		local c = substr("`j'", strpos("`j'", "_")+1, strrpos("`j'", "_cite")-strpos("`j'", "_")-1)

		gen w_`j' = asinh(`j') * scalar(w_asinh`c'cites) 
	}
	 
	* weighted number of top 5s, single_author 
	gen single_top5 = w_single_AER_cumulative + w_single_QJE_cumulative +w_single_JPE_cumulative + w_single_ECTA_cumulative + w_single_REStud_cumulative
	replace single_top5 = 0 if single_top5 == . 

	* weighted number of non-top5s, single author
	egen single_other = rowtotal(w_single_AER_cumulative-w_single_TE_cumulative)
	replace single_other = single_other - single_top5

	* weighted number of top5s 
	gen all_top5 = w_AER_cumulative + w_QJE_cumulative + w_JPE_cumulative + w_ECTA_cumulative + w_REStud_cumulative 

	* weighted number of non-top5s
	egen all_other = rowtotal(w_AER_cumulative-w_TE_cumulative)
	replace all_other = all_other - all_top5

	* weighted number of citations
	gen w_citations = w_AER_cite_cumulative + w_QJE_cite_cumulative + w_JPE_cite_cumulative + w_ECTA_cite_cumulative + w_REStud_cite_cumulative
	replace w_citations = 0 if w_citations == . 

	* weighted number of citations, single author 
	gen w_single_citations = w_single_AER_cite_cumulative + w_single_ECTA_cite_cumulative + w_single_JPE_cite_cumulative + w_single_QJE_cite_cumulative + w_single_REStud_cite_cumulative
	replace w_single_citations = 0 if w_single_citations == .

	* weighted number of levels of top5s 
	gen w_l_top5 = w_aer_1 + w_aer_2 + w_aer_3 + w_qje_1 + w_qje_2 + w_qje_3 + w_jpe_1 + w_jpe_2 + w_jpe_3 + w_ema_1 + w_ema_2 + w_ema_3 + w_res_1 + w_res_2 + w_res_3 + ///
	w_top5_1 + w_top5_2 + w_top5_3 + w_top5_4 + w_top5_5 + w_top5_6 + w_top5_7 

	* weighted  number of levels of cites 
	gen w_l_cite = w_topcite2 + w_topcite3 + w_topcite4 + w_topcite5 + w_topcite6 + w_topcite7 + w_topcite8 

	* index 
	gen journal_index = all_top5 + w_citations + all_other
	gen single_journal_index = single_top5 + w_single_citations + single_other
	gen control_index = w_l_top5 + w_l_cite + w_firstpub_10 + w_firstpub_20 + w_firstpub_30 

	* female x index (centered around mean)
	local list_coauthorship journal_index single_journal_index control_index
	foreach coauthorship in `list_coauthorship'{
		egen mean_`coauthorship' = mean(`coauthorship'/ (new_fellow_EMA == 1))
		gen female_`coauthorship' = Female * (`coauthorship' - mean_`coauthorship')
	}

	* reg locals 
	local gender Female_1990 Female_2000 Female_2010
	local index journal_index single_journal_index control_index
	local female_index female_journal_index female_single_journal_index
	local year i.year
	
	* specification 1
	logit `v' `gender' journal_index control_index `year' ///
	if (nominee == 1|fellow_EMA == 0) & `decade' == 1, cluster(author)
	
	* specification 2
	eststo `v'_1: logit `v' `gender' `index' `female_index' `year' ///
	if (nominee == 1|fellow_EMA == 0) & `decade' == 1, cluster(author)
	
	eststo `v'_2: logit `v' `gender' `index' `female_index' female_control_index `year' ///
	if (nominee == 1|fellow_EMA == 0) & `decade' == 1, cluster(author)

	restore 

	
}


* other fellowships (col 6 and 7)
* ==============================================================================
* AAAS 

gen decade_new_fellow_AAAS = (inrange(year, 1990, 2019))

preserve 
	
	keep if decade_new_fellow_AAAS == 1

	* run logit regression 
	logit new_fellow_AAAS Female_1990 Female_2000 Female_2010 ///
		AER_cumulative-TE_cumulative asinh*cites other_top5_1-other_top5_8 ///
		topcite2-topcite8 firstpub_20 firstpub_30 i.year ///
		if (new_fellow_AAAS == 1|fellow_AAAS == 0) * AAAS_sample, cluster(author)

	mat b = e(b)
	mat lis b

	* extract the weights as scalars 
	unab journal: AER_cumulative-TE_cumulative asinh*cites ///
	other_top5_* topcite2-topcite8 firstpub_20 firstpub_30

	foreach j in `journal'{
		scalar w_`j' =el(matrix(b), 1, colnumb(matrix(b),"`j'"))
	}

	* gen weighted number of top5s /non-top5s, by single/all-author
	unab journal_list: single_AER_cumulative-single_TE_cumulative
	foreach j in `journal_list'{
		
		local journal = substr("`j'", strpos("`j'", "_")+1, .)
		gen w_`j' = `j' * scalar(w_`journal')
	}

	unab journal_list: AER_cumulative-TE_cumulative 
	foreach j in `journal_list'{
		
		gen w_`j' = `j' * scalar(w_`j')
	}

	* gen weighted number of top5 asinh citations 
	unab citation: asinh*cites
	foreach c in `citation'{
		
		local journal = substr("`c'", 6, strrpos("`c'", "cites")-6)
		
		gen w_`journal'_cite_cumulative = asinh(`journal'_cite_cumulative) * scalar(w_`c') 
	}

	* gen weighted levels of top5 and cites and years_firstpub
	unab levels_top5: other_top5_* topcite2-topcite8 firstpub_20 firstpub_30
	foreach j in `levels_top5'{
		
		gen w_`j' = `j' * scalar(w_`j')
		
	}


	* gen weighted number of top5 asinh citations, by single/multi-author
	unab citations: single_ECTA_cite_cumulative single_AER_cite_cumulative single_QJE_cite_cumulative  ///
	single_REStud_cite_cumulative single_JPE_cite_cumulative  

	foreach j in `citations'{
		
		local c = substr("`j'", strpos("`j'", "_")+1, strrpos("`j'", "_cite")-strpos("`j'", "_")-1)

		gen w_`j' = asinh(`j') * scalar(w_asinh`c'cites) 
	}
		 
	* weighted number of top 5s, single_author 
	gen single_top5 = w_single_AER_cumulative + w_single_QJE_cumulative +w_single_JPE_cumulative + w_single_ECTA_cumulative + w_single_REStud_cumulative
	replace single_top5 = 0 if single_top5 == . 

	* weighted number of non-top5s, single author
	egen single_other = rowtotal(w_single_AER_cumulative-w_single_TE_cumulative)
	replace single_other = single_other - single_top5

	* weighted number of top5s 
	gen all_top5 = w_AER_cumulative + w_QJE_cumulative + w_JPE_cumulative + w_ECTA_cumulative + w_REStud_cumulative 

	* weighted number of non-top5s
	egen all_other = rowtotal(w_AER_cumulative-w_TE_cumulative)
	replace all_other = all_other - all_top5

	* weighted number of citations
	gen w_citations = w_AER_cite_cumulative + w_QJE_cite_cumulative + w_JPE_cite_cumulative + w_ECTA_cite_cumulative + w_REStud_cite_cumulative
	replace w_citations = 0 if w_citations == . 

	* weighted number of citations, single author 
	gen w_single_citations = w_single_AER_cite_cumulative + w_single_ECTA_cite_cumulative + w_single_JPE_cite_cumulative + w_single_QJE_cite_cumulative + w_single_REStud_cite_cumulative
	replace w_single_citations = 0 if w_single_citations == .

	* weighted number of levels of top5s 
	gen w_l_top5 = w_other_top5_1 + w_other_top5_2 + w_other_top5_3 + w_other_top5_4 + w_other_top5_5 + w_other_top5_6 + w_other_top5_7 + w_other_top5_8 

	* weighted  number of levels of cites 
	gen w_l_cite = w_topcite2 + w_topcite3 + w_topcite4 + w_topcite5 + w_topcite6 + w_topcite7 + w_topcite8 

	* index 
	gen journal_index = all_top5 + w_citations + all_other
	gen single_journal_index = single_top5 + w_single_citations + single_other
	gen control_index = w_l_top5 + w_l_cite + w_firstpub_20 + w_firstpub_30 

	* female x index (centered around mean)
	local list_coauthorship journal_index single_journal_index control_index
	foreach coauthorship in `list_coauthorship'{
		egen mean_`coauthorship' = mean(`coauthorship'/ (new_fellow_EMA == 1))
		gen female_`coauthorship' = Female * (`coauthorship' - mean_`coauthorship')
	}

	* reg locals 
	local gender Female_1990 Female_2000 Female_2010
	local index journal_index single_journal_index control_index
	local female_index female_journal_index female_single_journal_index
	local year i.year

	* specification 1
	logit new_fellow_AAAS `gender' journal_index control_index `year' ///
	if (new_fellow_AAAS == 1|fellow_AAAS == 0) & AAAS_sample, cluster(author)

	* specification 2
	eststo new_fellow_AAAS_1: logit new_fellow_AAAS `gender' `index' `female_index' `year' ///
	if (new_fellow_AAAS == 1|fellow_AAAS == 0) & AAAS_sample, cluster(author)

	eststo new_fellow_AAAS_2: logit new_fellow_AAAS `gender' `index' `female_index' female_control_index `year' ///
	if (new_fellow_AAAS == 1|fellow_AAAS == 0) & AAAS_sample, cluster(author)

restore 

	
* NAS 

gen decade_new_fellow_NAS = (inrange(year, 1990, 2019))

preserve 

	keep if decade_new_fellow_NAS == 1

	* run logit regression 
	logit new_fellow_NAS Female_1990 Female_2000 Female_2010 ///
		AER_cumulative-TE_cumulative asinh*cites other_top5_1-other_top5_8 ///
		topcite2-topcite8 firstpub_30 i.year ///
		if (new_fellow_NAS == 1|fellow_NAS == 0) & NAS_sample, cluster(author)

	mat b = e(b)
	mat lis b

	* extract the weights as scalars 
	unab journal: AER_cumulative-TE_cumulative asinh*cites ///
	other_top5_* topcite2-topcite8 firstpub_30

	foreach j in `journal'{
		scalar w_`j' =el(matrix(b), 1, colnumb(matrix(b),"`j'"))
	}


	* gen weighted number of top5s /non-top5s, by single/all-author
	unab journal_list: single_AER_cumulative-single_TE_cumulative
	foreach j in `journal_list'{
		
		local journal = substr("`j'", strpos("`j'", "_")+1, .)
		gen w_`j' = `j' * scalar(w_`journal')
	}

	unab journal_list: AER_cumulative-TE_cumulative 
	foreach j in `journal_list'{
		
		gen w_`j' = `j' * scalar(w_`j')
	}


	* gen weighted number of top5 asinh citations 
	unab citation: asinh*cites
	foreach c in `citation'{
		
		local journal = substr("`c'", 6, strrpos("`c'", "cites")-6)
		
		gen w_`journal'_cite_cumulative = asinh(`journal'_cite_cumulative) * scalar(w_`c') 
	}

	* gen weighted levels of top5 and cites and years_firstpub
	unab levels_top5: other_top5_* topcite2-topcite8 firstpub_30
	foreach j in `levels_top5'{
		
		gen w_`j' = `j' * scalar(w_`j')
		
	}


	* gen weighted number of top5 asinh citations, by single/multi-author
	unab citations: single_ECTA_cite_cumulative single_AER_cite_cumulative single_QJE_cite_cumulative  ///
	single_REStud_cite_cumulative single_JPE_cite_cumulative  

	foreach j in `citations'{
		
		local c = substr("`j'", strpos("`j'", "_")+1, strrpos("`j'", "_cite")-strpos("`j'", "_")-1)

		gen w_`j' = asinh(`j') * scalar(w_asinh`c'cites) 
	}
		 
	* weighted number of top 5s, single_author 
	gen single_top5 = w_single_AER_cumulative + w_single_QJE_cumulative +w_single_JPE_cumulative + w_single_ECTA_cumulative + w_single_REStud_cumulative
	replace single_top5 = 0 if single_top5 == . 

	* weighted number of non-top5s, single author
	egen single_other = rowtotal(w_single_AER_cumulative-w_single_TE_cumulative)
	replace single_other = single_other - single_top5

	* weighted number of top5s 
	gen all_top5 = w_AER_cumulative + w_QJE_cumulative + w_JPE_cumulative + w_ECTA_cumulative + w_REStud_cumulative 

	* weighted number of non-top5s
	egen all_other = rowtotal(w_AER_cumulative-w_TE_cumulative)
	replace all_other = all_other - all_top5

	* weighted number of citations
	gen w_citations = w_AER_cite_cumulative + w_QJE_cite_cumulative + w_JPE_cite_cumulative + w_ECTA_cite_cumulative + w_REStud_cite_cumulative
	replace w_citations = 0 if w_citations == . 

	* weighted number of citations, single author 
	gen w_single_citations = w_single_AER_cite_cumulative + w_single_ECTA_cite_cumulative + w_single_JPE_cite_cumulative + w_single_QJE_cite_cumulative + w_single_REStud_cite_cumulative
	replace w_single_citations = 0 if w_single_citations == .

	* weighted number of levels of top5s 
	gen w_l_top5 = w_other_top5_1 + w_other_top5_2 + w_other_top5_3 + w_other_top5_4 + w_other_top5_5 + w_other_top5_6 + w_other_top5_7 + w_other_top5_8 

	* weighted  number of levels of cites 
	gen w_l_cite = w_topcite2 + w_topcite3 + w_topcite4 + w_topcite5 + w_topcite6 + w_topcite7 + w_topcite8 

	* index 
	gen journal_index = all_top5 + w_citations + all_other
	gen single_journal_index = single_top5 + w_single_citations + single_other
	gen control_index = w_l_top5 + w_l_cite + w_firstpub_30 

	* female x index (centered around mean)
	local list_coauthorship journal_index single_journal_index control_index
	foreach coauthorship in `list_coauthorship'{
		egen mean_`coauthorship' = mean(`coauthorship'/ (new_fellow_EMA == 1))
		gen female_`coauthorship' = Female * (`coauthorship' - mean_`coauthorship')
	}

	* reg locals 
	local gender Female_1990 Female_2000 Female_2010
	local index journal_index single_journal_index control_index
	local female_index female_journal_index female_single_journal_index
	local year i.year

	* specification 1
	logit new_fellow_NAS `gender' journal_index control_index `year' ///
	if (new_fellow_NAS == 1|fellow_NAS == 0) & NAS_sample, cluster(author)

	* specification 2
	eststo new_fellow_NAS_1: logit new_fellow_NAS `gender' `index' `female_index' `year' ///
	if (new_fellow_NAS == 1|fellow_NAS == 0) & NAS_sample, cluster(author)

	eststo new_fellow_NAS_2: logit new_fellow_NAS `gender' `index' `female_index' female_control_index `year' ///
	if (new_fellow_NAS == 1|fellow_NAS == 0) & NAS_sample, cluster(author)

restore 


* ==============================================================================
* export

label variable Female_1990 "Female Economist*(1990-99)"
label variable Female_2000 "Female Economist*(2000-09)"
label variable Female_2010 "Female Economist*(2010-19)"

* ordering of the vars  
local ordering Female_1990 Female_2000 Female_2010 ///
journal_index single_journal_index control_index ///
female_journal_index female_single_journal_index

* output file 
esttab new_fellow_EMA_1 new_fellow_EMA_2 nominee_1 nomiFellow_1 nomiCommittee_1 new_fellow_AAAS_1 new_fellow_NAS_1 ///
using "tables/tableA12_comb.csv", ///
keep(`ordering') order(`ordering') extracols(3 6) ///
csv se(%9.3f) b(%9.3f) pr2 scalars(N) sfmt(%9.0fc) ///
refcat(Female_start_1970 "Authors' Gender (Omitted: Male Author)" journal_index "Measure of Coauthorhip" ///
female_journal_index "Measure of Coauthorhip Interacted with Female", nolabel) ///
title("Table A12") nogaps nodepvars nostar label replace


* ordering of the vars  
local ordering Female_1990 Female_2000 Female_2010 ///
journal_index single_journal_index control_index ///
female_journal_index female_single_journal_index female_control_index

* output file 
esttab new_fellow_EMA_1 new_fellow_EMA_3 nominee_2 nomiFellow_2 nomiCommittee_2 new_fellow_AAAS_2 new_fellow_NAS_2 ///
using "tables/tableA12_comb.csv", ///
keep(`ordering') order(`ordering') extracols(3 6) ///
csv se(%9.3f) b(%9.3f) pr2 scalars(N) sfmt(%9.0fc) ///
refcat(Female_start_1970 "Authors' Gender (Omitted: Male Author)" journal_index "Measure of Coauthorhip" ///
female_journal_index "Measure of Coauthorhip Interacted with Female", nolabel) ///
title("Table A12") nogaps nodepvars nostar label replace



log off
log close 

