* Table A13

eststo clear
clear

if !missing("$dropbox_dir") {
	local dropbox_dir = "$dropbox_dir"
}
else {
	local dropbox_dir "C:/Users/Chris/Dropbox"
}
cd "`dropbox_dir'/ECM_Fellow_Study/Replication"
use "`dropbox_dir'\ECM_Fellow_Study\Paper2\econ\output\regression_dataset_public.dta"

cap log close 
log using "tables/tableA13.log", replace


* ==============================================================================
* exclude deceased authors
drop if (author == "Sherwin Rosen" & year >= death + 2 | dead == 1 & author != "Sherwin Rosen")

* generate filter for NAS primary fellows. For secondary fellows, we keep them in 
* the risk set up to and including the year they are elected, but are not counted as
* a fellow and then dropped after that year
gen NAS_sample = 1
replace new_fellow_NAS = 0 if primary_NAS_econ == 0
replace NAS_sample = 0 if year > year_appointed_NAS & primary_NAS_econ == 0

* same for AAAS 
gen AAAS_sample = 1
replace new_fellow_AAAS = 0 if AAAS_flags == 3
replace AAAS_sample = 0 if year > year_appointed_AAAS & AAAS_flags == 3

* cumulative publication variables 
gen JEP_JEL_cumulative = JEP_cumulative + JEL_cumulative 
gen ECA_IER_cumulative = ECA_cumulative + IER_cumulative 
gen Theory_cumulative = JET_cumulative + ET_cumulative + GEB_cumulative + IJGT_cumulative + JMathE_cumulative + TE_cumulative 
gen Econometrics_cumulative = EcT_cumulative + JE_cumulative + JASA_cumulative 
gen Macro_cumulative = AEJ_Macro_cumulative + JME_cumulative 
gen Public_cumulative = JPubE_cumulative + AEJ_Policy_cumulative
gen Micro_cumulative = AEJ_Applied_cumulative + JOLE_cumulative + JEH_cumulative + JHE_cumulative + JPubE_cumulative + JDE_cumulative + AEJ_Policy_cumulative 

* other fellowships 

local sumstat ECTA_cumulative REStud_cumulative AER_cumulative QJE_cumulative JPE_cumulative ///
ECTA_cite_cumulative REStud_cite_cumulative AER_cite_cumulative QJE_cite_cumulative JPE_cite_cumulative ///
Theory_cumulative Econometrics_cumulative Micro_cumulative years_firstpub

local new_fellow new_fellow_AAAS new_fellow_AEAF new_fellow_Sloan new_fellow_NAS 
local AAAS_sample = " & AAAS_sample"
local NAS_sample = " & NAS_sample"
foreach new_fellow in `new_fellow'{

	preserve 

	* keep only fellows 
	keep if `new_fellow' == 1 
	
	local fellow = substr("`new_fellow'", 12, .)
	if "`new_fellow'" == "new_fellow_AAAS" {
		local start_year = 1931
	}
	else {
		* earliest in the dataset 
		egen min_year_appointed_`fellow' = min(year_appointed_`fellow')
		levelsof min_year_appointed_`fellow', local(start_year) 
	}
	* gen decade groups 
	gen decade = "."
	replace decade = "1950-1979" if inrange(year, `start_year', 1979)
	replace decade = "1980-1999" if inrange(year, 1980, 1999)
	replace decade = "2000-2019" if inrange(year, 2000, 2019)
	
	drop if decade == "."
		
	if "`new_fellow'" != "new_fellow_NAS"{
		
		levelsof decade, local(levels) 
		foreach decade in `levels'{	

			local years = substr("`decade'", 6, 9)
			
			* fraction of female/ambiguous 
			eststo `fellow'_1_`years': qui estpost tabstat Female ///
			if decade == "`decade'" ``new_fellow'_sample', s(mean) c(statistics) listwise /* all */
			
			eststo `fellow'_1m_`years': qui estpost tabstat Female ///
			if decade == "`decade'" & Male ==1 ``new_fellow'_sample', s(mean) c(statistics) listwise /* Male Only */
			
			eststo `fellow'_1f_`years': qui estpost tabstat Female ///
			if decade == "`decade'" & Female == 1 ``new_fellow'_sample', s(mean) c(statistics) listwise /* Female Only */
			
			* journal specific summary statistics
			eststo `fellow'_2_`years': qui estpost tabstat `sumstat' ///
			if decade == "`decade'" ``new_fellow'_sample', statistics(mean) columns(statistics) listwise
			
			eststo `fellow'_2m_`years': qui estpost tabstat `sumstat' ///
			if decade == "`decade'" & Male == 1 ``new_fellow'_sample', statistics(mean) columns(statistics) listwise 
			
			eststo `fellow'_2f_`years': qui estpost tabstat `sumstat' ///
			if decade == "`decade'" & Female == 1 ``new_fellow'_sample', statistics(mean) columns(statistics) listwise 
			}
		
		* output file 
		local numbers ",'(1),'(2),'(3),,'(4),'(5),'(6),,'(7),'(8),'(9)"
		esttab `fellow'_1* using "tables/tableA13_`fellow'.csv", ///
		main(mean %12.4fc) onecell nodepvars nostar unstack noobs nonote nogaps nonumbers eqlabels(none) ///
		title("TABLE AVII") sfmt(%9.4fc %9.4fc) ///
		mgroups(1933-1979 1980-1999 2000-2019, pattern(1 0 0 1 0 0 1 0 0)) ///
		mtitles("All" "Male" "Female" "All" "Male" "Female" "All" "Male" "Female") posthead(`numbers') ///
		extracols(4 7 10) label replace 

		esttab `fellow'_2* using "tables/tableA13_`fellow'.csv", ///
		unstack main(mean %12.2fc) nodepvars nostar nomtitle nonumbers nogaps onecell sfmt(%9.4fc) ///
		refcat(fellow_EMA "Fellowships (at Election)" ECTA_cumulative "Cumulative publications in top-5 journals" ///
		ECTA_cite_cumulative "Cum.citations in top-5 journals" ///
		Theory_cumulative "Cum. publications in field journals", nolabel) ///
		extracols(4 7 10) label append 
		
		restore 
	}
	
	* nas is a special case: no females in the earlier years 
	else{
		
		* first generate sum stat for 1950 - 1979 (no female fellows)
		eststo `fellow'_1_1979: qui estpost tabstat Female ///
		if decade == "1950-1979", s(mean) c(statistics) listwise 
		
		eststo `fellow'_1m_1979: qui estpost tabstat Female ///
		if decade == "1950-1979" & Male ==1, s(mean) c(statistics) listwise 

		eststo `fellow'_2_1979: qui estpost tabstat `sumstat' ///
		if decade == "1950-1979", statistics(mean) columns(statistics) listwise 
	
		eststo `fellow'_2m_1979: qui estpost tabstat `sumstat' ///
		if decade == "1950-1979" & Male == 1, statistics(mean) columns(statistics) listwise 
	
		replace decade = "." if decade == "1950-1979"
		drop if decade == "." 
	
		* loop through the remaining time groups (with female fellows)
		levelsof decade, local(levels) 
		foreach decade in `levels'{	

			local years = substr("`decade'", 6, 9)
		
			eststo `fellow'_1_`years': qui estpost tabstat Female ///
			if decade == "`decade'" ``new_fellow'_sample', s(mean) c(statistics) listwise 
		
			eststo `fellow'_1m_`years': qui estpost tabstat Female ///
			if decade == "`decade'" & Male ==1 ``new_fellow'_sample', s(mean) c(statistics) listwise 
		
			eststo `fellow'_1f_`years': qui estpost tabstat Female ///
			if decade == "`decade'" & Female == 1 ``new_fellow'_sample', s(mean) c(statistics) listwise 
		
			* journal specific summary statistics
			eststo `fellow'_2_`years': qui estpost tabstat `sumstat' ///
			if decade == "`decade'" ``new_fellow'_sample', statistics(mean) columns(statistics) listwise 
		
			eststo `fellow'_2m_`years': qui estpost tabstat `sumstat' ///
			if decade == "`decade'" & Male == 1 ``new_fellow'_sample', statistics(mean) columns(statistics) listwise 
		
			eststo `fellow'_2f_`years': qui estpost tabstat `sumstat' ///
			if decade == "`decade'" & Female == 1 ``new_fellow'_sample', statistics(mean) columns(statistics) listwise 
			}
	
		* output file 
		local numbers ",'(1),'(2),,'(4),'(5),'(6),,'(7),'(8),'(9)"
		esttab `fellow'_1* using "tables/tableA13_`fellow'.csv", ///
		main(mean %12.4fc) onecell nodepvars nostar unstack noobs nonote nogaps nonumbers eqlabels(none) ///
		title("TABLE AVII") sfmt(%9.4fc %9.4fc) ///
		mgroups(1933-1979 1980-1999 2000-2019, pattern(1 0 0 1 0 0 1 0 0)) ///
		mtitles("All" "Male" "All" "Male" "Female" "All" "Male" "Female") posthead(`numbers') ///
		extracols(3 6 9) label replace 

		esttab `fellow'_2* using "tables/tableA13_`fellow'.csv", ///
		unstack main(mean %12.2fc) nodepvars nostar nomtitle nonumbers nogaps onecell sfmt(%9.4fc) ///
		refcat(fellow_EMA "Fellowships (at Election)" ECTA_cumulative "Cumulative publications in top-5 journals" ///
		ECTA_cite_cumulative "Cum.citations in top-5 journals" ///
		Theory_cumulative "Cum. publications in field journals", nolabel) ///
		extracols(3 6 9) label append 
	
		restore 
		}

}

*replace female fraction with female percentage
foreach suffix in AAAS AEAF Sloan {
	import delimited "tables/tableA13_`suffix'.csv", clear


	local Female "Female"

	foreach var in v2 v3 v4 v6 v7 v8 v10 v11 v12 {

		replace `var' = subinstr(`var', ".", "", .) ///
			if strpos(v1, "`Female'") 
		replace `var' = substr(`var', 1, 5) + "." + substr(`var', 6, 9) ///
			if strpos(v1, "`Female'") 
	}
	
	
	export delimited "tables/tableA13_`suffix'.csv", replace
}


*replace female fraction with female percentage
local suffix = "NAS"
import delimited "tables/tableA13_`suffix'.csv", clear


local Female "Female"

foreach var in v2 v3 v5 v6 v7 v9 v10 v11  {

	replace `var' = subinstr(`var', ".", "", .) ///
		if strpos(v1, "`Female'") 
	replace `var' = substr(`var', 1, 5) + "." + substr(`var', 6, 9) ///
		if strpos(v1, "`Female'") 
}


export delimited "tables/tableA13_`suffix'.csv", replace



log close 
