* appendix table 14

clear
eststo clear

if !missing("$dropbox_dir") {
	local dropbox_dir = "$dropbox_dir"
}
else {
	local dropbox_dir "C:/Users/Chris/Dropbox"
}
cd "`dropbox_dir'/ECM_Fellow_Study/Replication"
use "`dropbox_dir'\ECM_Fellow_Study\Paper2\econ\output\regression_dataset_public.dta"

cap log close 
log using "tables/tableA14.log", replace
 
drop if Ambiguous == 1
drop if (author == "Sherwin Rosen" & year >= death + 2 | dead == 1 & author != "Sherwin Rosen")
 
* generate filter for NAS primary fellows. For secondary fellows, we keep them in 
* the risk set up to and including the year they are elected, but are not counted as
* a fellow and then dropped after that year
gen NAS_sample = 1
replace new_fellow_NAS = 0 if primary_NAS_econ == 0
replace NAS_sample = 0 if year > year_appointed_NAS & primary_NAS_econ == 0

* same for AAAS 
gen AAAS_sample = 1
replace new_fellow_AAAS = 0 if AAAS_flags == 3
replace AAAS_sample = 0 if year > year_appointed_AAAS & AAAS_flags == 3

* ==============================================================================
** Female*decade coefficient
* start-1980*female
gen year_start_1970 = 0 

local list_decade 1880 1890 1900 1910 1920 1930 1940 1950 1960 1970
foreach decade in `list_decade'{
	replace year_start_1970 = 1 if floor(year/10)*10== `decade'
}

gen Female_start_1970 = 0 
replace Female_start_1970 = 1 if year_start_1970 * Female == 1
label variable Female_start_1970 "Whether or not Female before 1990"


* gen per decade * female interaction term 
local list_decade 1980 1990 2000 2010
foreach decade in `list_decade'{
	gen year_`decade' = 0 
	replace year_`decade' = 1 if floor(year/10)*10== `decade'
	gen Female_`decade' = Female * year_`decade'
	gen Ambiguous_`decade' = Ambiguous * year_`decade'
}

drop year_*

* new coefficients for levels of top5 and cites 
gen top5 = AER_cumulative+QJE_cumulative+REStud_cumulative+ECTA_cumulative+JPE_cumulative
gen top5_cite_cumulative=AER_cite_cumulative+QJE_cite_cumulative+REStud_cite_cumulative+ECTA_cite_cumulative+JPE_cite_cumulative

gen top5_1=(top5 <= 3)
gen top5_2=(top5 >= 4 & top5 <= 5)
gen top5_3=(top5 >= 6 & top5 <= 7)
gen top5_4=(top5 >= 8 & top5 <= 9)
gen top5_5=(top5 >= 10 & top5 <= 11)
gen top5_6=(top5 >= 12 & top5 <= 13)
gen top5_7=(top5 >= 14 & top5 <= 15)
gen top5_8=(top5 >= 16)

* levels of citation 
gen if_top5=(top5>=1)
gen if_riskset = (fellow_EMA == 0 | new_fellow_EMA == 1)

gen decade = . 
local list_decade 1940 1950 1960 1970 1980 1990 2000 2010 
foreach decade in `list_decade'{
	replace decade = `decade' if floor(year/10)*10 == `decade'
}
replace decade = 1930 if inrange(year, 1931, 1939)

gen topcite = . 

levelsof decade, local(levels)
foreach d in `levels'{
	
	_pctile top5_cite_cumulative if decade == `d' & if_top5 == 1 & if_riskset == 1, p(50 70 80 90 95 97.5 99)
	return list
	
	replace topcite = 1 if top5_cite_cumulative < r(r1) & decade == `d'
	replace topcite = 2 if top5_cite_cumulative < r(r2) & top5_cite_cumulative >= r(r1) & decade == `d'
	replace topcite = 3 if top5_cite_cumulative < r(r3) & top5_cite_cumulative >= r(r2) & decade == `d'
	replace topcite = 4 if top5_cite_cumulative < r(r4) & top5_cite_cumulative >= r(r3) & decade == `d'
	replace topcite = 5 if top5_cite_cumulative < r(r5) & top5_cite_cumulative >= r(r4) & decade == `d'
	replace topcite = 6 if top5_cite_cumulative < r(r6) & top5_cite_cumulative >= r(r5) & decade == `d'
	replace topcite = 7 if top5_cite_cumulative < r(r7) & top5_cite_cumulative >= r(r6) & decade == `d'
	replace topcite = 8 if top5_cite_cumulative >= r(r7) & decade == `d'
	
}

gen topcite1 = (topcite == 1)
gen topcite2 = (topcite == 2)
gen topcite3 = (topcite == 3)
gen topcite4 = (topcite == 4)
gen topcite5 = (topcite == 5)
gen topcite6 = (topcite == 6) 
gen topcite7 = (topcite == 7) 
gen topcite8 = (topcite == 8)

* years since first publication 
gen firstpub_10 = (years_firstpub < 20 & years_firstpub >= 10)
gen firstpub_20 = (years_firstpub < 30 & years_firstpub >= 20)
gen firstpub_30 = (years_firstpub >= 30)

drop decade topcite

* ==============================================================================
* controls
unab journal: AER_cumulative-TE_cumulative
unab top5_dum: top5_2-top5_8
unab citations: asinh*cites topcite2-topcite8 
unab firstpub_AAAS: firstpub_20 firstpub_30
unab firstpub_NAS: firstpub_30 

* specifications 
unab spec1: asinh*cites `journal' 
unab spec2: `journal' `top5_dum' `citations' `firstpub_AAAS' 

* pre-1980 	
eststo fellow_AAAS_start_1: logit new_fellow_AAAS Female `spec1' i.year ///
if (fellow_AAAS==0|new_fellow_AAAS==1)& year < 1980 & year >= 1931 & AAAS_sample, cluster(author) iter(20)

eststo fellow_AAAS_start_2: logit new_fellow_AAAS Female `spec2' i.year ///
if (fellow_AAAS==0|new_fellow_AAAS==1)& year < 1980 & year >= 1931 & AAAS_sample, cluster(author) iter(20)

* 1980 - 1999
eststo fellow_AAAS_1980_1: logit new_fellow_AAAS Female_1980 Female_1990 `spec1' i.year ///
if (fellow_AAAS==0|new_fellow_AAAS==1)& year < 2000 & year >= 1980 & AAAS_sample, cluster(author) iter(20)

eststo fellow_AAAS_1980_2: logit new_fellow_AAAS Female_1980 Female_1990 `spec2' i.year ///
if (fellow_AAAS==0|new_fellow_AAAS==1)& year < 2000 & year >= 1980 & AAAS_sample, cluster(author) iter(20)

* 2000 - 2019
eststo fellow_AAAS_2000_1: logit new_fellow_AAAS Female_2000 Female_2010 `spec1' i.year ///
if (fellow_AAAS==0|new_fellow_AAAS==1)& year >= 2000 & AAAS_sample, cluster(author) iter(20)

eststo fellow_AAAS_2000_2: logit new_fellow_AAAS Female_2000 Female_2010 `spec2' i.year ///
if (fellow_AAAS==0|new_fellow_AAAS==1)& year >= 2000 & AAAS_sample, cluster(author) iter(20)

* specifications 
unab spec1: asinh*cites `journal' 
unab spec2: `journal' `top5_dum' `citations' `firstpub_NAS' 

* pre-1980 
eststo fellow_NAS_start_1: logit new_fellow_NAS Female `spec1' i.year ///
if (fellow_NAS==0|new_fellow_NAS==1)& year < 1980 & year > 1932 & NAS_sample, cluster(author) iter(20)

eststo fellow_NAS_start_2: logit new_fellow_NAS Female `spec2' i.year ///
if (fellow_NAS==0|new_fellow_NAS==1)& year < 1980 & year > 1932 & NAS_sample, cluster(author) iter(20)

* 1980 - 1999
eststo fellow_NAS_1980_1: logit new_fellow_NAS Female_1980 Female_1990 `spec1' i.year ///
if (fellow_NAS==0|new_fellow_NAS==1)& year < 2000 & year >= 1980 & NAS_sample, cluster(author) iter(20)

eststo fellow_NAS_1980_2: logit new_fellow_NAS Female_1980 Female_1990 `spec2' i.year ///
if (fellow_NAS==0|new_fellow_NAS==1)& year < 2000 & year >= 1980 & NAS_sample, cluster(author) iter(20)

* 2000 - 2019
eststo fellow_NAS_2000_1: logit new_fellow_NAS Female_2000 Female_2010 `spec1' i.year ///
if (fellow_NAS==0|new_fellow_NAS==1)& year >= 2000 & NAS_sample, cluster(author) iter(20)

eststo fellow_NAS_2000_2: logit new_fellow_NAS Female_2000 Female_2010 `spec2' i.year ///
if (fellow_NAS==0|new_fellow_NAS==1)& year >= 2000 & NAS_sample, cluster(author) iter(20)


* ==============================================================================
* export 

* labeling 
label variable Female "Female Economist*(pre-1980)"
label variable Female_1980 "Female Economist*(1980-89)"
label variable Female_1990 "Female Economist*(1990-99)"
label variable Female_2000 "Female Economist*(2000-09)"
label variable Female_2010 "Female Economist*(2010-19)"

label variable ECTA_cite_cumulative "Asinh citations in Econometrica"
label variable REStud_cite_cumulative "Asinh citations in REStud"
label variable AER_cite_cumulative "Asinh citations in AER"
label variable QJE_cite_cumulative "Asinh citations in QJE"
label variable JPE_cite_cumulative "Asinh citations in JPE"

label variable ECTA_cumulative "Papers in Econometrica"
label variable REStud_cumulative "Papers in Review of Economic Studies"
label variable AER_cumulative "Papers in American Economic Review"
label variable QJE_cumulative "Papers in Quarterly Journal of Eco."
label variable JPE_cumulative "Papers in JPE"

* labeling for journal controls 
unab list_journal: AER-JEH
foreach journal in `list_journal'{

	local old_label: var label `journal'
	label variable `journal'_cumulative "Papers in `old_label'"
}


unab list_journal: AER_cumulative-EJ_cumulative JDE_cumulative-JEH_cumulative JASA_cumulative QE_cumulative TE_cumulative
unab ordering: Female Female_1980 Female_1990 Female_2000 Female_2010 ECTA_cumulative asinhEMAcites REStud_cumulative asinhREScites ///
AER_cumulative asinhAERcites QJE_cumulative asinhQJEcites JPE_cumulative asinhJPEcites
unab ordering_top5_full: top5_2-top5_8 topcite2-topcite8 firstpub_20 firstpub_30

* output file for appendix table 14 full 
esttab fellow_AAAS_start_* fellow_AAAS_1980_* fellow_AAAS_2000_* ///
fellow_NAS_start_* fellow_NAS_1980_* fellow_NAS_2000_* using "tables/tableA14.csv", ///
order(`ordering' `list_journal' `ordering_top5_full') csv se(%9.3f) b(%9.3f) pr2 scalars(N) sfmt(%9.0fc) ///
refcat(Female "Authors' Genders (Omitted: Male Author)" ///
ECTA_cumulative "Cumulative Publications and Citations Received in top-5 journals" ///
AERPP_cumulative "Cumulative Publications in other Journals" ///
JOLE_cumulative "APPENDIX TABLE V CONTINUED" ///
top5_2 "Levels of Top5 and Top 5 Citations" ///
topcite2 "Levels of Top 5 Citations (percentile)" ///
firstpub_20 "Years since first publication", nolabel) ///
mgroups(AAAS NAS, pattern(1 0 0 1 0 0)) ///
title("Table A14") keep(`ordering' `list_journal' `ordering_top5_full') ///
label nostar nogaps nodepvars extracols(4 7) replace



log off
log close



