* appendix table 15

clear
eststo clear

if !missing("$dropbox_dir") {
	local dropbox_dir = "$dropbox_dir"
}
else {
	local dropbox_dir "C:/Users/Chris/Dropbox"
}
cd "`dropbox_dir'/ECM_Fellow_Study/Replication"
use "`dropbox_dir'\ECM_Fellow_Study\Paper2\econ\output\regression_dataset_public.dta"

cap log close
log using "tables/tableA15.log", replace
 
drop if Ambiguous == 1
drop if (author == "Sherwin Rosen" & year >= death + 2 | dead == 1 & author != "Sherwin Rosen")
 
* ==============================================================================
** Female*decade coefficient
* start-1980*female
gen year_start_1970 = 0 

local list_decade 1880 1890 1900 1910 1920 1930 1940 1950 1960 1970
foreach decade in `list_decade'{
	replace year_start_1970 = 1 if floor(year/10)*10== `decade'
}

gen Female_start_1970 = 0 
replace Female_start_1970 = 1 if year_start_1970 * Female == 1
label variable Female_start_1970 "Whether or not Female before 1990"


* gen per decade * female interaction term 
local list_decade 1980 1990 2000 2010
foreach decade in `list_decade'{
	gen year_`decade' = 0 
	replace year_`decade' = 1 if floor(year/10)*10== `decade'
	gen Female_`decade' = Female * year_`decade'
	gen Ambiguous_`decade' = Ambiguous * year_`decade'
}

drop year_*

* new coefficients for levels of top5 and cites 
gen top5 = AER_cumulative+QJE_cumulative+REStud_cumulative+ECTA_cumulative+JPE_cumulative
gen top5_cite_cumulative=AER_cite_cumulative+QJE_cite_cumulative+REStud_cite_cumulative+ECTA_cite_cumulative+JPE_cite_cumulative

gen sloan_top5_1=(top5<=1)
gen sloan_top5_2=(top5==2)
gen sloan_top5_3=(top5==3)
gen sloan_top5_4=(top5==4)
gen sloan_top5_5=(top5>=5)

gen top5_1=(top5 <= 3)
gen top5_2=(top5 >= 4 & top5 <= 5)
gen top5_3=(top5 >= 6 & top5 <= 7)
gen top5_4=(top5 >= 8 & top5 <= 9)
gen top5_5=(top5 >= 10 & top5 <= 11)
gen top5_6=(top5 >= 12 & top5 <= 13)
gen top5_7=(top5 >= 14 & top5 <= 15)
gen top5_8=(top5 >= 16)

* levels of citation 
gen if_top5=(top5>=1)
gen if_riskset = (fellow_EMA == 0 | new_fellow_EMA == 1)

gen decade = . 
local list_decade 1940 1950 1960 1970 1980 1990 2000 2010 
foreach decade in `list_decade'{
	replace decade = `decade' if floor(year/10)*10 == `decade'
}
replace decade = 1930 if inrange(year, 1931, 1939)

gen topcite = . 

levelsof decade, local(levels)
foreach d in `levels'{
	
	_pctile top5_cite_cumulative if decade == `d' & if_top5 == 1 & if_riskset == 1, p(50 70 80 90 95 97.5 99)
	return list
	
	replace topcite = 1 if top5_cite_cumulative < r(r1) & decade == `d'
	replace topcite = 2 if top5_cite_cumulative < r(r2) & top5_cite_cumulative >= r(r1) & decade == `d'
	replace topcite = 3 if top5_cite_cumulative < r(r3) & top5_cite_cumulative >= r(r2) & decade == `d'
	replace topcite = 4 if top5_cite_cumulative < r(r4) & top5_cite_cumulative >= r(r3) & decade == `d'
	replace topcite = 5 if top5_cite_cumulative < r(r5) & top5_cite_cumulative >= r(r4) & decade == `d'
	replace topcite = 6 if top5_cite_cumulative < r(r6) & top5_cite_cumulative >= r(r5) & decade == `d'
	replace topcite = 7 if top5_cite_cumulative < r(r7) & top5_cite_cumulative >= r(r6) & decade == `d'
	replace topcite = 8 if top5_cite_cumulative >= r(r7) & decade == `d'
	
}

gen topcite1 = (topcite == 1)
gen topcite2 = (topcite == 2)
gen topcite3 = (topcite == 3)
gen topcite4 = (topcite == 4)
gen topcite5 = (topcite == 5)
gen topcite6 = (topcite == 6) 
gen topcite7 = (topcite == 7) 
gen topcite8 = (topcite == 8)

* years since first publication 
gen firstpub_10 = (years_firstpub < 20 & years_firstpub >= 10)
gen firstpub_20 = (years_firstpub < 30 & years_firstpub >= 20)
gen firstpub_30 = (years_firstpub >= 30)

drop decade topcite

* ==============================================================================
* controls 

unab journal: AER_cumulative-TE_cumulative
unab top5_dum_AEAF: top5_2-top5_8
unab top5_dum_Sloan: sloan_top5_2-sloan_top5_5
unab citations: asinh*cites topcite2-topcite8 
unab asinh_citations_only: asinh*cites

* specifications 
unab spec1: asinh*cites `journal' 
unab spec2_AEAF: `journal' `citations' `top5_dum_AEAF' firstpub_30 
unab spec2_Sloan: `journal' `asinh_citations_only' `top5_dum_Sloan' 


* logit model for AEAF
* pre-1980 	
eststo fellow_AEAF_start_1: logit new_fellow_AEAF Female `spec1' i.year ///
if (fellow_AEAF==0|new_fellow_AEAF==1)& year < 1980 & year > 1932, cluster(author) iter(20)
eststo fellow_AEAF_start_2: logit new_fellow_AEAF Female `spec2_AEAF' i.year ///
if (fellow_AEAF==0|new_fellow_AEAF==1)& year < 1980 & year > 1932, cluster(author) iter(20)


* 1980 - 1999
eststo fellow_AEAF_1980_1: logit new_fellow_AEAF Female_1980 Female_1990 `spec1' i.year ///
if (fellow_AEAF==0|new_fellow_AEAF==1)& year < 2000 & year >= 1980, cluster(author) iter(20)
eststo fellow_AEAF_1980_2: logit new_fellow_AEAF Female_1980 Female_1990 `spec2_AEAF' i.year ///
if (fellow_AEAF==0|new_fellow_AEAF==1)& year < 2000 & year >= 1980, cluster(author) iter(20)

* 2000 - 2019
eststo fellow_AEAF_2000_1: logit new_fellow_AEAF Female_2000 Female_2010 `spec1' i.year ///
if (fellow_AEAF==0|new_fellow_AEAF==1)& year >= 2000, cluster(author) iter(20)
eststo fellow_AEAF_2000_2: logit new_fellow_AEAF Female_2000 Female_2010 `spec2_AEAF' i.year ///
if (fellow_AEAF==0|new_fellow_AEAF==1)& year >= 2000, cluster(author) iter(20)


* logit model for Sloan 
* 1980 - 1999
eststo fellow_Sloan_1980_1: logit new_fellow_Sloan Female_1980 Female_1990 `spec1' i.year ///
if (fellow_Sloan==0|new_fellow_Sloan==1)& year < 2000 & year >= 1980 & years_firstpub <= 8, cluster(author) iter(20)
eststo fellow_Sloan_1980_2: logit new_fellow_Sloan Female_1980 Female_1990 `spec2_Sloan' i.year ///
if (fellow_Sloan==0|new_fellow_Sloan==1)& year < 2000 & year >= 1980 & years_firstpub <= 8, cluster(author) iter(20)

* 2000 - 2019
eststo fellow_Sloan_2000_1: logit new_fellow_Sloan Female_2000 Female_2010 `spec1' i.year ///
if (fellow_Sloan==0|new_fellow_Sloan==1)& year >= 2000 & years_firstpub <= 8, cluster(author) iter(20)
eststo fellow_Sloan_2000_2: logit new_fellow_Sloan Female_2000 Female_2010 `spec2_Sloan' i.year ///
if (fellow_Sloan==0|new_fellow_Sloan==1)& year >= 2000 & years_firstpub <= 8, cluster(author) iter(20)


* ==============================================================================
* export 

* labeling 
label variable Female "Female Economist*(pre-1980)"
label variable Female_1980 "Female Economist*(1980-89)"
label variable Female_1990 "Female Economist*(1990-99)"
label variable Female_2000 "Female Economist*(2000-09)"
label variable Female_2010 "Female Economist*(2010-19)"

label variable ECTA_cite_cumulative "Asinh citations in Econometrica"
label variable REStud_cite_cumulative "Asinh citations in REStud"
label variable AER_cite_cumulative "Asinh citations in AER"
label variable QJE_cite_cumulative "Asinh citations in QJE"
label variable JPE_cite_cumulative "Asinh citations in JPE"

label variable ECTA_cumulative "Papers in Econometrica"
label variable REStud_cumulative "Papers in Review of Economic Studies"
label variable AER_cumulative "Papers in American Economic Review"
label variable QJE_cumulative "Papers in Quarterly Journal of Eco."
label variable JPE_cumulative "Papers in JPE"

* labeling for journal controls 
unab list_journal: AER-JEH
foreach journal in `list_journal'{

	local old_label: var label `journal'
	label variable `journal'_cumulative "Papers in `old_label'"
}


unab list_journal: AER_cumulative-EJ_cumulative JDE_cumulative-JEH_cumulative JASA_cumulative QE_cumulative TE_cumulative
unab ordering: Female Female_1980 Female_1990 Female_2000 Female_2010 ECTA_cumulative asinhEMAcites REStud_cumulative asinhREScites ///
AER_cumulative asinhAERcites QJE_cumulative asinhQJEcites JPE_cumulative asinhJPEcites
unab ordering_top5_full: top5_2-top5_8 sloan_top5_1-sloan_top5_5 topcite2-topcite8 firstpub_30

* output file for appendix table 13 full 
esttab fellow_AEAF_start_1 fellow_AEAF_start_2 fellow_AEAF_1980_1 fellow_AEAF_1980_2 ///
fellow_AEAF_2000_1 fellow_AEAF_2000_2 fellow_Sloan_1980_1 fellow_Sloan_1980_2 ///
fellow_Sloan_2000_1 fellow_Sloan_2000_2 using "tables/tableA15.csv", ///
order(`ordering' `list_journal' `ordering_top5_full') csv se(%9.3f) b(%9.3f) pr2 scalars(N) sfmt(%9.0fc) ///
refcat(Female "Authors' Genders (Omitted: Male Author)" ///
ECTA_cumulative "Cumulative Publications and Citations Received in top-5 journals" ///
AERPP_cumulative "Cumulative Publications in other Journals" ///
JPubE_cumulative "APPENDIX TABLE V CONTINUED" ///
top5_1 "Levels of Top5 and Top 5 Citations" ///
topcite2 "Levels of Top 5 Citations (percentile)" ///
firstpub_30 "Years since first publication", nolabel) ///
mgroups(AEAF Sloan, pattern(1 0 0 0 0 0 1 0 0 0)) ///
title("Table AXV") keep(`ordering' `list_journal' `ordering_top5_full') ///
label nostar nogaps nodepvars extracols(7) replace



log off
log close



