* table A4

clear 
eststo clear

if !missing("$dropbox_dir") {
	local dropbox_dir = "$dropbox_dir"
}
else {
	local dropbox_dir "C:/Users/Chris/Dropbox"
}
cd "`dropbox_dir'/ECM_Fellow_Study/Replication"
use "`dropbox_dir'/ECM_Fellow_Study\Paper2\econ\output\regression_dataset.dta"

cap log close 
log using "tables/tableA4b.log", replace

* ==============================================================================

* exclude deceased authors
drop if (author == "Sherwin Rosen" & year >= death + 2 | dead == 1 & author != "Sherwin Rosen")

* cumulative publication variables 

gen JEP_JEL_cumulative = JEP_cumulative + JEL_cumulative 

gen ECA_IER_cumulative = ECA_cumulative + IER_cumulative 

gen Theory_cumulative = JET_cumulative + ET_cumulative + GEB_cumulative + IJGT_cumulative + JMathE_cumulative + TE_cumulative 

gen Econometrics_cumulative = EcT_cumulative + JE_cumulative + JASA_cumulative 

gen Macro_cumulative = AEJ_Macro_cumulative + JME_cumulative 

gen Public_cumulative = JPubE_cumulative + AEJ_Policy_cumulative

gen Micro_cumulative = AEJ_Applied_cumulative + JOLE_cumulative + JEH_cumulative + JHE_cumulative + JPubE_cumulative + JDE_cumulative + AEJ_Policy_cumulative 

** regions / institutions 
gen UStop5 = (location == "US Top 5")
gen UStop17 = (location == "US 6-17")
gen USother = (location == "US Below 17")
gen Europe = (location == "Europe")
gen AsiaAustr = (location == "Asia/Australia")
gen LatinAfrica = (location == "Latin America/Africa")

** byFellow / byCommittee
gen byFellow = 1 if byCommittee == 0 
replace byFellow = 0 if byCommittee == 1 

* endorsement missing encode 
replace numEndorsed = . if numEndorsed == 0 

* time intervals 
gen decade = "." /* drop if not in the range */
replace decade = "1990-2005" if inrange(year, 1990, 2005) 
replace decade = "2006-2019" if inrange(year, 2006, 2019)
drop if decade == "."

* ==============================================================================
* reg locals 

levelsof decade, local(levels)

local sumstat ECTA_cumulative REStud_cumulative AER_cumulative QJE_cumulative JPE_cumulative ///
ECTA_cite_cumulative REStud_cite_cumulative AER_cite_cumulative QJE_cite_cumulative JPE_cite_cumulative ///
Theory_cumulative Econometrics_cumulative Micro_cumulative years_firstpub

local region UStop5 UStop17 USother Europe AsiaAustr LatinAfrica 

local fellowships fellow_AAAS fellow_NAS fellow_AEAF fellow_Sloan

local sumstat_extended ECTA_cumulative REStud_cumulative AER_cumulative QJE_cumulative JPE_cumulative ///
ECTA_cite_cumulative REStud_cite_cumulative AER_cite_cumulative QJE_cite_cumulative JPE_cite_cumulative ///
JEP_JEL_cumulative AERPP_cumulative JEEA_cumulative EJ_cumulative REStat_cumulative ECA_IER_cumulative ///
Theory_cumulative Econometrics_cumulative AEJ_Micro_cumulative Macro_cumulative AEJ_Applied_cumulative QE_cumulative ///
JDE_cumulative JF_cumulative JHE_cumulative JEH_cumulative JIE_cumulative RAND_cumulative JOLE_cumulative ///
Public_cumulative years_firstpub


* ==============================================================================

local new_fellow nominee new_fellow_EMA byCommittee byFellow 

foreach new_fellow in `new_fellow'{
	
	foreach decade in `levels'{
		
		preserve 
		
		keep if `new_fellow' == 1 & decade == "`decade'" /* keep only fellows/nominated fellows from the decade */
	
		local fellow = substr("`new_fellow'", strrpos("`new_fellow'", "_")+1, .)
		
		local year = substr("`decade'", 1, 4)
		
		* extended t3 
		eststo ext_`fellow'_2_`year': qui estpost tabstat Female `fellowships' ///
		if decade == "`decade'", statistics(mean) columns(statistics) listwise 
		
		eststo ext_`fellow'_3_`year': qui estpost tabstat `sumstat_extended' ///
		if decade == "`decade'", statistics(mean) columns(statistics) listwise 
		
		eststo ext_`fellow'_2m_`year': qui estpost tabstat Female `fellowships' ///
		if Male == 1 & decade == "`decade'", statistics(mean) columns(statistics) listwise 
		
		eststo ext_`fellow'_3m_`year': qui estpost tabstat `sumstat_extended' ///
		if Male == 1 & decade == "`decade'", statistics(mean) columns(statistics) listwise 

		eststo ext_`fellow'_2f_`year': qui estpost tabstat Female `fellowships' ///
		if Female == 1 & decade == "`decade'", statistics(mean) columns(statistics) listwise 
		
		eststo ext_`fellow'_3f_`year': qui estpost tabstat `sumstat_extended' ///
		if Female == 1 & decade == "`decade'", statistics(mean) columns(statistics) listwise 
						
		restore 
		
		}
	}

	
	
* ==============================================================================
* some labeling 

* gender variables 
label variable Female "Fraction Female"

* fellowship variables
label variable fellow_AAAS "Fellow of AAAS (1942-2019)"
label variable fellow_NAS "Fellow of NAS (1968-2019)"
label variable fellow_AEAF "Fellow of AEA (1965-2019)"
label variable fellow_Sloan "Sloan Fellow (1981-2019)"

label variable JEP_JEL_cumulative "JEP+JEL"
label variable AERPP_cumulative "AER (AEA) Papers and Proceedings"
label variable ECA_IER_cumulative "Economica+IER"
label variable Theory_cumulative "Theory (JET+ET+GEB+IJGT+JMaE)"
label variable Econometrics_cumulative "Econometrics (EcT+JEc+JASA)"
label variable Macro_cumulative "Macro (AEJMacro+JME)"
label variable Public_cumulative "Public (JPubE+AEJPolicy)"
label variable Micro_cumulative "Empirical Micro (AEJApplied+JoLE+JEH+JHE+JPube+JDE+AEJPolicy)"
label variable ECTA_cite_cumulative "Econometrica"
label variable REStud_cite_cumulative "REStud"
label variable AER_cite_cumulative "AER"
label variable QJE_cite_cumulative "QJE"
label variable JPE_cite_cumulative "JPE"

label variable ECTA_cumulative "Econometrica"
label variable REStud_cumulative "REStud"
label variable AER_cumulative "AER"
label variable QJE_cumulative "QJE"
label variable JPE_cumulative "JPE"

label variable JEEA_cumulative "JEEA"
label variable EJ_cumulative "EJ"
label variable REStat_cumulative "REStat"
label variable AEJ_Micro_cumulative "Micro (AEJMicro)"
label variable AEJ_Applied_cumulative "AEJApplied"
label variable QE_cumulative "QE"
label variable JDE_cumulative "Development (JDE)"
label variable JF_cumulative "Finance (JF)"
label variable JHE_cumulative "Health (JHE)"
label variable JEH_cumulative "History (JEH)"
label variable JIE_cumulative "International (JIE)"
label variable RAND_cumulative "Industrial Organization (RAND)"
label variable JOLE_cumulative "Labor (JoLE)"

label variable UStop5 "Percent US Top5"
label variable UStop17 "Percent US Top17"
label variable USother "Percent US non-Top17"
label variable Europe "Percent Europe"
label variable AsiaAustr "Percent Asia and Australia"
label variable LatinAfrica "Percent Latin America and Africa"

label variable byFellow "Percent Nominated by Fellows (1995-)"
label variable byCommittee "Percent Nominated by Committee (1995-)"
label variable numVotes "Number of Votes (2006-)"
label variable numEndorsed "Number of Endorsements (if nom. By Fellows)"
	

* ==============================================================================
* export 

local format1 onecell nodepvars nostar unstack noobs nonotes nogaps nonumbers eqlabels(none)
local format2 nodepvars nostar nomtitle unstack nonumbers nogaps onecell
local format3 nodepvars nostar unstack nonumbers nogaps onecell nonotes noobs eqlabels(none)

local groups Fellow Nominee byCommittee byFellow 
local numbers ",'(1),'(2),'(3),,'(4),'(5),'(6),,'(7),'(8),'(9),,'(10),'(11),'(12)"
local mtitles "All" "Male" "Female" "All" "Male" "Female" "All" "Male" "Female" "All" "Male" "Female" 

local ext_1990_1 ext_nominee_2_1990 ext_nominee_2m_1990 ext_nominee_2f_1990 ext_EMA_2_1990 ext_EMA_2m_1990 ext_EMA_2f_1990 ///
	ext_byCommittee_2_1990 ext_byCommittee_2m_1990 ext_byCommittee_2f_1990 ext_byFellow_2_1990 ext_byFellow_2m_1990 ext_byFellow_2f_1990 
	
local ext_1990_2 ext_nominee_3_1990 ext_nominee_3m_1990 ext_nominee_3f_1990 ext_EMA_3_1990 ext_EMA_3m_1990 ext_EMA_3f_1990 ///
	ext_byCommittee_3_1990 ext_byCommittee_3m_1990 ext_byCommittee_3f_1990 ext_byFellow_3_1990 ext_byFellow_3m_1990 ext_byFellow_3f_1990 

	
local ext_2006_1 ext_nominee_2_2006 ext_nominee_2m_2006 ext_nominee_2f_2006 ext_EMA_2_2006 ext_EMA_2m_2006 ext_EMA_2f_2006 ///
	ext_byCommittee_2_2006 ext_byCommittee_2m_2006 ext_byCommittee_2f_2006 ext_byFellow_2_2006 ext_byFellow_2m_2006 ext_byFellow_2f_2006 
	
local ext_2006_2 ext_nominee_3_2006 ext_nominee_3m_2006 ext_nominee_3f_2006 ext_EMA_3_2006 ext_EMA_3m_2006 ext_EMA_3f_2006 ///
	ext_byCommittee_3_2006 ext_byCommittee_3m_2006 ext_byCommittee_3f_2006 ext_byFellow_3_2006 ext_byFellow_3m_2006 ext_byFellow_3f_2006 


esttab `ext_1990_1' using "tables/tableA4b.csv", ///
main(mean %12.4fc) `format1' ///
title("TABLE A4a") sfmt(%9.4fc %9.4fc) ///
mgroups(`groups', pattern(1 0 0 1 0 0 1 0 0 1 0 0)) ///
mtitles(`mtitles') posthead(`numbers') ///
refcat(fellow_AAAS "Percent Fellows (as of current year)", nolabel) ///
extracols(4 7 10 13) label replace  

esttab `ext_1990_2' using "tables/tableA4b.csv", ///
main(mean %12.2fc) `format2' sfmt(%9.4fc) ///
refcat(ECTA_cumulative "Cumulative publications in top-5 journals" ///
ECTA_cite_cumulative "Cum.citations in top-5 journals" ///
JEP_JEL_cumulative "Cum. publications in general interest journals" ///
Theory_cumulative "Cum. publications in field journals", nolabel) ///
extracols(4 7 10) nonotes label append  


esttab `ext_2006_1' using "tables/tableA4b.csv", ///
main(mean %12.4fc) `format1' sfmt(%9.4fc %9.4fc) ///
refcat(fellow_AAAS "Percent Fellows (as of current year)", nolabel) ///
title("TABLE A4b") mtitles(`mtitles') extracols(4 7 10 13) nonotes label replace  

esttab `ext_2006_2' using "tables/tableA4b.csv", ///
main(mean %12.2fc) `format2' sfmt(%9.4fc) ///
refcat(ECTA_cumulative "Cumulative publications in top-5 journals" ///
ECTA_cite_cumulative "Cum.citations in top-5 journals" ///
JEP_JEL_cumulative "Cum. publications in general interest journals" ///
Theory_cumulative "Cum. publications in field journals", nolabel) ///
extracols(4 7 10) label append 



import delimited "tables/tableA4b.csv", clear

foreach var in v5 v9 v13 {
replace `var' = ""
} 

foreach var in v2 v3 v4 v6 v7 v8 v10 v11 v12 v14 v15 v16 {

	replace `var' = subinstr(`var', ".", "", .) if inlist(_n, 3, 5, 6, 7, 8)
	replace `var' = substr(`var', 1, 5) + "." + substr(`var', 6, 9) if inlist(_n, 3, 5, 6, 7, 8)
}

export delimited "tables/tableA4b.csv", replace


log close
