* table A6 

clear
eststo clear
if !missing("$dropbox_dir") {
	local dropbox_dir = "$dropbox_dir"
}
else {
	local dropbox_dir "C:/Users/Chris/Dropbox"
}
cd "`dropbox_dir'/ECM_Fellow_Study/Replication"
use "`dropbox_dir'\ECM_Fellow_Study\Paper2\econ\output\regression_dataset_public.dta"

cap log close
log using "tables/tableA6.log", replace

* ==============================================================================
drop if (author == "Sherwin Rosen" & year >= death + 2 | dead == 1 & author != "Sherwin Rosen")
drop if Ambiguous == 1
keep if (fellow_EMA==0|new_fellow_EMA==1)

* drop ECM that received award prior to first publication
bys author: gen prior_to_pub = (year == year_appointed_EMA & years_firstpub < 0)
bys author: egen fellow_before_pub = max(prior_to_pub)
drop prior_to_pub


* author id 
qui egen id = group(author year)

* Female*decade coefficient
local list_decade 1980 1990 2000 2010
foreach decade in `list_decade'{
	gen year_`decade' = (floor(year/10)*10== `decade')
	gen Female_`decade' = Female * year_`decade'
}

drop year_*

* coefficients for levels of top5 and cites 
gen top5 = AER_cumulative+QJE_cumulative+REStud_cumulative+ECTA_cumulative+JPE_cumulative
gen top5_cite_cumulative=AER_cite_cumulative+QJE_cite_cumulative+REStud_cite_cumulative+ECTA_cite_cumulative+JPE_cite_cumulative

gen top5_1=(top5==1)
gen top5_2=(top5==2)
gen top5_3=(top5==3)
gen top5_4=(top5==4)
gen top5_5=(top5==5)
gen top5_6=(top5==6)
gen top5_7=(top5>=7)

gen ema_1=(ECTA_cumulative==1)
gen ema_2=(ECTA_cumulative==2)
gen ema_3=(ECTA_cumulative>=3)

gen res_1=(REStud_cumulative==1)
gen res_2=(REStud_cumulative==2)
gen res_3=(REStud_cumulative>=3)

gen qje_1=(QJE_cumulative==1)
gen qje_2=(QJE_cumulative==2)
gen qje_3=(QJE_cumulative>=3)

gen aer_1=(AER_cumulative==1)
gen aer_2=(AER_cumulative==2)
gen aer_3=(AER_cumulative>=3)

gen jpe_1=(JPE_cumulative==1)
gen jpe_2=(JPE_cumulative==2)
gen jpe_3=(JPE_cumulative>=3)

* levels of citation 
gen if_top5=(top5>=1)
gen if_riskset = (fellow_EMA == 0 | new_fellow_EMA == 1)

gen decade = . 
local list_decade 1940 1950 1960 1970 1980 1990 2000 2010 
foreach decade in `list_decade'{
	replace decade = `decade' if floor(year/10)*10 == `decade'
}
replace decade = 1930 if inrange(year, 1931, 1939)

gen topcite = . 

levelsof decade, local(levels)
foreach d in `levels'{
	
	_pctile top5_cite_cumulative if decade == `d' & if_top5 == 1 & if_riskset == 1, p(50 70 80 90 95 97.5 99)
	return list
	
	replace topcite = 1 if top5_cite_cumulative < r(r1) & decade == `d'
	replace topcite = 2 if top5_cite_cumulative < r(r2) & top5_cite_cumulative >= r(r1) & decade == `d'
	replace topcite = 3 if top5_cite_cumulative < r(r3) & top5_cite_cumulative >= r(r2) & decade == `d'
	replace topcite = 4 if top5_cite_cumulative < r(r4) & top5_cite_cumulative >= r(r3) & decade == `d'
	replace topcite = 5 if top5_cite_cumulative < r(r5) & top5_cite_cumulative >= r(r4) & decade == `d'
	replace topcite = 6 if top5_cite_cumulative < r(r6) & top5_cite_cumulative >= r(r5) & decade == `d'
	replace topcite = 7 if top5_cite_cumulative < r(r7) & top5_cite_cumulative >= r(r6) & decade == `d'
	replace topcite = 8 if top5_cite_cumulative >= r(r7) & decade == `d'
	
}

gen topcite1 = (topcite == 1)
gen topcite2 = (topcite == 2)
gen topcite3 = (topcite == 3)
gen topcite4 = (topcite == 4)
gen topcite5 = (topcite == 5)
gen topcite6 = (topcite == 6) 
gen topcite7 = (topcite == 7) 
gen topcite8 = (topcite == 8)

* years since first publication
gen firstpub_10 = (years_firstpub < 20 & years_firstpub >= 10)
gen firstpub_20 = (years_firstpub < 30 & years_firstpub >= 20)
gen firstpub_30 = (years_firstpub >= 30)

drop decade topcite

* ==============================================================================
* controls 

unab journal: AER_cumulative-TE_cumulative
unab citations: asinh*cites
unab levels_top5: top5_1-top5_7 
unab levels_cite: topcite2-topcite8
unab top5_dum: ema_1 ema_2 ema_3 res_1 res_2 res_3 qje_1 qje_2 qje_3 aer_1 aer_2 aer_3 jpe_1 jpe_2 jpe_3
unab years_firstpub: firstpub_10 firstpub_20 firstpub_30

* specifications 
local spec1 `citations' `journal' `levels_top5' `levels_cite' `top5_dum' `years_firstpub'
local spec2 `levels_top5' `levels_cite' top5 


preserve

keep if year >= 2000

eststo robust_fellow_EMA_2000_1 : logit new_fellow_EMA Female_2000 Female_2010 i.year `spec1' ///
if (fellow_EMA==0|new_fellow_EMA==1), cluster(author) iter(20)

eststo robust_fellow_EMA_2000_2 : logit new_fellow_EMA Female_2000 Female_2010  i.year `spec2' ///
if (fellow_EMA==0|new_fellow_EMA==1), cluster(author) iter(20)

eststo robust_fellow_EMA_2000_3 : logit new_fellow_EMA Female_2000 Female_2010  i.year `spec1' ///
if (fellow_EMA==0|new_fellow_EMA==1) & !fellow_before_pub, cluster(author) iter(20)

restore, preserve

keep if year < 2000 & year >= 1980

eststo robust_fellow_EMA_1980_1 : logit new_fellow_EMA Female_1980 Female_1990 i.year `spec1' ///
if (fellow_EMA==0|new_fellow_EMA==1), cluster(author) iter(20)

eststo robust_fellow_EMA_1980_2 : logit new_fellow_EMA Female_1980 Female_1990 i.year `spec2' ///
if (fellow_EMA==0|new_fellow_EMA==1), cluster(author) iter(20)

eststo robust_fellow_EMA_1980_3 : logit new_fellow_EMA Female_1980 Female_1990 i.year `spec1' ///
if (fellow_EMA==0|new_fellow_EMA==1) & !fellow_before_pub, cluster(author) iter(20)

restore, preserve

keep if year < 1980 & year >= 1933

eststo robust_fellow_EMA_start_1 : logit new_fellow_EMA Female i.year `spec1' ///
if (fellow_EMA==0|new_fellow_EMA==1), cluster(author) iter(20)

eststo robust_fellow_EMA_start_2 : logit new_fellow_EMA Female i.year  `spec2'  ///
if (fellow_EMA==0|new_fellow_EMA==1), cluster(author) iter(20)

eststo robust_fellow_EMA_start_3 : logit new_fellow_EMA Female i.year  `spec1'  ///
if (fellow_EMA==0|new_fellow_EMA==1) & !fellow_before_pub, cluster(author) iter(20)

restore, preserve


* ==============================================================================
* export 

local order Female Female_1980 Female_1990 Female_2000 Female_2010

esttab ///
	robust_fellow_EMA_start_* robust_fellow_EMA_1980_* robust_fellow_EMA_2000_* ///
	using "tables/tableA6.csv", ///
	order(`order') csv se(%9.3f) b(%9.3f) pr2 scalars(N) sfmt(%9.0fc) ///
	refcat(Female "Authors' Genders (Omitted: Male Author)", nolabel) ///
	mgroups(1933-79 1980-99 2000-19, pattern(1 0 1 0 1 0)) ///
	title("Table AVI") keep(`order') label nostar nogaps nodepvars extracols(4 7) replace


log off
log close 
